@@ -43,7 +43,23 @@ import docs202Config from '../../../site_config/docs2-0-2';
 import docs203Config from '../../../site_config/docs2-0-3';
 import docs205Config from '../../../site_config/docs2-0-5';
 import docs206Config from '../../../site_config/docs2-0-6';
+import docs207Config from '../../../site_config/docs2-0-7';
 import docs300Config from '../../../site_config/docs3-0-0';
+import docs301Config from '../../../site_config/docs3-0-1';
+import docs302Config from '../../../site_config/docs3-0-2';
+import docs303Config from '../../../site_config/docs3-0-3';
+import docs304Config from '../../../site_config/docs3-0-4';
+import docs305Config from '../../../site_config/docs3-0-5';
+import docs306Config from '../../../site_config/docs3-0-6';
+import docs310Config from '../../../site_config/docs3-1-0';
+import docs311Config from '../../../site_config/docs3-1-1';
+import docs312Config from '../../../site_config/docs3-1-2';
+import docs313Config from '../../../site_config/docs3-1-3';
+import docs314Config from '../../../site_config/docs3-1-4';
+import docs315Config from '../../../site_config/docs3-1-5';
+import docs316Config from '../../../site_config/docs3-1-6';
+import docs317Config from '../../../site_config/docs3-1-7';
+import docs318Config from '../../../site_config/docs3-1-8';
 import docsDevConfig from '../../../site_config/docsdev';
 
 const docsSource = {
@@ -63,7 +79,23 @@ const docsSource = {
   '2.0.3': docs203Config,
   '2.0.5': docs205Config,
   '2.0.6': docs206Config,
+  '2.0.7': docs207Config,
   '3.0.0': docs300Config,
+  '3.0.1': docs301Config,
+  '3.0.2': docs302Config,
+  '3.0.3': docs303Config,
+  '3.0.4': docs304Config,
+  '3.0.5': docs305Config,
+  '3.0.6': docs306Config,
+  '3.1.0': docs310Config,
+  '3.1.1': docs311Config,
+  '3.1.2': docs312Config,
+  '3.1.3': docs313Config,
+  '3.1.4': docs314Config,
+  '3.1.5': docs315Config,
+  '3.1.6': docs316Config,
+  '3.1.7': docs317Config,
+  '3.1.8': docs318Config,
   dev: docsDevConfig,
 };
 
