@@ -17,8 +17,8 @@
 
 package org.apache.dolphinscheduler.plugin.alert.http;
 
-import com.fasterxml.jackson.databind.node.ObjectNode;
 import org.apache.dolphinscheduler.alert.api.AlertResult;
+import org.apache.dolphinscheduler.alert.api.HttpServiceRetryStrategy;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 
 import org.apache.commons.lang3.StringUtils;
@@ -29,10 +29,8 @@ import org.apache.http.client.methods.HttpPost;
 import org.apache.http.client.methods.HttpRequestBase;
 import org.apache.http.entity.StringEntity;
 import org.apache.http.impl.client.CloseableHttpClient;
-import org.apache.http.impl.client.HttpClientBuilder;
+import org.apache.http.impl.client.HttpClients;
 import org.apache.http.util.EntityUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
@@ -44,8 +42,13 @@ import java.net.URLEncoder;
 import java.util.HashMap;
 import java.util.Map;
 
+import lombok.extern.slf4j.Slf4j;
+
+import com.fasterxml.jackson.databind.node.ObjectNode;
+
+@Slf4j
 public final class HttpSender {
-    private static final Logger logger = LoggerFactory.getLogger(HttpSender.class);
+
     private static final String URL_SPLICE_CHAR = "?";
     /**
      * request type post
@@ -91,14 +94,11 @@ public final class HttpSender {
         }
 
         try {
-            CloseableHttpClient httpClient = HttpClientBuilder.create().build();
-            CloseableHttpResponse response = httpClient.execute(httpRequest);
-            HttpEntity entity = response.getEntity();
-            String resp = EntityUtils.toString(entity, DEFAULT_CHARSET);
+            String resp = this.getResponseString(httpRequest);
             alertResult.setStatus("true");
             alertResult.setMessage(resp);
         } catch (Exception e) {
-            logger.error("send http alert msg  exception : {}", e.getMessage());
+            log.error("send http alert msg  exception : {}", e.getMessage());
             alertResult.setStatus("false");
             alertResult.setMessage("send http request  alert fail.");
         }
@@ -106,11 +106,19 @@ public final class HttpSender {
         return alertResult;
     }
 
+    public String getResponseString(HttpRequestBase httpRequest) throws IOException {
+        CloseableHttpClient httpClient =
+                HttpClients.custom().setRetryHandler(HttpServiceRetryStrategy.retryStrategy).build();
+        CloseableHttpResponse response = httpClient.execute(httpRequest);
+        HttpEntity entity = response.getEntity();
+        return EntityUtils.toString(entity, DEFAULT_CHARSET);
+    }
+
     private void createHttpRequest(String msg) throws MalformedURLException, URISyntaxException {
         if (REQUEST_TYPE_POST.equalsIgnoreCase(requestType)) {
             httpRequest = new HttpPost(url);
             setHeader();
-            //POST request add param in request body
+            // POST request add param in request body
             setMsgInRequestBody(msg);
         } else if (REQUEST_TYPE_GET.equalsIgnoreCase(requestType)) {
             // GET request add param in url
@@ -131,7 +139,7 @@ public final class HttpSender {
 
         if (StringUtils.isNotBlank(contentField)) {
             String type = "&";
-            //check splice char is & or ?
+            // check splice char is & or ?
             if (!url.contains(URL_SPLICE_CHAR)) {
                 type = URL_SPLICE_CHAR;
             }
@@ -163,13 +171,16 @@ public final class HttpSender {
      */
     private void setMsgInRequestBody(String msg) {
         try {
-            ObjectNode objectNode = JSONUtils.parseObject(bodyParams);
-            //set msg content field
+            ObjectNode objectNode = JSONUtils.createObjectNode();
+            if (StringUtils.isNotBlank(bodyParams)) {
+                objectNode = JSONUtils.parseObject(bodyParams);
+            }
+            // set msg content field
             objectNode.put(contentField, msg);
             StringEntity entity = new StringEntity(JSONUtils.toJsonString(objectNode), DEFAULT_CHARSET);
             ((HttpPost) httpRequest).setEntity(entity);
         } catch (Exception e) {
-            logger.error("send http alert msg  exception : {}", e.getMessage());
+            log.error("send http alert msg  exception : {}", e.getMessage());
         }
     }
 
