@@ -17,7 +17,7 @@
 
 package org.apache.dolphinscheduler.plugin.alert.script;
 
-import org.junit.Test;
+import org.junit.jupiter.api.Test;
 
 /**
  * ProcessUtilsTest
@@ -26,7 +26,8 @@ public class ProcessUtilsTest {
 
     private static final String rootPath = System.getProperty("user.dir");
 
-    private static final String shellFilPath = rootPath + "/dolphinscheduler-alert-plugins/dolphinscheduler-alert-script/src/test/script/shell/test.sh";
+    private static final String shellFilPath =
+            rootPath + "/dolphinscheduler-alert-plugins/dolphinscheduler-alert-script/src/test/script/shell/test.sh";
 
     private String[] cmd = {"/bin/sh", "-c", shellFilPath + " -t 1"};
 
