@@ -17,9 +17,9 @@
 
 package org.apache.dolphinscheduler.plugin.alert.telegram;
 
-import com.fasterxml.jackson.annotation.JsonProperty;
 import org.apache.dolphinscheduler.alert.api.AlertData;
 import org.apache.dolphinscheduler.alert.api.AlertResult;
+import org.apache.dolphinscheduler.alert.api.HttpServiceRetryStrategy;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 
 import org.apache.commons.lang3.StringUtils;
@@ -38,17 +38,18 @@ import org.apache.http.impl.client.BasicCredentialsProvider;
 import org.apache.http.impl.client.CloseableHttpClient;
 import org.apache.http.impl.client.HttpClients;
 import org.apache.http.util.EntityUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 
 import java.io.IOException;
 import java.nio.charset.StandardCharsets;
 import java.util.HashMap;
 import java.util.Map;
 
-public final class TelegramSender {
+import lombok.extern.slf4j.Slf4j;
 
-    private static final Logger logger = LoggerFactory.getLogger(TelegramSender.class);
+import com.fasterxml.jackson.annotation.JsonProperty;
+
+@Slf4j
+public final class TelegramSender {
 
     private static final String BOT_TOKEN_REGEX = "{botToken}";
 
@@ -70,7 +71,6 @@ public final class TelegramSender {
 
     private String password;
 
-
     TelegramSender(Map<String, String> config) {
         url = config.get(TelegramParamsConstants.NAME_TELEGRAM_WEB_HOOK);
         botToken = config.get(TelegramParamsConstants.NAME_TELEGRAM_BOT_TOKEN);
@@ -103,7 +103,7 @@ public final class TelegramSender {
             String resp = sendInvoke(alertData.getTitle(), alertData.getContent());
             result = parseRespToResult(resp);
         } catch (Exception e) {
-            logger.warn("send telegram alert msg exception : {}", e.getMessage());
+            log.warn("send telegram alert msg exception : {}", e.getMessage());
             result = new AlertResult();
             result.setStatus("false");
             result.setMessage(String.format("send telegram alert fail. %s", e.getMessage()));
@@ -133,14 +133,13 @@ public final class TelegramSender {
         return result;
     }
 
-
     private String sendInvoke(String title, String content) throws IOException {
         HttpPost httpPost = buildHttpPost(url, buildMsgJsonStr(content));
         CloseableHttpClient httpClient;
         if (Boolean.TRUE.equals(enableProxy)) {
             if (StringUtils.isNotEmpty(user) && StringUtils.isNotEmpty(password)) {
                 httpClient = getProxyClient(proxy, port, user, password);
-            }else {
+            } else {
                 httpClient = getDefaultClient();
             }
             RequestConfig rcf = getProxyConfig(proxy, port);
@@ -159,7 +158,7 @@ public final class TelegramSender {
             } finally {
                 response.close();
             }
-            logger.info("Telegram send title :{},content : {}, resp: {}", title, content, resp);
+            log.info("Telegram send title :{},content : {}, resp: {}", title, content, resp);
             return resp;
         } finally {
             httpClient.close();
@@ -181,6 +180,7 @@ public final class TelegramSender {
     }
 
     static class TelegramSendMsgResponse {
+
         @JsonProperty("ok")
         private Boolean ok;
         @JsonProperty("error_code")
@@ -240,14 +240,15 @@ public final class TelegramSender {
     }
 
     private static CloseableHttpClient getDefaultClient() {
-        return HttpClients.createDefault();
+        return HttpClients.custom().setRetryHandler(HttpServiceRetryStrategy.retryStrategy).build();
     }
 
     private static CloseableHttpClient getProxyClient(String proxy, int port, String user, String password) {
         HttpHost httpProxy = new HttpHost(proxy, port);
         CredentialsProvider provider = new BasicCredentialsProvider();
         provider.setCredentials(new AuthScope(httpProxy), new UsernamePasswordCredentials(user, password));
-        return HttpClients.custom().setDefaultCredentialsProvider(provider).build();
+        return HttpClients.custom().setRetryHandler(HttpServiceRetryStrategy.retryStrategy)
+                .setDefaultCredentialsProvider(provider).build();
     }
 
     private static RequestConfig getProxyConfig(String proxy, int port) {
