@@ -35,7 +35,6 @@ package org.apache.dolphinscheduler.api.permission;
 
 import static java.util.stream.Collectors.toSet;
 
-import org.apache.commons.collections.CollectionUtils;
 import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.dao.entity.AccessToken;
@@ -54,9 +53,7 @@ import org.apache.dolphinscheduler.dao.entity.WorkerGroup;
 import org.apache.dolphinscheduler.dao.mapper.AccessTokenMapper;
 import org.apache.dolphinscheduler.dao.mapper.AlertGroupMapper;
 import org.apache.dolphinscheduler.dao.mapper.AlertPluginInstanceMapper;
-import org.apache.dolphinscheduler.dao.mapper.CommandMapper;
 import org.apache.dolphinscheduler.dao.mapper.DataSourceMapper;
-import org.apache.dolphinscheduler.dao.mapper.DqRuleMapper;
 import org.apache.dolphinscheduler.dao.mapper.EnvironmentMapper;
 import org.apache.dolphinscheduler.dao.mapper.K8sNamespaceMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
@@ -69,6 +66,8 @@ import org.apache.dolphinscheduler.dao.mapper.UdfFuncMapper;
 import org.apache.dolphinscheduler.dao.mapper.WorkerGroupMapper;
 import org.apache.dolphinscheduler.service.process.ProcessService;
 
+import org.apache.commons.collections4.CollectionUtils;
+
 import java.util.ArrayList;
 import java.util.Arrays;
 import java.util.Collections;
@@ -88,39 +87,47 @@ import org.springframework.context.ApplicationContextAware;
 import org.springframework.stereotype.Component;
 
 @Component
-public class ResourcePermissionCheckServiceImpl implements ResourcePermissionCheckService<Object>, ApplicationContextAware {
+public class ResourcePermissionCheckServiceImpl
+        implements
+            ResourcePermissionCheckService<Object>,
+            ApplicationContextAware {
 
     @Autowired
     private ProcessService processService;
 
-    public static final Map<AuthorizationType, ResourceAcquisitionAndPermissionCheck<?>> RESOURCE_LIST_MAP = new ConcurrentHashMap<>();
+    public static final Map<AuthorizationType, ResourceAcquisitionAndPermissionCheck<?>> RESOURCE_LIST_MAP =
+            new ConcurrentHashMap<>();
 
     @Override
     public void setApplicationContext(ApplicationContext applicationContext) throws BeansException {
-        for (ResourceAcquisitionAndPermissionCheck<?> authorizedResourceList : applicationContext.getBeansOfType(ResourceAcquisitionAndPermissionCheck.class).values()) {
+        for (ResourceAcquisitionAndPermissionCheck<?> authorizedResourceList : applicationContext
+                .getBeansOfType(ResourceAcquisitionAndPermissionCheck.class).values()) {
             List<AuthorizationType> authorizationTypes = authorizedResourceList.authorizationTypes();
             authorizationTypes.forEach(auth -> RESOURCE_LIST_MAP.put(auth, authorizedResourceList));
         }
-     }
+    }
 
     @Override
-    public boolean resourcePermissionCheck(Object authorizationType, Object[] needChecks, Integer userId, Logger logger) {
+    public boolean resourcePermissionCheck(Object authorizationType, Object[] needChecks, Integer userId,
+                                           Logger logger) {
         if (Objects.nonNull(needChecks) && needChecks.length > 0) {
             Set<?> originResSet = new HashSet<>(Arrays.asList(needChecks));
-            Set<?> ownResSets = RESOURCE_LIST_MAP.get(authorizationType).listAuthorizedResource(userId, logger);
-            originResSet.removeAll(ownResSets);
-            if (CollectionUtils.isNotEmpty(originResSet))
+            Set<?> ownResSets = RESOURCE_LIST_MAP.get(authorizationType).listAuthorizedResourceIds(userId, logger);
+            boolean checkResult = ownResSets != null && ownResSets.containsAll(originResSet);
+            if (!checkResult) {
                 logger.warn("User does not have resource permission on associated resources, userId:{}", userId);
-            return CollectionUtils.isEmpty(originResSet);
+            }
+            return checkResult;
         }
         return true;
     }
 
     @Override
-    public boolean operationPermissionCheck(Object authorizationType, Object[] projectIds, Integer userId, String permissionKey, Logger logger) {
+    public boolean operationPermissionCheck(Object authorizationType, Integer userId,
+                                            String permissionKey, Logger logger) {
         User user = processService.getUserById(userId);
         if (user == null) {
-            logger.error("user id {} doesn't exist", userId);
+            logger.error("User does not exist, userId:{}.", userId);
             return false;
         }
         if (user.getUserType().equals(UserType.ADMIN_USER)) {
@@ -143,10 +150,10 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
     public Set<Object> userOwnedResourceIdsAcquisition(Object authorizationType, Integer userId, Logger logger) {
         User user = processService.getUserById(userId);
         if (user == null) {
-            logger.error("user id {} doesn't exist", userId);
+            logger.error("User does not exist, userId:{}.", userId);
             return Collections.emptySet();
         }
-        return (Set<Object>) RESOURCE_LIST_MAP.get(authorizationType).listAuthorizedResource(
+        return (Set<Object>) RESOURCE_LIST_MAP.get(authorizationType).listAuthorizedResourceIds(
                 user.getUserType().equals(UserType.ADMIN_USER) ? 0 : userId, logger);
     }
 
@@ -166,12 +173,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
 
         @Override
         public boolean permissionCheck(int userId, String permissionKey, Logger logger) {
-            // admin can create projects
             return false;
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             if (userId != 0) {
                 return Collections.emptySet();
             }
@@ -201,7 +207,7 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             return projectMapper.listAuthorizedProjects(userId, null).stream().map(Project::getId).collect(toSet());
         }
     }
@@ -224,14 +230,15 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<Resource> relationResources;
             if (userId == 0) {
                 relationResources = new ArrayList<>();
             } else {
                 // query resource relation
                 List<Integer> resIds = resourceUserMapper.queryResourcesIdListByUserIdAndPerm(userId, 0);
-                relationResources = CollectionUtils.isEmpty(resIds) ? new ArrayList<>() : resourceMapper.queryResourceListById(resIds);
+                relationResources = CollectionUtils.isEmpty(resIds) ? new ArrayList<>()
+                        : resourceMapper.queryResourceListById(resIds);
             }
             List<Resource> ownResourceList = resourceMapper.queryResourceListAuthored(userId, -1);
             relationResources.addAll(ownResourceList);
@@ -259,7 +266,7 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<UdfFunc> udfFuncList = udfFuncMapper.listAuthorizedUdfByUserId(userId);
             return udfFuncList.stream().map(UdfFunc::getId).collect(toSet());
         }
@@ -285,7 +292,7 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<TaskGroup> taskGroupList = taskGroupMapper.listAuthorizedResource(userId);
             return taskGroupList.stream().map(TaskGroup::getId).collect(Collectors.toSet());
         }
@@ -297,11 +304,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
     }
 
     @Component
-    public static class K8sNamespaceResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class K8sNamespaceResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final K8sNamespaceMapper k8sNamespaceMapper;
 
-        public K8sNamespaceResourceList(K8sNamespaceMapper k8sNamespaceMapper) {
+        public K8sNamespaceResourcePermissionCheck(K8sNamespaceMapper k8sNamespaceMapper) {
             this.k8sNamespaceMapper = k8sNamespaceMapper;
         }
 
@@ -316,19 +323,18 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<K8sNamespace> k8sNamespaces = k8sNamespaceMapper.queryAuthedNamespaceListByUserId(userId);
             return k8sNamespaces.stream().map(K8sNamespace::getId).collect(Collectors.toSet());
         }
     }
 
-
     @Component
-    public static class EnvironmentResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class EnvironmentResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final EnvironmentMapper environmentMapper;
 
-        public EnvironmentResourceList(EnvironmentMapper environmentMapper) {
+        public EnvironmentResourcePermissionCheck(EnvironmentMapper environmentMapper) {
             this.environmentMapper = environmentMapper;
         }
 
@@ -339,22 +345,22 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
 
         @Override
         public boolean permissionCheck(int userId, String url, Logger logger) {
-           return true;
+            return true;
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<Environment> environments = environmentMapper.queryAllEnvironmentList();
             return environments.stream().map(Environment::getId).collect(Collectors.toSet());
         }
     }
 
     @Component
-    public static class WorkerGroupResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class WorkerGroupResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final WorkerGroupMapper workerGroupMapper;
 
-        public WorkerGroupResourceList(WorkerGroupMapper workerGroupMapper) {
+        public WorkerGroupResourcePermissionCheck(WorkerGroupMapper workerGroupMapper) {
             this.workerGroupMapper = workerGroupMapper;
         }
 
@@ -368,9 +374,8 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
             return false;
         }
 
-
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<WorkerGroup> workerGroups = workerGroupMapper.queryAllWorkerGroup();
             return workerGroups.stream().map(WorkerGroup::getId).collect(Collectors.toSet());
         }
@@ -380,11 +385,13 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
      * AlertPluginInstance Resource
      */
     @Component
-    public static class AlertPluginInstanceResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class AlertPluginInstanceResourcePermissionCheck
+            implements
+                ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final AlertPluginInstanceMapper alertPluginInstanceMapper;
 
-        public AlertPluginInstanceResourceList(AlertPluginInstanceMapper alertPluginInstanceMapper) {
+        public AlertPluginInstanceResourcePermissionCheck(AlertPluginInstanceMapper alertPluginInstanceMapper) {
             this.alertPluginInstanceMapper = alertPluginInstanceMapper;
         }
 
@@ -398,9 +405,8 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
             return false;
         }
 
-
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             return Collections.emptySet();
         }
     }
@@ -409,11 +415,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
      * AlertPluginInstance Resource
      */
     @Component
-    public static class AlertGroupResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class AlertGroupResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final AlertGroupMapper alertGroupMapper;
 
-        public AlertGroupResourceList(AlertGroupMapper alertGroupMapper) {
+        public AlertGroupResourcePermissionCheck(AlertGroupMapper alertGroupMapper) {
             this.alertGroupMapper = alertGroupMapper;
         }
 
@@ -424,12 +430,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
 
         @Override
         public boolean permissionCheck(int userId, String url, Logger logger) {
-           return false;
+            return false;
         }
 
-
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<AlertGroup> alertGroupList = alertGroupMapper.queryAllGroupList();
             return alertGroupList.stream().map(AlertGroup::getId).collect(toSet());
         }
@@ -439,11 +444,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
      * Tenant Resource
      */
     @Component
-    public static class TenantResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class TenantResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final TenantMapper tenantMapper;
 
-        public TenantResourceList(TenantMapper tenantMapper) {
+        public TenantResourcePermissionCheck(TenantMapper tenantMapper) {
             this.tenantMapper = tenantMapper;
         }
 
@@ -457,9 +462,8 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
             return false;
         }
 
-
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
             List<Tenant> tenantList = tenantMapper.queryAll();
             return tenantList.stream().map(Tenant::getId).collect(Collectors.toSet());
         }
@@ -469,11 +473,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
      * DataSource Resource
      */
     @Component
-    public static class DataSourceResourceList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class DataSourceResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final DataSourceMapper dataSourceMapper;
 
-        public DataSourceResourceList(DataSourceMapper dataSourceMapper) {
+        public DataSourceResourcePermissionCheck(DataSourceMapper dataSourceMapper) {
             this.dataSourceMapper = dataSourceMapper;
         }
 
@@ -487,10 +491,10 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
             return true;
         }
 
-
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
-            return dataSourceMapper.listAuthorizedDataSource(userId, null).stream().map(DataSource::getId).collect(toSet());
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
+            return dataSourceMapper.listAuthorizedDataSource(userId, null).stream().map(DataSource::getId)
+                    .collect(toSet());
         }
     }
 
@@ -498,11 +502,11 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
      * AccessToken Resource
      */
     @Component
-    public static class AccessTokenList implements ResourceAcquisitionAndPermissionCheck<Integer> {
+    public static class AccessTokenResourcePermissionCheck implements ResourceAcquisitionAndPermissionCheck<Integer> {
 
         private final AccessTokenMapper accessTokenMapper;
 
-        public AccessTokenList(AccessTokenMapper accessTokenMapper) {
+        public AccessTokenResourcePermissionCheck(AccessTokenMapper accessTokenMapper) {
             this.accessTokenMapper = accessTokenMapper;
         }
 
@@ -517,12 +521,12 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
         }
 
         @Override
-        public Set<Integer> listAuthorizedResource(int userId, Logger logger) {
-            return accessTokenMapper.listAuthorizedAccessToken(userId, null).stream().map(AccessToken::getId).collect(toSet());
+        public Set<Integer> listAuthorizedResourceIds(int userId, Logger logger) {
+            return accessTokenMapper.listAuthorizedAccessToken(userId, null).stream().map(AccessToken::getId)
+                    .collect(toSet());
         }
     }
 
-
     interface ResourceAcquisitionAndPermissionCheck<T> {
 
         /**
@@ -537,7 +541,7 @@ public class ResourcePermissionCheckServiceImpl implements ResourcePermissionChe
          * @param userId
          * @return
          */
-        Set<T> listAuthorizedResource(int userId, Logger logger);
+        Set<T> listAuthorizedResourceIds(int userId, Logger logger);
 
         /**
          * permission check
