@@ -17,7 +17,7 @@
 
 package org.apache.dolphinscheduler.api.python;
 
-import org.apache.dolphinscheduler.api.configuration.PythonGatewayConfiguration;
+import org.apache.dolphinscheduler.api.configuration.ApiConfig;
 import org.apache.dolphinscheduler.api.dto.EnvironmentDto;
 import org.apache.dolphinscheduler.api.dto.resources.ResourceComponent;
 import org.apache.dolphinscheduler.api.enums.Status;
@@ -34,6 +34,7 @@ import org.apache.dolphinscheduler.api.service.UsersService;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.enums.ComplementDependentMode;
+import org.apache.dolphinscheduler.common.enums.ExecutionOrder;
 import org.apache.dolphinscheduler.common.enums.FailureStrategy;
 import org.apache.dolphinscheduler.common.enums.Priority;
 import org.apache.dolphinscheduler.common.enums.ProcessExecutionTypeEnum;
@@ -49,7 +50,6 @@ import org.apache.dolphinscheduler.dao.entity.ProcessDefinition;
 import org.apache.dolphinscheduler.dao.entity.Project;
 import org.apache.dolphinscheduler.dao.entity.ProjectUser;
 import org.apache.dolphinscheduler.dao.entity.Queue;
-import org.apache.dolphinscheduler.dao.entity.Resource;
 import org.apache.dolphinscheduler.dao.entity.Schedule;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.Tenant;
@@ -60,12 +60,13 @@ import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.ProjectUserMapper;
 import org.apache.dolphinscheduler.dao.mapper.ScheduleMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskDefinitionMapper;
+import org.apache.dolphinscheduler.plugin.storage.api.StorageEntity;
 import org.apache.dolphinscheduler.spi.enums.ResourceType;
 
 import py4j.GatewayServer;
 import py4j.GatewayServer.GatewayServerBuilder;
 
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 
 import java.io.IOException;
@@ -79,14 +80,14 @@ import java.util.stream.Collectors;
 
 import javax.annotation.PostConstruct;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
 
 @Component
+@Slf4j
 public class PythonGateway {
-    private static final Logger logger = LoggerFactory.getLogger(PythonGateway.class);
 
     private static final FailureStrategy DEFAULT_FAILURE_STRATEGY = FailureStrategy.CONTINUE;
     private static final Priority DEFAULT_PRIORITY = Priority.MEDIUM;
@@ -94,7 +95,9 @@ public class PythonGateway {
 
     private static final TaskDependType DEFAULT_TASK_DEPEND_TYPE = TaskDependType.TASK_POST;
     private static final RunMode DEFAULT_RUN_MODE = RunMode.RUN_MODE_SERIAL;
+    private static final ExecutionOrder DEFAULT_EXECUTION_ORDER = ExecutionOrder.DESC_ORDER;
     private static final int DEFAULT_DRY_RUN = 0;
+    private static final int DEFAULT_TEST_FLAG = 0;
     private static final ComplementDependentMode COMPLEMENT_DEPENDENT_MODE = ComplementDependentMode.OFF_MODE;
     // We use admin user's user_id to skip some permission issue from python gateway service
     private static final int ADMIN_USER_ID = 1;
@@ -142,13 +145,14 @@ public class PythonGateway {
     private DataSourceMapper dataSourceMapper;
 
     @Autowired
-    private PythonGatewayConfiguration pythonGatewayConfiguration;
+    private ApiConfig apiConfig;
 
     @Autowired
     private ProjectUserMapper projectUserMapper;
 
     // TODO replace this user to build in admin user if we make sure build in one could not be change
     private final User dummyAdminUser = new User() {
+
         {
             setId(ADMIN_USER_ID);
             setUserName("dummyUser");
@@ -157,6 +161,7 @@ public class PythonGateway {
     };
 
     private final Queue queuePythonGateway = new Queue() {
+
         {
             setId(Integer.MAX_VALUE);
             setQueueName("queuePythonGateway");
@@ -173,7 +178,8 @@ public class PythonGateway {
         return taskDefinitionService.genTaskCodeList(genNum);
     }
 
-    public Map<String, Long> getCodeAndVersion(String projectName, String processDefinitionName, String taskName) throws CodeGenerateUtils.CodeGenerateException {
+    public Map<String, Long> getCodeAndVersion(String projectName, String processDefinitionName,
+                                               String taskName) throws CodeGenerateUtils.CodeGenerateException {
         Project project = projectMapper.queryByName(projectName);
         Map<String, Long> result = new HashMap<>();
         // project do not exists, mean task not exists too, so we should directly return init value
@@ -193,7 +199,8 @@ public class PythonGateway {
             return result;
         }
 
-        TaskDefinition taskDefinition = taskDefinitionMapper.queryByName(project.getCode(), processDefinition.getCode(), taskName);
+        TaskDefinition taskDefinition =
+                taskDefinitionMapper.queryByName(project.getCode(), processDefinition.getCode(), taskName);
         if (taskDefinition == null) {
             result.put("code", CodeGenerateUtils.getInstance().genCode());
             result.put("version", 0L);
@@ -262,15 +269,15 @@ public class PythonGateway {
                     ReleaseState.OFFLINE);
             processDefinitionService.updateProcessDefinition(user, projectCode, name,
                     processDefinitionCode, description, globalParams,
-                    null, timeout, user.getTenantCode(), taskRelationJson, taskDefinitionJson, otherParamsJson,
+                    null, timeout, taskRelationJson, taskDefinitionJson, otherParamsJson,
                     executionTypeEnum);
         } else {
             Map<String, Object> result = processDefinitionService.createProcessDefinition(user, projectCode, name,
                     description, globalParams,
-                    null, timeout, user.getTenantCode(), taskRelationJson, taskDefinitionJson, otherParamsJson,
+                    null, timeout, taskRelationJson, taskDefinitionJson, otherParamsJson,
                     executionTypeEnum);
             if (result.get(Constants.STATUS) != Status.SUCCESS) {
-                logger.error(result.get(Constants.MSG).toString());
+                log.error(result.get(Constants.MSG).toString());
                 throw new ServiceException(result.get(Constants.MSG).toString());
             }
             processDefinition = (ProcessDefinition) result.get(Constants.DATA_LIST);
@@ -283,7 +290,8 @@ public class PythonGateway {
                     warningType,
                     warningGroupId);
         }
-        processDefinitionService.releaseProcessDefinition(user, projectCode, processDefinitionCode, ReleaseState.getEnum(releaseState));
+        processDefinitionService.releaseProcessDefinition(user, projectCode, processDefinitionCode,
+                ReleaseState.getEnum(releaseState));
         return processDefinitionCode;
     }
 
@@ -305,7 +313,7 @@ public class PythonGateway {
         } else if (verifyStatus != Status.SUCCESS) {
             String msg =
                     "Verify workflow exists status is invalid, neither SUCCESS or WORKFLOW_NAME_EXIST.";
-            logger.error(msg);
+            log.error(msg);
             throw new RuntimeException(msg);
         }
 
@@ -342,14 +350,16 @@ public class PythonGateway {
                     ReleaseState.ONLINE);
             Map<String, Object> result = schedulerService.insertSchedule(user, projectCode, workflowCode,
                     schedule, WarningType.valueOf(warningType),
-                    warningGroupId, DEFAULT_FAILURE_STRATEGY, DEFAULT_PRIORITY, workerGroup, DEFAULT_ENVIRONMENT_CODE);
+                    warningGroupId, DEFAULT_FAILURE_STRATEGY, DEFAULT_PRIORITY, workerGroup, user.getTenantCode(),
+                    DEFAULT_ENVIRONMENT_CODE);
             scheduleId = (int) result.get("scheduleId");
         } else {
             scheduleId = scheduleObj.getId();
             processDefinitionService.releaseProcessDefinition(user, projectCode, workflowCode,
                     ReleaseState.OFFLINE);
             schedulerService.updateSchedule(user, projectCode, scheduleId, schedule, WarningType.valueOf(warningType),
-                    warningGroupId, DEFAULT_FAILURE_STRATEGY, DEFAULT_PRIORITY, workerGroup, DEFAULT_ENVIRONMENT_CODE);
+                    warningGroupId, DEFAULT_FAILURE_STRATEGY, DEFAULT_PRIORITY, workerGroup, user.getTenantCode(),
+                    DEFAULT_ENVIRONMENT_CODE);
         }
         if (onlineSchedule) {
             // set workflow online to make sure we can set schedule online
@@ -388,13 +398,17 @@ public class PythonGateway {
                 DEFAULT_RUN_MODE,
                 DEFAULT_PRIORITY,
                 workerGroup,
+                user.getTenantCode(),
                 DEFAULT_ENVIRONMENT_CODE,
                 timeout,
                 null,
                 null,
                 DEFAULT_DRY_RUN,
-                COMPLEMENT_DEPENDENT_MODE
-        );
+                DEFAULT_TEST_FLAG,
+                COMPLEMENT_DEPENDENT_MODE,
+                processDefinition.getVersion(),
+                false,
+                DEFAULT_EXECUTION_ORDER);
     }
 
     // side object
@@ -414,8 +428,8 @@ public class PythonGateway {
     }
 
     /*
-      Grant or create project. Create a new project if project do not exists, and grant the project
-      permission to user if project exists but without permission to this user.
+     * Grant or create project. Create a new project if project do not exists, and grant the project permission to user
+     * if project exists but without permission to this user.
      */
     public void createOrGrantProject(String userName, String name, String desc) {
         User user = usersService.queryUser(userName);
@@ -483,7 +497,8 @@ public class PythonGateway {
         return user;
     }
 
-    public User updateUser(String userName, String userPassword, String email, String phone, String tenantCode, String queue, int state) throws Exception {
+    public User updateUser(String userName, String userPassword, String email, String phone, String tenantCode,
+                           String queue, int state) throws Exception {
         return usersService.createUserIfNotExists(userName, userPassword, email, phone, tenantCode, queue, state);
     }
 
@@ -505,7 +520,7 @@ public class PythonGateway {
         List<DataSource> dataSourceList = dataSourceMapper.queryDataSourceByName(datasourceName);
         if (dataSourceList == null || dataSourceList.isEmpty()) {
             String msg = String.format("Can not find any datasource by name %s", datasourceName);
-            logger.error(msg);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
 
@@ -513,16 +528,16 @@ public class PythonGateway {
                 .filter(dataSource -> type == null || StringUtils.equalsIgnoreCase(dataSource.getType().name(), type))
                 .collect(Collectors.toList());
 
-        logger.info("Get the datasource list match the type are: {}", dataSourceListMatchType);
+        log.info("Get the datasource list match the type are: {}", dataSourceListMatchType);
         if (dataSourceListMatchType.size() > 1) {
             String msg = String.format("Get more than one datasource by name %s", datasourceName);
-            logger.error(msg);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
 
         return dataSourceListMatchType.stream().findFirst().orElseThrow(() -> {
             String msg = String.format("Can not find any datasource by name %s and type %s", datasourceName, type);
-            logger.error(msg);
+            log.error(msg);
             return new IllegalArgumentException(msg);
         });
     }
@@ -553,7 +568,7 @@ public class PythonGateway {
             result.put("code", processDefinition.getCode());
         } else {
             String msg = String.format("Can not find valid workflow by name %s", workflowName);
-            logger.error(msg);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
 
@@ -574,7 +589,7 @@ public class PythonGateway {
         Project project = projectMapper.queryByName(projectName);
         if (project == null) {
             String msg = String.format("Can not find valid project by name %s", projectName);
-            logger.error(msg);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
         long projectCode = project.getCode();
@@ -584,13 +599,14 @@ public class PythonGateway {
                 processDefinitionMapper.queryByDefineName(projectCode, workflowName);
         if (processDefinition == null) {
             String msg = String.format("Can not find valid workflow by name %s", workflowName);
-            logger.error(msg);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
         result.put("processDefinitionCode", processDefinition.getCode());
 
         if (taskName != null) {
-            TaskDefinition taskDefinition = taskDefinitionMapper.queryByName(projectCode, processDefinition.getCode(), taskName);
+            TaskDefinition taskDefinition =
+                    taskDefinitionMapper.queryByName(projectCode, processDefinition.getCode(), taskName);
             result.put("taskDefinitionCode", taskDefinition.getCode());
         }
         return result;
@@ -606,12 +622,15 @@ public class PythonGateway {
     public Map<String, Object> getResourcesFileInfo(String programType, String fullName) {
         Map<String, Object> result = new HashMap<>();
 
-        Result<Object> resources = resourceService.queryResourceByProgramType(dummyAdminUser, ResourceType.FILE, ProgramType.valueOf(programType));
+        Result<Object> resources = resourceService.queryResourceByProgramType(dummyAdminUser, ResourceType.FILE,
+                ProgramType.valueOf(programType));
         List<ResourceComponent> resourcesComponent = (List<ResourceComponent>) resources.getData();
-        List<ResourceComponent> namedResources = resourcesComponent.stream().filter(s -> fullName.equals(s.getFullName())).collect(Collectors.toList());
+        List<ResourceComponent> namedResources =
+                resourcesComponent.stream().filter(s -> fullName.equals(s.getFullName())).collect(Collectors.toList());
         if (CollectionUtils.isEmpty(namedResources)) {
-            String msg = String.format("Can not find valid resource by program type %s and name %s", programType, fullName);
-            logger.error(msg);
+            String msg =
+                    String.format("Can not find valid resource by program type %s and name %s", programType, fullName);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
 
@@ -631,23 +650,23 @@ public class PythonGateway {
 
         if (result.get("data") == null) {
             String msg = String.format("Can not find valid environment by name %s", environmentName);
-            logger.error(msg);
+            log.error(msg);
             throw new IllegalArgumentException(msg);
         }
         EnvironmentDto environmentDto = EnvironmentDto.class.cast(result.get("data"));
         return environmentDto.getCode();
     }
 
-
     /**
      * Get resource by given resource type and full name. It return map contain resource id, name.
      * Useful in Python API create task which need workflow information.
      *
      * @param userName user who query resource
      * @param fullName full name of the resource
+     * @return StorageEntity object which contains necessary information about resource
      */
-    public Resource queryResourcesFileInfo(String userName, String fullName) {
-        return resourceService.queryResourcesFileInfo(userName, fullName);
+    public StorageEntity queryResourcesFileInfo(String userName, String fullName) throws Exception {
+        return resourceService.queryFileStatus(userName, fullName);
     }
 
     public String getGatewayVersion() {
@@ -660,23 +679,24 @@ public class PythonGateway {
      *
      * @param userName user who create or update resource
      * @param fullName The fullname of resource.Includes path and suffix.
-     * @param description description of resource
      * @param resourceContent content of resource
+     * @return StorageEntity object which contains necessary information about resource
      */
-    public void createOrUpdateResource(
-            String userName, String fullName, String description, String resourceContent) {
-        resourceService.createOrUpdateResource(userName, fullName, description, resourceContent);
+    public StorageEntity createOrUpdateResource(String userName, String fullName,
+                                                String resourceContent) throws Exception {
+        return resourceService.createOrUpdateResource(userName, fullName, resourceContent);
     }
 
     @PostConstruct
     public void init() {
-        if (pythonGatewayConfiguration.isEnabled()) {
+        if (apiConfig.getPythonGateway().isEnabled()) {
             this.start();
         }
     }
 
     private void start() {
         try {
+            ApiConfig.PythonGatewayConfiguration pythonGatewayConfiguration = apiConfig.getPythonGateway();
             InetAddress gatewayHost = InetAddress.getByName(pythonGatewayConfiguration.getGatewayServerAddress());
             GatewayServerBuilder serverBuilder = new GatewayServer.GatewayServerBuilder()
                     .entryPoint(this)
@@ -689,10 +709,10 @@ public class PythonGateway {
             }
 
             GatewayServer.turnLoggingOn();
-            logger.info("PythonGatewayService started on: " + gatewayHost.toString());
+            log.info("PythonGatewayService started on: " + gatewayHost.toString());
             serverBuilder.build().start();
         } catch (UnknownHostException e) {
-            logger.error("exception occurred while constructing PythonGatewayService().", e);
+            log.error("exception occurred while constructing PythonGatewayService().", e);
         }
     }
 }
