@@ -17,9 +17,11 @@
 
 package org.apache.dolphinscheduler.api.service;
 
+import org.apache.dolphinscheduler.api.dto.workflowInstance.WorkflowExecuteResponse;
 import org.apache.dolphinscheduler.api.enums.ExecuteType;
 import org.apache.dolphinscheduler.common.enums.CommandType;
 import org.apache.dolphinscheduler.common.enums.ComplementDependentMode;
+import org.apache.dolphinscheduler.common.enums.ExecutionOrder;
 import org.apache.dolphinscheduler.common.enums.FailureStrategy;
 import org.apache.dolphinscheduler.common.enums.Priority;
 import org.apache.dolphinscheduler.common.enums.RunMode;
@@ -51,22 +53,28 @@ public interface ExecutorService {
      * @param warningGroupId notify group id
      * @param processInstancePriority process instance priority
      * @param workerGroup worker group name
+     * @param tenantCode tenant code
      * @param environmentCode environment code
      * @param runMode run mode
      * @param timeout timeout
      * @param startParams the global param values which pass to new process instance
      * @param expectedParallelismNumber the expected parallelism number when execute complement in parallel mode
+     * @param executionOrder the execution order when complementing data
      * @return execute process instance code
      */
     Map<String, Object> execProcessInstance(User loginUser, long projectCode,
                                             long processDefinitionCode, String cronTime, CommandType commandType,
                                             FailureStrategy failureStrategy, String startNodeList,
-                                            TaskDependType taskDependType, WarningType warningType, int warningGroupId,
+                                            TaskDependType taskDependType, WarningType warningType,
+                                            Integer warningGroupId,
                                             RunMode runMode,
-                                            Priority processInstancePriority, String workerGroup, Long environmentCode, Integer timeout,
+                                            Priority processInstancePriority, String workerGroup, String tenantCode,
+                                            Long environmentCode,
+                                            Integer timeout,
                                             Map<String, String> startParams, Integer expectedParallelismNumber,
-                                            int dryRun,
-                                            ComplementDependentMode complementDependentMode);
+                                            int dryRun, int testFlag,
+                                            ComplementDependentMode complementDependentMode, Integer version,
+                                            boolean allLevelDependent, ExecutionOrder executionOrder);
 
     /**
      * check whether the process definition can be executed
@@ -74,10 +82,10 @@ public interface ExecutorService {
      * @param projectCode project code
      * @param processDefinition process definition
      * @param processDefineCode process definition code
-     * @param verison process definition version
-     * @return check result code
+     * @param version process definition version
      */
-    Map<String, Object> checkProcessDefinitionValid(long projectCode, ProcessDefinition processDefinition, long processDefineCode, Integer verison);
+    void checkProcessDefinitionValid(long projectCode, ProcessDefinition processDefinition, long processDefineCode,
+                                     Integer version);
 
     /**
      * do action to process instance：pause, stop, repeat, recover from pause, recover from stop
@@ -90,6 +98,30 @@ public interface ExecutorService {
      */
     Map<String, Object> execute(User loginUser, long projectCode, Integer processInstanceId, ExecuteType executeType);
 
+    /**
+     * do action to execute task in process instance
+     *
+     * @param loginUser login user
+     * @param projectCode project code
+     * @param processInstanceId process instance id
+     * @param startNodeList start node list
+     * @param taskDependType task depend type
+     * @return execute result code
+     */
+    WorkflowExecuteResponse executeTask(User loginUser, long projectCode, Integer processInstanceId,
+                                        String startNodeList,
+                                        TaskDependType taskDependType);
+
+    /**
+     * do action to process instance：pause, stop, repeat, recover from pause, recover from stop
+     *
+     * @param loginUser login user
+     * @param workflowInstanceId workflow instance id
+     * @param executeType execute type
+     * @return execute result code
+     */
+    Map<String, Object> execute(User loginUser, Integer workflowInstanceId, ExecuteType executeType);
+
     /**
      * check if sub processes are offline before starting process definition
      *
@@ -127,14 +159,17 @@ public interface ExecutorService {
      * @param projectCode project code
      * @param warningGroupId notify group id
      * @param workerGroup worker group name
+     * @param tenantCode tenant code
      * @param environmentCode environment code
      * @param startParams the global param values which pass to new process instance
      * @return execute process instance code
      */
     Map<String, Object> execStreamTaskInstance(User loginUser, long projectCode,
-                                            long taskDefinitionCode, int taskDefinitionVersion,
-                                            int warningGroupId,
-                                            String workerGroup, Long environmentCode,
-                                            Map<String, String> startParams,
-                                            int dryRun);
+                                               long taskDefinitionCode, int taskDefinitionVersion,
+                                               int warningGroupId,
+                                               String workerGroup,
+                                               String tenantCode,
+                                               Long environmentCode,
+                                               Map<String, String> startParams,
+                                               int dryRun);
 }
