@@ -17,6 +17,11 @@
 
 package org.apache.dolphinscheduler.api.service.impl;
 
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_GROUP_CREATE;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_GROUP_DELETE;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_GROUP_UPDATE;
+import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.ALERT_GROUP_VIEW;
+
 import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.service.AlertGroupService;
 import org.apache.dolphinscheduler.api.utils.PageInfo;
@@ -38,8 +43,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.dao.DuplicateKeyException;
 import org.springframework.stereotype.Service;
@@ -48,16 +53,13 @@ import org.springframework.transaction.annotation.Transactional;
 import com.baomidou.mybatisplus.core.metadata.IPage;
 import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
 
-import static org.apache.dolphinscheduler.api.constants.ApiFuncIdentificationConstant.*;
-
 /**
  * alert group service impl
  */
 @Service
+@Slf4j
 public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroupService {
 
-    private Logger logger = LoggerFactory.getLogger(AlertGroupServiceImpl.class);
-
     @Autowired
     private AlertGroupMapper alertGroupMapper;
 
@@ -74,7 +76,8 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
         if (loginUser.getUserType().equals(UserType.ADMIN_USER)) {
             alertGroups = alertGroupMapper.queryAllGroupList();
         } else {
-            Set<Integer> ids = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.ALERT_GROUP, loginUser.getId(), logger);
+            Set<Integer> ids = resourcePermissionCheckService
+                    .userOwnedResourceIdsAcquisition(AuthorizationType.ALERT_GROUP, loginUser.getId(), log);
             if (ids.isEmpty()) {
                 result.put(Constants.DATA_LIST, Collections.emptyList());
                 putMsg(result, Status.SUCCESS);
@@ -99,12 +102,12 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
         Map<String, Object> result = new HashMap<>();
         result.put(Constants.STATUS, false);
 
-        //only admin can operate
-        if (!canOperatorPermissions(loginUser,new Object[]{id}, AuthorizationType.ALERT_GROUP,ALERT_GROUP_VIEW)) {
+        // only admin can operate
+        if (!canOperatorPermissions(loginUser, new Object[]{id}, AuthorizationType.ALERT_GROUP, ALERT_GROUP_VIEW)) {
             putMsg(result, Status.USER_NO_OPERATION_PERM);
             return result;
         }
-        //check if exist
+        // check if exist
         AlertGroup alertGroup = alertGroupMapper.selectById(id);
         if (alertGroup == null) {
             putMsg(result, Status.ALERT_GROUP_NOT_EXIST);
@@ -134,7 +137,8 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
         if (loginUser.getUserType().equals(UserType.ADMIN_USER)) {
             alertGroupPage = alertGroupMapper.queryAlertGroupPage(page, searchVal);
         } else {
-            Set<Integer> ids = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.ALERT_GROUP, loginUser.getId(), logger);
+            Set<Integer> ids = resourcePermissionCheckService
+                    .userOwnedResourceIdsAcquisition(AuthorizationType.ALERT_GROUP, loginUser.getId(), log);
             if (ids.isEmpty()) {
                 result.setData(pageInfo);
                 putMsg(result, Status.SUCCESS);
@@ -161,14 +165,16 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
      */
     @Override
     @Transactional
-    public Map<String, Object> createAlertgroup(User loginUser, String groupName, String desc, String alertInstanceIds) {
+    public Map<String, Object> createAlertgroup(User loginUser, String groupName, String desc,
+                                                String alertInstanceIds) {
         Map<String, Object> result = new HashMap<>();
-        //only admin can operate
-        if (!canOperatorPermissions(loginUser,null, AuthorizationType.ALERT_GROUP, ALERT_GROUP_CREATE)) {
+        // only admin can operate
+        if (!canOperatorPermissions(loginUser, null, AuthorizationType.ALERT_GROUP, ALERT_GROUP_CREATE)) {
             putMsg(result, Status.USER_NO_OPERATION_PERM);
             return result;
         }
-        if(checkDescriptionLength(desc)){
+        if (checkDescriptionLength(desc)) {
+            log.warn("Parameter description is too long.");
             putMsg(result, Status.DESCRIPTION_TOO_LONG_ERROR);
             return result;
         }
@@ -188,12 +194,15 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
             if (insert > 0) {
                 result.put(Constants.DATA_LIST, alertGroup);
                 putMsg(result, Status.SUCCESS);
-                permissionPostHandle(AuthorizationType.ALERT_GROUP, loginUser.getId(), Collections.singletonList(alertGroup.getId()), logger);
+                permissionPostHandle(AuthorizationType.ALERT_GROUP, loginUser.getId(),
+                        Collections.singletonList(alertGroup.getId()), log);
+                log.info("Create alert group complete, groupName:{}", alertGroup.getGroupName());
             } else {
+                log.error("Create alert group error, groupName:{}", alertGroup.getGroupName());
                 putMsg(result, Status.CREATE_ALERT_GROUP_ERROR);
             }
         } catch (DuplicateKeyException ex) {
-            logger.error("Create alert group error.", ex);
+            log.error("Create alert group error, groupName:{}", alertGroup.getGroupName(), ex);
             putMsg(result, Status.ALERT_GROUP_EXIST);
         }
 
@@ -211,20 +220,23 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
      * @return update result code
      */
     @Override
-    public Map<String, Object> updateAlertgroup(User loginUser, int id, String groupName, String desc, String alertInstanceIds) {
+    public Map<String, Object> updateAlertgroup(User loginUser, int id, String groupName, String desc,
+                                                String alertInstanceIds) {
         Map<String, Object> result = new HashMap<>();
 
-        if (!canOperatorPermissions(loginUser, new Object[]{id},AuthorizationType.ALERT_GROUP,ALERT_GROUP_UPDATE)) {
+        if (!canOperatorPermissions(loginUser, new Object[]{id}, AuthorizationType.ALERT_GROUP, ALERT_GROUP_UPDATE)) {
             putMsg(result, Status.USER_NO_OPERATION_PERM);
             return result;
         }
-        if(checkDescriptionLength(desc)){
+        if (checkDescriptionLength(desc)) {
+            log.warn("Parameter description is too long.");
             putMsg(result, Status.DESCRIPTION_TOO_LONG_ERROR);
             return result;
         }
         AlertGroup alertGroup = alertGroupMapper.selectById(id);
 
         if (alertGroup == null) {
+            log.error("Alert group does not exist, id:{}.", id);
             putMsg(result, Status.ALERT_GROUP_NOT_EXIST);
             return result;
 
@@ -241,9 +253,10 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
         alertGroup.setAlertInstanceIds(alertInstanceIds);
         try {
             alertGroupMapper.updateById(alertGroup);
+            log.info("Update alert group complete, groupName:{}", alertGroup.getGroupName());
             putMsg(result, Status.SUCCESS);
         } catch (DuplicateKeyException ex) {
-            logger.error("Update alert group error.", ex);
+            log.error("Update alert group error, groupName:{}", alertGroup.getGroupName(), ex);
             putMsg(result, Status.ALERT_GROUP_EXIST);
         }
         return result;
@@ -262,26 +275,29 @@ public class AlertGroupServiceImpl extends BaseServiceImpl implements AlertGroup
         Map<String, Object> result = new HashMap<>();
         result.put(Constants.STATUS, false);
 
-        //only admin can operate
-        if (!canOperatorPermissions(loginUser,new Object[]{id}, AuthorizationType.ALERT_GROUP,ALERT_GROUP_DELETE)) {
+        // only admin can operate
+        if (!canOperatorPermissions(loginUser, new Object[]{id}, AuthorizationType.ALERT_GROUP, ALERT_GROUP_DELETE)) {
             putMsg(result, Status.USER_NO_OPERATION_PERM);
             return result;
         }
 
         // Not allow to delete the default alarm group ,because the module of service need to use it.
         if (id == 1) {
+            log.warn("Not allow to delete the default alarm group.");
             putMsg(result, Status.NOT_ALLOW_TO_DELETE_DEFAULT_ALARM_GROUP);
             return result;
         }
 
-        //check exist
+        // check exist
         AlertGroup alertGroup = alertGroupMapper.selectById(id);
         if (alertGroup == null) {
+            log.error("Alert group does not exist, id:{}.", id);
             putMsg(result, Status.ALERT_GROUP_NOT_EXIST);
             return result;
         }
 
         alertGroupMapper.deleteById(id);
+        log.info("Delete alert group complete, groupId:{}", id);
         putMsg(result, Status.SUCCESS);
         return result;
     }
