@@ -17,27 +17,50 @@
 
 package org.apache.dolphinscheduler.api.service.impl;
 
-import org.apache.commons.lang.StringUtils;
 import org.apache.dolphinscheduler.api.enums.Status;
+import org.apache.dolphinscheduler.api.exceptions.ServiceException;
+import org.apache.dolphinscheduler.api.permission.ResourcePermissionCheckService;
 import org.apache.dolphinscheduler.api.service.BaseService;
 import org.apache.dolphinscheduler.api.utils.Result;
-import org.apache.dolphinscheduler.common.Constants;
+import org.apache.dolphinscheduler.common.constants.Constants;
+import org.apache.dolphinscheduler.common.enums.AuthorizationType;
 import org.apache.dolphinscheduler.common.enums.UserType;
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.dao.entity.User;
 
-import java.io.IOException;
+import org.apache.commons.lang3.StringUtils;
+
 import java.text.MessageFormat;
 import java.util.Date;
-import java.util.HashMap;
+import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
+import lombok.extern.slf4j.Slf4j;
+
+import org.slf4j.Logger;
+import org.springframework.beans.factory.annotation.Autowired;
+
 /**
  * base service impl
  */
+@Slf4j
 public class BaseServiceImpl implements BaseService {
 
+    @Autowired
+    protected ResourcePermissionCheckService resourcePermissionCheckService;
+
+    @Override
+    public void permissionPostHandle(AuthorizationType authorizationType, Integer userId, List<Integer> ids,
+                                     Logger logger) {
+        try {
+            resourcePermissionCheckService.postHandle(authorizationType, userId, ids, logger);
+        } catch (Exception e) {
+            log.error("Post handle error, userId:{}.", userId, e);
+            throw new RuntimeException("Resource association user error", e);
+        }
+    }
+
     /**
      * check admin
      *
@@ -58,7 +81,7 @@ public class BaseServiceImpl implements BaseService {
      */
     @Override
     public boolean isNotAdmin(User loginUser, Map<String, Object> result) {
-        //only admin can operate
+        // only admin can operate
         if (!isAdmin(loginUser)) {
             putMsg(result, Status.USER_NO_OPERATION_PERM);
             return true;
@@ -125,14 +148,14 @@ public class BaseServiceImpl implements BaseService {
      * @param tenantCode tenant code
      * @throws IOException if hdfs operation exception
      */
-//    @Override
-//    public void createTenantDirIfNotExists(String tenantCode) throws IOException {
-//        String resourcePath = HadoopUtils.getHdfsResDir(tenantCode);
-//        String udfsPath = HadoopUtils.getHdfsUdfDir(tenantCode);
-//        // init resource path and udf path
-//        HadoopUtils.getInstance().mkdir(tenantCode,resourcePath);
-//        HadoopUtils.getInstance().mkdir(tenantCode,udfsPath);
-//    }
+    // @Override
+    // public void createTenantDirIfNotExists(String tenantCode) throws IOException {
+    // String resourcePath = HadoopUtils.getHdfsResDir(tenantCode);
+    // String udfsPath = HadoopUtils.getHdfsUdfDir(tenantCode);
+    // // init resource path and udf path
+    // HadoopUtils.getInstance().mkdir(tenantCode,resourcePath);
+    // HadoopUtils.getInstance().mkdir(tenantCode,udfsPath);
+    // }
 
     /**
      * Verify that the operator has permissions
@@ -146,37 +169,39 @@ public class BaseServiceImpl implements BaseService {
     }
 
     /**
-     * check and parse date parameters
-     *
-     * @param startDateStr start date string
-     * @param endDateStr end date string
-     * @return map<status,startDate,endDate>
+     * Verify that the operator has permissions
+     * @param user operate user
+     * @param ids Object[]
+     * @param type AuthorizationType
+     * @return boolean
      */
     @Override
-    public Map<String, Object> checkAndParseDateParameters(String startDateStr, String endDateStr) {
-        Map<String, Object> result = new HashMap<>();
-        Date start = null;
-        if (!StringUtils.isEmpty(startDateStr)) {
-            start = DateUtils.getScheduleDate(startDateStr);
-            if (Objects.isNull(start)) {
-                putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.START_END_DATE);
-                return result;
-            }
-        }
-        result.put(Constants.START_TIME, start);
-
-        Date end = null;
-        if (!StringUtils.isEmpty(endDateStr)) {
-            end = DateUtils.getScheduleDate(endDateStr);
-            if (Objects.isNull(end)) {
-                putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.START_END_DATE);
-                return result;
-            }
-        }
-        result.put(Constants.END_TIME, end);
-
-        putMsg(result, Status.SUCCESS);
-        return result;
+    public boolean canOperatorPermissions(User user, Object[] ids, AuthorizationType type, String permissionKey) {
+        boolean operationPermissionCheck =
+                resourcePermissionCheckService.operationPermissionCheck(type, user.getId(), permissionKey, log);
+        boolean resourcePermissionCheck = resourcePermissionCheckService.resourcePermissionCheck(type, ids,
+                user.getUserType().equals(UserType.ADMIN_USER) ? 0 : user.getId(), log);
+        return operationPermissionCheck && resourcePermissionCheck;
     }
 
+    /**
+     * check and parse date parameters
+     */
+    @Override
+    public Date checkAndParseDateParameters(String startDateStr) throws ServiceException {
+        Date start = null;
+        if (!StringUtils.isEmpty(startDateStr)) {
+            start = DateUtils.stringToDate(startDateStr);
+            if (Objects.isNull(start)) {
+                log.warn("Parameter startDateStr is invalid.");
+                throw new ServiceException(Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.START_END_DATE);
+            }
+        }
+        return start;
+    }
+
+    @Override
+    public boolean checkDescriptionLength(String description) {
+        return description != null && description.codePointCount(0, description.length()) > 255;
+    }
 }
