@@ -64,8 +64,8 @@ import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
@@ -80,10 +80,9 @@ import com.fasterxml.jackson.databind.ObjectMapper;
  * DqRuleServiceImpl
  */
 @Service
+@Slf4j
 public class DqRuleServiceImpl extends BaseServiceImpl implements DqRuleService {
 
-    private final Logger logger = LoggerFactory.getLogger(DqRuleServiceImpl.class);
-
     @Autowired
     private DqRuleMapper dqRuleMapper;
 
@@ -240,7 +239,7 @@ public class DqRuleServiceImpl extends BaseServiceImpl implements DqRuleService
         try {
             result = mapper.writeValueAsString(params);
         } catch (JsonProcessingException e) {
-            logger.error("json parse error : {}", e.getMessage(), e);
+            log.error("Json parse error.", e);
         }
 
         return result;
