@@ -29,10 +29,9 @@ import org.apache.dolphinscheduler.dao.entity.K8sNamespace;
 import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.ClusterMapper;
 import org.apache.dolphinscheduler.dao.mapper.K8sNamespaceMapper;
-import org.apache.dolphinscheduler.remote.exceptions.RemotingException;
 
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
-import org.apache.commons.collections.CollectionUtils;
 
 import java.util.ArrayList;
 import java.util.Date;
@@ -43,8 +42,8 @@ import java.util.Map;
 import java.util.Set;
 import java.util.stream.Collectors;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
@@ -55,10 +54,9 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
  * k8s namespace service impl
  */
 @Service
+@Slf4j
 public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNamespaceService {
 
-    private static final Logger logger = LoggerFactory.getLogger(K8SNamespaceServiceImpl.class);
-
     private static String resourceYaml = "apiVersion: v1\n"
             + "kind: ResourceQuota\n"
             + "metadata:\n"
@@ -91,6 +89,7 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
     public Result queryListPaging(User loginUser, String searchVal, Integer pageNo, Integer pageSize) {
         Result result = new Result();
         if (!isAdmin(loginUser)) {
+            log.warn("Only admin can query namespace list, current login user name:{}.", loginUser.getUserName());
             putMsg(result, Status.USER_NO_OPERATION_PERM);
             return result;
         }
@@ -124,36 +123,43 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
                                                   Integer limitsMemory) {
         Map<String, Object> result = new HashMap<>();
         if (isNotAdmin(loginUser, result)) {
+            log.warn("Only admin can create K8s namespace, current login user name:{}.", loginUser.getUserName());
             return result;
         }
 
         if (StringUtils.isEmpty(namespace)) {
+            log.warn("Parameter namespace is empty.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.NAMESPACE);
             return result;
         }
 
         if (clusterCode == null) {
+            log.warn("Parameter clusterCode is null.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.CLUSTER);
             return result;
         }
 
         if (limitsCpu != null && limitsCpu < 0.0) {
+            log.warn("Parameter limitsCpu is invalid.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.LIMITS_CPU);
             return result;
         }
 
         if (limitsMemory != null && limitsMemory < 0) {
+            log.warn("Parameter limitsMemory is invalid.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.LIMITS_MEMORY);
             return result;
         }
 
         if (checkNamespaceExistInDb(namespace, clusterCode)) {
+            log.warn("K8S namespace already exists.");
             putMsg(result, Status.K8S_NAMESPACE_EXIST, namespace, clusterCode);
             return result;
         }
 
         Cluster cluster = clusterMapper.queryByClusterCode(clusterCode);
         if (cluster == null) {
+            log.error("Cluster does not exist, clusterCode:{}", clusterCode);
             putMsg(result, Status.CLUSTER_NOT_EXISTS, namespace, clusterCode);
             return result;
         }
@@ -163,7 +169,7 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
             code = CodeGenerateUtils.getInstance().genCode();
             cluster.setCode(code);
         } catch (CodeGenerateUtils.CodeGenerateException e) {
-            logger.error("Cluster code get error, ", e);
+            log.error("Generate cluster code error.", e);
         }
         if (code == 0L) {
             putMsg(result, Status.INTERNAL_SERVER_ERROR_ARGS, "Error generating cluster code");
@@ -190,13 +196,14 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
                 String yamlStr = genDefaultResourceYaml(k8sNamespaceObj);
                 k8sClientService.upsertNamespaceAndResourceToK8s(k8sNamespaceObj, yamlStr);
             } catch (Exception e) {
-                logger.error("namespace create to k8s error", e);
+                log.error("Namespace create to k8s error", e);
                 putMsg(result, Status.K8S_CLIENT_OPS_ERROR, e.getMessage());
                 return result;
             }
         }
 
         k8sNamespaceMapper.insert(k8sNamespaceObj);
+        log.info("K8s namespace create complete, namespace:{}.", k8sNamespaceObj.getNamespace());
         putMsg(result, Status.SUCCESS);
 
         return result;
@@ -216,21 +223,25 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
                                                   Integer limitsMemory) {
         Map<String, Object> result = new HashMap<>();
         if (isNotAdmin(loginUser, result)) {
+            log.warn("Only admin can update K8s namespace, current login user name:{}.", loginUser.getUserName());
             return result;
         }
 
         if (limitsCpu != null && limitsCpu < 0.0) {
+            log.warn("Parameter limitsCpu is invalid.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.LIMITS_CPU);
             return result;
         }
 
         if (limitsMemory != null && limitsMemory < 0) {
+            log.warn("Parameter limitsMemory is invalid.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.LIMITS_MEMORY);
             return result;
         }
 
         K8sNamespace k8sNamespaceObj = k8sNamespaceMapper.selectById(id);
         if (k8sNamespaceObj == null) {
+            log.error("K8s namespace does not exist, namespaceId:{}.", id);
             putMsg(result, Status.K8S_NAMESPACE_NOT_EXIST, id);
             return result;
         }
@@ -245,14 +256,14 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
                 String yamlStr = genDefaultResourceYaml(k8sNamespaceObj);
                 k8sClientService.upsertNamespaceAndResourceToK8s(k8sNamespaceObj, yamlStr);
             } catch (Exception e) {
-                logger.error("namespace update to k8s error", e);
+                log.error("Namespace update to k8s error", e);
                 putMsg(result, Status.K8S_CLIENT_OPS_ERROR, e.getMessage());
                 return result;
             }
         }
         // update to db
         k8sNamespaceMapper.updateById(k8sNamespaceObj);
-
+        log.info("K8s namespace update complete, namespace:{}.", k8sNamespaceObj.getNamespace());
         putMsg(result, Status.SUCCESS);
         return result;
     }
@@ -268,16 +279,19 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
     public Result<Object> verifyNamespaceK8s(String namespace, Long clusterCode) {
         Result<Object> result = new Result<>();
         if (StringUtils.isEmpty(namespace)) {
+            log.warn("Parameter namespace is empty.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.NAMESPACE);
             return result;
         }
 
         if (clusterCode == null) {
+            log.warn("Parameter clusterCode is null.");
             putMsg(result, Status.REQUEST_PARAMS_NOT_VALID_ERROR, Constants.CLUSTER);
             return result;
         }
 
         if (checkNamespaceExistInDb(namespace, clusterCode)) {
+            log.warn("K8S namespace already exists.");
             putMsg(result, Status.K8S_NAMESPACE_EXIST, namespace, clusterCode);
             return result;
         }
@@ -297,23 +311,19 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
     public Map<String, Object> deleteNamespaceById(User loginUser, int id) {
         Map<String, Object> result = new HashMap<>();
         if (isNotAdmin(loginUser, result)) {
+            log.warn("Only admin can delete K8s namespace, current login user name:{}.", loginUser.getUserName());
             return result;
         }
 
         K8sNamespace k8sNamespaceObj = k8sNamespaceMapper.selectById(id);
         if (k8sNamespaceObj == null) {
+            log.error("K8s namespace does not exist, namespaceId:{}.", id);
             putMsg(result, Status.K8S_NAMESPACE_NOT_EXIST, id);
             return result;
         }
-        if (!Constants.K8S_LOCAL_TEST_CLUSTER_CODE.equals(k8sNamespaceObj.getClusterCode())) {
-            try {
-                k8sClientService.deleteNamespaceToK8s(k8sNamespaceObj.getNamespace(), k8sNamespaceObj.getClusterCode());
-            } catch (RemotingException e) {
-                putMsg(result, Status.K8S_CLIENT_OPS_ERROR, id);
-                return result;
-            }
-        }
+
         k8sNamespaceMapper.deleteById(id);
+        log.info("K8s namespace delete complete, namespace:{}.", k8sNamespaceObj.getNamespace());
         putMsg(result, Status.SUCCESS);
         return result;
     }
@@ -377,7 +387,7 @@ public class K8SNamespaceServiceImpl extends BaseServiceImpl implements K8sNames
         if (loginUser.getId() != userId && isNotAdmin(loginUser, result)) {
             return result;
         }
-        // query all namespace list,this auth does not like project
+        // query all namespace list, this auth does not like project
         List<K8sNamespace> namespaceList = k8sNamespaceMapper.selectList(null);
         List<K8sNamespace> resultList = new ArrayList<>();
         Set<K8sNamespace> namespaceSet;
