@@ -28,13 +28,15 @@ import org.apache.dolphinscheduler.dao.entity.User;
 import org.apache.dolphinscheduler.dao.mapper.ProjectMapper;
 import org.apache.dolphinscheduler.dao.mapper.TaskGroupQueueMapper;
 
+import org.apache.commons.collections4.CollectionUtils;
+
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 
@@ -45,6 +47,7 @@ import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
  * task group queue service
  */
 @Service
+@Slf4j
 public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGroupQueueService {
 
     @Autowired
@@ -53,8 +56,6 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
     @Autowired
     private ProjectMapper projectMapper;
 
-    private static final Logger logger = LoggerFactory.getLogger(TaskGroupQueueServiceImpl.class);
-
     /**
      * query tasks in task group queue by group id
      *
@@ -65,20 +66,21 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
      * @return tasks list
      */
     @Override
-    public Map<String, Object> queryTasksByGroupId(User loginUser, String taskName
-        , String processName, Integer status, int groupId, int pageNo, int pageSize) {
+    public Map<String, Object> queryTasksByGroupId(User loginUser, String taskName, String processName, Integer status,
+                                                   int groupId, int pageNo, int pageSize) {
         Map<String, Object> result = new HashMap<>();
         Page<TaskGroupQueue> page = new Page<>(pageNo, pageSize);
         PageInfo<TaskGroupQueue> pageInfo = new PageInfo<>(pageNo, pageSize);
-        Set<Integer> projectIds = resourcePermissionCheckService.userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), logger);
+        Set<Integer> projectIds = resourcePermissionCheckService
+                .userOwnedResourceIdsAcquisition(AuthorizationType.PROJECTS, loginUser.getId(), log);
         if (projectIds.isEmpty()) {
             result.put(Constants.DATA_LIST, pageInfo);
             putMsg(result, Status.SUCCESS);
             return result;
         }
         List<Project> projects = projectMapper.selectBatchIds(projectIds);
-        IPage<TaskGroupQueue> taskGroupQueue = taskGroupQueueMapper.queryTaskGroupQueueByTaskGroupIdPaging(page, taskName
-            ,processName,status,groupId,projects);
+        IPage<TaskGroupQueue> taskGroupQueue = taskGroupQueueMapper.queryTaskGroupQueueByTaskGroupIdPaging(page,
+                taskName, processName, status, groupId, projects);
 
         pageInfo.setTotal((int) taskGroupQueue.getTotal());
         pageInfo.setTotalList(taskGroupQueue.getRecords());
@@ -99,7 +101,7 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
      */
     @Override
     public Map<String, Object> queryTasksByProcessId(User loginUser, int pageNo, int pageSize, int processId) {
-        return this.doQuery(loginUser, pageNo, pageSize,  processId);
+        return this.doQuery(loginUser, pageNo, pageSize, processId);
     }
 
     /**
@@ -112,7 +114,7 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
      */
     @Override
     public Map<String, Object> queryAllTasks(User loginUser, int pageNo, int pageSize) {
-        return this.doQuery(loginUser, pageNo, pageSize,  0);
+        return this.doQuery(loginUser, pageNo, pageSize, 0);
     }
 
     public Map<String, Object> doQuery(User loginUser, int pageNo, int pageSize,
@@ -145,12 +147,33 @@ public class TaskGroupQueueServiceImpl extends BaseServiceImpl implements TaskGr
     }
 
     @Override
-    public void forceStartTask(int queueId,int forceStart) {
-        taskGroupQueueMapper.updateForceStart(queueId,forceStart);
+    public void deleteByTaskInstanceIds(List<Integer> taskInstanceIds) {
+        if (CollectionUtils.isEmpty(taskInstanceIds)) {
+            return;
+        }
+        taskGroupQueueMapper.deleteByTaskInstanceIds(taskInstanceIds);
+    }
+
+    @Override
+    public void deleteByWorkflowInstanceId(Integer workflowInstanceId) {
+        taskGroupQueueMapper.deleteByWorkflowInstanceId(workflowInstanceId);
+    }
+
+    @Override
+    public void forceStartTask(int queueId, int forceStart) {
+        taskGroupQueueMapper.updateForceStart(queueId, forceStart);
     }
 
     @Override
     public void modifyPriority(Integer queueId, Integer priority) {
-        taskGroupQueueMapper.modifyPriority(queueId,priority);
+        taskGroupQueueMapper.modifyPriority(queueId, priority);
+    }
+
+    @Override
+    public void deleteByTaskGroupIds(List<Integer> taskGroupIds) {
+        if (CollectionUtils.isEmpty(taskGroupIds)) {
+            return;
+        }
+        taskGroupQueueMapper.deleteByTaskGroupIds(taskGroupIds);
     }
 }
