@@ -52,6 +52,8 @@ import java.util.Optional;
 import java.util.Set;
 import java.util.stream.Collectors;
 
+import lombok.extern.slf4j.Slf4j;
+
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Service;
 import org.springframework.util.CollectionUtils;
@@ -59,6 +61,7 @@ import org.springframework.util.CollectionUtils;
 /**
  * work flow lineage service impl
  */
+@Slf4j
 @Service
 public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkFlowLineageService {
 
@@ -79,10 +82,12 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
         Map<String, Object> result = new HashMap<>();
         Project project = projectMapper.queryByCode(projectCode);
         if (project == null) {
+            log.error("Project does not exist, projectCode:{}.", projectCode);
             putMsg(result, Status.PROJECT_NOT_FOUND, projectCode);
             return result;
         }
-        List<WorkFlowLineage> workFlowLineageList = workFlowLineageMapper.queryWorkFlowLineageByName(projectCode, workFlowName);
+        List<WorkFlowLineage> workFlowLineageList =
+                workFlowLineageMapper.queryWorkFlowLineageByName(projectCode, workFlowName);
         result.put(Constants.DATA_LIST, workFlowLineageList);
         putMsg(result, Status.SUCCESS);
         return result;
@@ -93,6 +98,7 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
         Map<String, Object> result = new HashMap<>();
         Project project = projectMapper.queryByCode(projectCode);
         if (project == null) {
+            log.error("Project does not exist, projectCode:{}.", projectCode);
             putMsg(result, Status.PROJECT_NOT_FOUND, projectCode);
             return result;
         }
@@ -111,23 +117,26 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
                                    long sourceWorkFlowCode,
                                    List<WorkFlowLineage> workFlowLineages,
                                    Set<WorkFlowRelation> workFlowRelations) {
-        workFlowLineages.add(workFlowLineageMapper.queryWorkFlowLineageByCode(projectCode,sourceWorkFlowCode));
+        workFlowLineages.add(workFlowLineageMapper.queryWorkFlowLineageByCode(projectCode, sourceWorkFlowCode));
 
         List<WorkFlowLineage> downStreamWorkFlowLineages =
                 workFlowLineageMapper.queryDownstreamLineageByProcessDefinitionCode(sourceWorkFlowCode, "DEPENDENT");
         workFlowLineages.addAll(downStreamWorkFlowLineages);
-        downStreamWorkFlowLineages.forEach(workFlowLineage -> workFlowRelations.add(new WorkFlowRelation(sourceWorkFlowCode, workFlowLineage.getWorkFlowCode())));
+        downStreamWorkFlowLineages.forEach(workFlowLineage -> workFlowRelations
+                .add(new WorkFlowRelation(sourceWorkFlowCode, workFlowLineage.getWorkFlowCode())));
 
         List<WorkFlowLineage> upstreamWorkFlowLineages = new ArrayList<>();
         getUpstreamLineages(sourceWorkFlowCode, upstreamWorkFlowLineages);
         workFlowLineages.addAll(upstreamWorkFlowLineages);
-        upstreamWorkFlowLineages.forEach(workFlowLineage -> workFlowRelations.add(new WorkFlowRelation(workFlowLineage.getWorkFlowCode(), sourceWorkFlowCode)));
+        upstreamWorkFlowLineages.forEach(workFlowLineage -> workFlowRelations
+                .add(new WorkFlowRelation(workFlowLineage.getWorkFlowCode(), sourceWorkFlowCode)));
     }
 
     private void getUpstreamLineages(long sourceWorkFlowCode,
                                      List<WorkFlowLineage> upstreamWorkFlowLineages) {
         List<DependentProcessDefinition> workFlowDependentDefinitionList =
-                workFlowLineageMapper.queryUpstreamDependentParamsByProcessDefinitionCode(sourceWorkFlowCode, "DEPENDENT");
+                workFlowLineageMapper.queryUpstreamDependentParamsByProcessDefinitionCode(sourceWorkFlowCode,
+                        "DEPENDENT");
 
         List<Long> upstreamProcessDefinitionCodes = new ArrayList<>();
 
@@ -146,7 +155,8 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
     private void getProcessDefinitionCodeByDependentDefinitionList(List<DependentProcessDefinition> dependentDefinitionList,
                                                                    List<Long> processDefinitionCodes) {
         for (DependentProcessDefinition dependentProcessDefinition : dependentDefinitionList) {
-            for (DependentTaskModel dependentTaskModel : dependentProcessDefinition.getDependentParameters().getDependTaskList()) {
+            for (DependentTaskModel dependentTaskModel : dependentProcessDefinition.getDependentParameters()
+                    .getDependTaskList()) {
                 for (DependentItem dependentItem : dependentTaskModel.getDependItemList()) {
                     if (!processDefinitionCodes.contains(dependentItem.getDefinitionCode())) {
                         processDefinitionCodes.add(dependentItem.getDefinitionCode());
@@ -161,6 +171,7 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
         Map<String, Object> result = new HashMap<>();
         Project project = projectMapper.queryByCode(projectCode);
         if (project == null) {
+            log.error("Project does not exist, projectCode:{}.", projectCode);
             putMsg(result, Status.PROJECT_NOT_FOUND, projectCode);
             return result;
         }
@@ -168,8 +179,10 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
         Map<Long, WorkFlowLineage> workFlowLineagesMap = new HashMap<>();
         Set<WorkFlowRelation> workFlowRelations = new HashSet<>();
         if (!processLineages.isEmpty()) {
-            List<WorkFlowLineage> workFlowLineages = workFlowLineageMapper.queryWorkFlowLineageByLineage(processLineages);
-            workFlowLineagesMap = workFlowLineages.stream().collect(Collectors.toMap(WorkFlowLineage::getWorkFlowCode, workFlowLineage -> workFlowLineage));
+            List<WorkFlowLineage> workFlowLineages =
+                    workFlowLineageMapper.queryWorkFlowLineageByLineage(processLineages);
+            workFlowLineagesMap = workFlowLineages.stream()
+                    .collect(Collectors.toMap(WorkFlowLineage::getWorkFlowCode, workFlowLineage -> workFlowLineage));
             Map<Long, List<TaskDefinition>> workFlowMap = new HashMap<>();
             for (ProcessLineage processLineage : processLineages) {
                 workFlowMap.compute(processLineage.getProcessDefinitionCode(), (k, v) -> {
@@ -180,18 +193,22 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
                         v.add(new TaskDefinition(processLineage.getPreTaskCode(), processLineage.getPreTaskVersion()));
                     }
                     if (processLineage.getPostTaskCode() > 0) {
-                        v.add(new TaskDefinition(processLineage.getPostTaskCode(), processLineage.getPostTaskVersion()));
+                        v.add(new TaskDefinition(processLineage.getPostTaskCode(),
+                                processLineage.getPostTaskVersion()));
                     }
                     return v;
                 });
             }
             for (Entry<Long, List<TaskDefinition>> workFlow : workFlowMap.entrySet()) {
-                Set<Long> sourceWorkFlowCodes = querySourceWorkFlowCodes(projectCode, workFlow.getKey(), workFlow.getValue());
+                Set<Long> sourceWorkFlowCodes =
+                        querySourceWorkFlowCodes(projectCode, workFlow.getKey(), workFlow.getValue());
                 if (sourceWorkFlowCodes.isEmpty()) {
                     workFlowRelations.add(new WorkFlowRelation(0L, workFlow.getKey()));
                 } else {
-                    workFlowLineagesMap.get(workFlow.getKey()).setSourceWorkFlowCode(StringUtils.join(sourceWorkFlowCodes, Constants.COMMA));
-                    sourceWorkFlowCodes.forEach(code -> workFlowRelations.add(new WorkFlowRelation(code, workFlow.getKey())));
+                    workFlowLineagesMap.get(workFlow.getKey())
+                            .setSourceWorkFlowCode(StringUtils.join(sourceWorkFlowCodes, Constants.COMMA));
+                    sourceWorkFlowCodes
+                            .forEach(code -> workFlowRelations.add(new WorkFlowRelation(code, workFlow.getKey())));
                 }
             }
         }
@@ -203,7 +220,8 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
         return result;
     }
 
-    private Set<Long> querySourceWorkFlowCodes(long projectCode, long workFlowCode, List<TaskDefinition> taskDefinitionList) {
+    private Set<Long> querySourceWorkFlowCodes(long projectCode, long workFlowCode,
+                                               List<TaskDefinition> taskDefinitionList) {
         Set<Long> sourceWorkFlowCodes = new HashSet<>();
         if (taskDefinitionList == null || taskDefinitionList.isEmpty()) {
             return sourceWorkFlowCodes;
@@ -212,14 +230,17 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
         for (TaskDefinitionLog taskDefinitionLog : taskDefinitionLogs) {
             if (taskDefinitionLog.getProjectCode() == projectCode) {
                 if (taskDefinitionLog.getTaskType().equals(TASK_TYPE_DEPENDENT)) {
-                    DependentParameters dependentParameters = JSONUtils.parseObject(taskDefinitionLog.getDependence(), DependentParameters.class);
+                    DependentParameters dependentParameters =
+                            JSONUtils.parseObject(taskDefinitionLog.getDependence(), DependentParameters.class);
                     if (dependentParameters != null) {
-                        List<DependentTaskModel> dependTaskList = dependentParameters.getDependTaskList();
+                        List<DependentTaskModel> dependTaskList =
+                                dependentParameters.getDependTaskList();
                         if (!CollectionUtils.isEmpty(dependTaskList)) {
                             for (DependentTaskModel taskModel : dependTaskList) {
                                 List<DependentItem> dependItemList = taskModel.getDependItemList();
                                 for (DependentItem dependentItem : dependItemList) {
-                                    if (dependentItem.getProjectCode() == projectCode && dependentItem.getDefinitionCode() != workFlowCode) {
+                                    if (dependentItem.getProjectCode() == projectCode
+                                            && dependentItem.getDefinitionCode() != workFlowCode) {
                                         sourceWorkFlowCodes.add(dependentItem.getDefinitionCode());
                                     }
                                 }
@@ -242,14 +263,18 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
      */
     @Override
     public Optional<String> taskDepOnTaskMsg(long projectCode, long processDefinitionCode, long taskCode) {
-        List<TaskMainInfo> tasksDep = workFlowLineageMapper.queryTaskDepOnTask(projectCode, processDefinitionCode, taskCode);
+        List<TaskMainInfo> tasksDep =
+                workFlowLineageMapper.queryTaskDepOnTask(projectCode, processDefinitionCode, taskCode);
         if (CollectionUtils.isEmpty(tasksDep)) {
             return Optional.empty();
         }
 
-        String taskDepStr = tasksDep.stream().map(task -> String.format(Constants.FORMAT_S_S_COLON, task.getProcessDefinitionName(), task.getTaskName())).collect(Collectors.joining(Constants.COMMA));
+        String taskDepStr = tasksDep.stream().map(
+                task -> String.format(Constants.FORMAT_S_S_COLON, task.getProcessDefinitionName(), task.getTaskName()))
+                .collect(Collectors.joining(Constants.COMMA));
         TaskDefinition taskDefinition = taskDefinitionMapper.queryByCode(taskCode);
-        return Optional.of(MessageFormat.format(Status.DELETE_TASK_USE_BY_OTHER_FAIL.getMsg(), taskDefinition.getName(), taskDepStr));
+        return Optional.of(MessageFormat.format(Status.DELETE_TASK_USE_BY_OTHER_FAIL.getMsg(), taskDefinition.getName(),
+                taskDepStr));
     }
 
     /**
@@ -262,8 +287,10 @@ public class WorkFlowLineageServiceImpl extends BaseServiceImpl implements WorkF
     @Override
     public Set<TaskMainInfo> queryTaskDepOnProcess(long projectCode, long processDefinitionCode) {
         Set<TaskMainInfo> taskMainInfos = new HashSet<>();
-        List<TaskMainInfo> taskDependents = workFlowLineageMapper.queryTaskDependentDepOnProcess(projectCode, processDefinitionCode);
-        List<TaskMainInfo> taskSubProcess = workFlowLineageMapper.queryTaskSubProcessDepOnProcess(projectCode, processDefinitionCode);
+        List<TaskMainInfo> taskDependents =
+                workFlowLineageMapper.queryTaskDependentDepOnProcess(projectCode, processDefinitionCode);
+        List<TaskMainInfo> taskSubProcess =
+                workFlowLineageMapper.queryTaskSubProcessDepOnProcess(projectCode, processDefinitionCode);
         taskMainInfos.addAll(taskDependents);
         taskMainInfos.addAll(taskSubProcess);
         return taskMainInfos;
