@@ -125,11 +125,21 @@ public class ScheduleVo {
      */
     private String workerGroup;
 
+    /**
+     * tenantCode
+     */
+    private String tenantCode;
+
     /**
      * environment code
      */
     private Long environmentCode;
 
+    /**
+     * environment name
+     */
+    private String environmentName;
+
     public ScheduleVo(Schedule schedule) {
         this.setId(schedule.getId());
         this.setCrontab(schedule.getCrontab());
@@ -150,5 +160,7 @@ public class ScheduleVo {
         this.setEnvironmentCode(schedule.getEnvironmentCode());
         this.setStartTime(DateUtils.dateToString(schedule.getStartTime(), ZoneId.systemDefault().getId()));
         this.setEndTime(DateUtils.dateToString(schedule.getEndTime(), ZoneId.systemDefault().getId()));
+        this.setEnvironmentName(schedule.getEnvironmentName());
+        this.setTenantCode(schedule.getTenantCode());
     }
 }
