@@ -25,8 +25,8 @@ import org.apache.dolphinscheduler.api.enums.Status;
 import org.apache.dolphinscheduler.api.utils.Result;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import org.springframework.http.MediaType;
@@ -36,22 +36,23 @@ import org.springframework.test.web.servlet.MvcResult;
  * monitor controller test
  */
 public class MonitorControllerTest extends AbstractControllerTest {
+
     private static final Logger logger = LoggerFactory.getLogger(MonitorControllerTest.class);
 
     @Test
     public void testListMaster() throws Exception {
 
         MvcResult mvcResult = mockMvc.perform(get("/monitor/masters")
-            .header(SESSION_ID, sessionId)
-           /* .param("type", ResourceType.FILE.name())*/)
-            .andExpect(status().isOk())
-            .andExpect(content().contentType(MediaType.APPLICATION_JSON))
-            .andReturn();
+                .header(SESSION_ID, sessionId)
+        /* .param("type", ResourceType.FILE.name()) */)
+                .andExpect(status().isOk())
+                .andExpect(content().contentType(MediaType.APPLICATION_JSON))
+                .andReturn();
 
         Result result = JSONUtils.parseObject(mvcResult.getResponse().getContentAsString(), Result.class);
         result.getCode().equals(Status.SUCCESS.getCode());
 
-        Assert.assertEquals(Status.SUCCESS.getCode(),result.getCode().intValue());
+        Assertions.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
         logger.info(mvcResult.getResponse().getContentAsString());
     }
 
@@ -59,32 +60,32 @@ public class MonitorControllerTest extends AbstractControllerTest {
     public void testListWorker() throws Exception {
 
         MvcResult mvcResult = mockMvc.perform(get("/monitor/workers")
-            .header(SESSION_ID, sessionId)
-           /* .param("type", ResourceType.FILE.name())*/)
-            .andExpect(status().isOk())
-            .andExpect(content().contentType(MediaType.APPLICATION_JSON))
-            .andReturn();
+                .header(SESSION_ID, sessionId)
+        /* .param("type", ResourceType.FILE.name()) */)
+                .andExpect(status().isOk())
+                .andExpect(content().contentType(MediaType.APPLICATION_JSON))
+                .andReturn();
 
         Result result = JSONUtils.parseObject(mvcResult.getResponse().getContentAsString(), Result.class);
         result.getCode().equals(Status.SUCCESS.getCode());
 
-        Assert.assertEquals(Status.SUCCESS.getCode(),result.getCode().intValue());
+        Assertions.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
         logger.info(mvcResult.getResponse().getContentAsString());
     }
 
     @Test
     public void testQueryDatabaseState() throws Exception {
         MvcResult mvcResult = mockMvc.perform(get("/monitor/databases")
-            .header(SESSION_ID, sessionId)
-            /* .param("type", ResourceType.FILE.name())*/)
-            .andExpect(status().isOk())
-            .andExpect(content().contentType(MediaType.APPLICATION_JSON))
-            .andReturn();
+                .header(SESSION_ID, sessionId)
+        /* .param("type", ResourceType.FILE.name()) */)
+                .andExpect(status().isOk())
+                .andExpect(content().contentType(MediaType.APPLICATION_JSON))
+                .andReturn();
 
         Result result = JSONUtils.parseObject(mvcResult.getResponse().getContentAsString(), Result.class);
         result.getCode().equals(Status.SUCCESS.getCode());
 
-        Assert.assertEquals(Status.SUCCESS.getCode(),result.getCode().intValue());
+        Assertions.assertEquals(Status.SUCCESS.getCode(), result.getCode().intValue());
         logger.info(mvcResult.getResponse().getContentAsString());
     }
 
