@@ -22,8 +22,6 @@ import org.apache.dolphinscheduler.common.thread.ThreadLocalContext;
 
 import org.apache.commons.lang3.StringUtils;
 
-import javax.annotation.Nonnull;
-import javax.annotation.Nullable;
 import java.time.Instant;
 import java.time.LocalDateTime;
 import java.time.ZoneId;
@@ -34,9 +32,12 @@ import java.util.Date;
 import java.util.Objects;
 import java.util.TimeZone;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import javax.annotation.Nonnull;
+import javax.annotation.Nullable;
 
+import lombok.extern.slf4j.Slf4j;
+
+@Slf4j
 public final class DateUtils {
 
     static final long C0 = 1L;
@@ -47,7 +48,6 @@ public final class DateUtils {
     static final long C5 = C4 * 60L;
     static final long C6 = C5 * 24L;
 
-    private static final Logger logger = LoggerFactory.getLogger(DateUtils.class);
     private static final DateTimeFormatter YYYY_MM_DD_HH_MM_SS =
             DateTimeFormatter.ofPattern(DateConstants.YYYY_MM_DD_HH_MM_SS);
 
@@ -75,7 +75,7 @@ public final class DateUtils {
      * @return local datetime
      */
     private static LocalDateTime date2LocalDateTime(Date date, ZoneId zoneId) {
-        return LocalDateTime.ofInstant(date.toInstant(), zoneId);
+        return LocalDateTime.ofInstant(Instant.ofEpochMilli(date.getTime()), zoneId);
     }
 
     /**
@@ -124,7 +124,8 @@ public final class DateUtils {
 
     public static String format(Date date, DateTimeFormatter dateTimeFormatter, String timezone) {
         LocalDateTime localDateTime =
-            StringUtils.isEmpty(timezone) ? date2LocalDateTime(date) : date2LocalDateTime(date, ZoneId.of(timezone));
+                StringUtils.isEmpty(timezone) ? date2LocalDateTime(date)
+                        : date2LocalDateTime(date, ZoneId.of(timezone));
         return format(localDateTime, dateTimeFormatter);
     }
 
@@ -216,7 +217,7 @@ public final class DateUtils {
             }
             return localDateTime2Date(ldt, ZoneId.of(timezone));
         } catch (Exception e) {
-            logger.error("error while parse date:" + date, e);
+            log.error("error while parse date:" + date, e);
         }
         return null;
     }
@@ -244,8 +245,8 @@ public final class DateUtils {
         Date d = stringToDate(date);
         if (d == null) {
             throw new IllegalArgumentException(String.format(
-                "data: %s should be a validate data string - yyyy-MM-dd HH:mm:ss ",
-                date));
+                    "data: %s should be a validate data string - yyyy-MM-dd HH:mm:ss ",
+                    date));
         }
         return ZonedDateTime.ofInstant(d.toInstant(), ZoneId.systemDefault());
     }
@@ -354,6 +355,10 @@ public final class DateUtils {
         if (end == null) {
             end = new Date();
         }
+        if (start.after(end)) {
+            log.warn("start Time {} is later than end Time {}", start, end);
+            return null;
+        }
         return format2Duration(differMs(start, end));
     }
 
@@ -579,6 +584,14 @@ public final class DateUtils {
         return intervalSeconds - usedTime;
     }
 
+    public static long getRemainTime(Long baseTime, long intervalSeconds) {
+        if (baseTime == null) {
+            return 0;
+        }
+        long usedTime = (System.currentTimeMillis() - baseTime) / 1000;
+        return intervalSeconds - usedTime;
+    }
+
     /**
      * get current time stamp : yyyyMMddHHmmssSSS
      *
@@ -611,7 +624,7 @@ public final class DateUtils {
         LocalDateTime localDateTime =
                 LocalDateTime.parse(dateToString, DateTimeFormatter.ofPattern(DateConstants.YYYY_MM_DD_HH_MM_SS));
         ZonedDateTime zonedDateTime =
-            ZonedDateTime.of(localDateTime, TimeZone.getTimeZone(targetTimezoneId).toZoneId());
+                ZonedDateTime.of(localDateTime, TimeZone.getTimeZone(targetTimezoneId).toZoneId());
         return Date.from(zonedDateTime.toInstant());
     }
 
@@ -629,6 +642,7 @@ public final class DateUtils {
      * Time unit representing one thousandth of a second
      */
     public static class MILLISECONDS {
+
         public static long toDays(long d) {
             return d / (C6 / C2);
         }
@@ -714,7 +728,7 @@ public final class DateUtils {
             LocalDateTime ldt = LocalDateTime.parse(date, DateTimeFormatter.ofPattern(format));
             return localDateTime2Date(ldt);
         } catch (Exception e) {
-            logger.error("error while parse date:" + date, e);
+            log.error("error while parse date:" + date, e);
         }
         return null;
     }
