@@ -39,8 +39,7 @@ import java.util.TimeZone;
 
 import javax.annotation.Nullable;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
 import com.fasterxml.jackson.core.JsonGenerator;
 import com.fasterxml.jackson.core.JsonParser;
@@ -54,6 +53,7 @@ import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.ObjectWriter;
 import com.fasterxml.jackson.databind.SerializationFeature;
 import com.fasterxml.jackson.databind.SerializerProvider;
+import com.fasterxml.jackson.databind.json.JsonMapper;
 import com.fasterxml.jackson.databind.module.SimpleModule;
 import com.fasterxml.jackson.databind.node.ArrayNode;
 import com.fasterxml.jackson.databind.node.ObjectNode;
@@ -64,29 +64,24 @@ import com.google.common.base.Strings;
 /**
  * json utils
  */
+@Slf4j
 public class JSONUtils {
 
-    private static final Logger logger = LoggerFactory.getLogger(JSONUtils.class);
-
     static {
-        logger.info("init timezone: {}", TimeZone.getDefault());
+        log.info("init timezone: {}", TimeZone.getDefault());
     }
 
-    private static final SimpleModule LOCAL_DATE_TIME_MODULE = new SimpleModule()
-            .addSerializer(LocalDateTime.class, new LocalDateTimeSerializer())
-            .addDeserializer(LocalDateTime.class, new LocalDateTimeDeserializer());
-
-    /**
-     * can use static singleton, inject: just make sure to reuse!
-     */
-    private static final ObjectMapper objectMapper = new ObjectMapper()
+    private static final ObjectMapper objectMapper = JsonMapper.builder()
             .configure(FAIL_ON_UNKNOWN_PROPERTIES, false)
             .configure(ACCEPT_EMPTY_ARRAY_AS_NULL_OBJECT, true)
             .configure(READ_UNKNOWN_ENUM_VALUES_AS_NULL, true)
             .configure(REQUIRE_SETTERS_FOR_GETTERS, true)
-            .registerModule(LOCAL_DATE_TIME_MODULE)
-            .setTimeZone(TimeZone.getDefault())
-            .setDateFormat(new SimpleDateFormat(YYYY_MM_DD_HH_MM_SS));
+            .addModule(new SimpleModule()
+                    .addSerializer(LocalDateTime.class, new LocalDateTimeSerializer())
+                    .addDeserializer(LocalDateTime.class, new LocalDateTimeDeserializer()))
+            .defaultTimeZone(TimeZone.getDefault())
+            .defaultDateFormat(new SimpleDateFormat(YYYY_MM_DD_HH_MM_SS))
+            .build();
 
     private JSONUtils() {
         throw new UnsupportedOperationException("Construct JSONUtils");
@@ -120,7 +115,7 @@ public class JSONUtils {
             ObjectWriter writer = objectMapper.writer(feature);
             return writer.writeValueAsString(object);
         } catch (Exception e) {
-            logger.error("object to json exception!", e);
+            log.error("object to json exception!", e);
         }
 
         return null;
@@ -148,7 +143,7 @@ public class JSONUtils {
         try {
             return objectMapper.readValue(json, clazz);
         } catch (Exception e) {
-            logger.error("Parse object exception, jsonStr: {}, class: {}", json, clazz, e);
+            log.error("Parse object exception, jsonStr: {}, class: {}", json, clazz, e);
         }
         return null;
     }
@@ -186,7 +181,7 @@ public class JSONUtils {
             CollectionType listType = objectMapper.getTypeFactory().constructCollectionType(ArrayList.class, clazz);
             return objectMapper.readValue(json, listType);
         } catch (Exception e) {
-            logger.error("parse list exception!", e);
+            log.error("parse list exception!", e);
         }
 
         return Collections.emptyList();
@@ -208,7 +203,7 @@ public class JSONUtils {
             objectMapper.readTree(json);
             return true;
         } catch (IOException e) {
-            logger.error("check json object valid exception!", e);
+            log.error("check json object valid exception!", e);
         }
 
         return false;
@@ -264,7 +259,7 @@ public class JSONUtils {
             return objectMapper.readValue(json, new TypeReference<Map<K, V>>() {
             });
         } catch (Exception e) {
-            logger.error("json to map exception!", e);
+            log.error("json to map exception!", e);
         }
 
         return Collections.emptyMap();
@@ -305,7 +300,7 @@ public class JSONUtils {
         try {
             return objectMapper.readValue(json, type);
         } catch (Exception e) {
-            logger.error("json to map exception!", e);
+            log.error("json to map exception!", e);
         }
 
         return null;
@@ -348,7 +343,7 @@ public class JSONUtils {
         try {
             json = toJsonString(obj);
         } catch (Exception e) {
-            logger.error("json serialize exception.", e);
+            log.error("json serialize exception.", e);
         }
 
         return json.getBytes(UTF_8);
