@@ -17,9 +17,12 @@
 
 package org.apache.dolphinscheduler.dao.entity;
 
+import lombok.Data;
+
 /**
  * count definition number group by user
  */
+@Data
 public class DefinitionGroupByUser {
 
     /**
@@ -36,28 +39,4 @@ public class DefinitionGroupByUser {
      * count number
      */
     private int count;
-
-    public String getUserName() {
-        return userName;
-    }
-
-    public void setUserName(String userName) {
-        this.userName = userName;
-    }
-
-    public int getCount() {
-        return count;
-    }
-
-    public void setCount(int count) {
-        this.count = count;
-    }
-
-    public Integer getUserId() {
-        return userId;
-    }
-
-    public void setUserId(Integer userId) {
-        this.userId = userId;
-    }
 }
