@@ -21,6 +21,7 @@ import static org.apache.dolphinscheduler.common.constants.Constants.SEC_2_MINUT
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_BLOCKING;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_CONDITIONS;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_DEPENDENT;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_DYNAMIC;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_SUB_PROCESS;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TASK_TYPE_SWITCH;
 
@@ -40,6 +41,7 @@ import java.util.Map;
 
 import lombok.Data;
 
+import com.baomidou.mybatisplus.annotation.FieldStrategy;
 import com.baomidou.mybatisplus.annotation.IdType;
 import com.baomidou.mybatisplus.annotation.TableField;
 import com.baomidou.mybatisplus.annotation.TableId;
@@ -69,30 +71,16 @@ public class TaskInstance implements Serializable {
      */
     private String taskType;
 
-    /**
-     * process instance id
-     */
     private int processInstanceId;
 
-    /**
-     * task code
-     */
-    private long taskCode;
-
-    /**
-     * task definition version
-     */
-    private int taskDefinitionVersion;
-
-    /**
-     * process instance name
-     */
-    @TableField(exist = false)
     private String processInstanceName;
 
-    /**
-     * process definition name
-     */
+    private Long projectCode;
+
+    private long taskCode;
+
+    private int taskDefinitionVersion;
+
     @TableField(exist = false)
     private String processDefinitionName;
 
@@ -187,6 +175,17 @@ public class TaskInstance implements Serializable {
      */
     private Flag flag;
 
+    /**
+     * task is cache: yes/no
+     */
+    private Flag isCache;
+
+    /**
+     * cache_key
+     */
+    @TableField(updateStrategy = FieldStrategy.IGNORED)
+    private String cacheKey;
+
     /**
      * dependency
      */
@@ -257,10 +256,6 @@ public class TaskInstance implements Serializable {
      */
     private String varPool;
 
-    /**
-     * executor name
-     */
-    @TableField(exist = false)
     private String executorName;
 
     @TableField(exist = false)
@@ -300,6 +295,11 @@ public class TaskInstance implements Serializable {
      */
     private TaskExecuteType taskExecuteType;
 
+    /**
+     * test flag
+     */
+    private int testFlag;
+
     public void init(String host, Date startTime, String executePath) {
         this.host = host;
         this.startTime = startTime;
@@ -322,6 +322,8 @@ public class TaskInstance implements Serializable {
     }
 
     public SwitchParameters getSwitchDependency() {
+        // todo: We need to directly use Jackson to deserialize the taskParam, rather than parse the map and get from
+        // field.
         if (this.switchDependency == null) {
             Map<String, Object> taskParamsMap =
                     JSONUtils.parseObject(this.getTaskParams(), new TypeReference<Map<String, Object>>() {
@@ -337,6 +339,7 @@ public class TaskInstance implements Serializable {
                 JSONUtils.parseObject(this.getTaskParams(), new TypeReference<Map<String, Object>>() {
                 });
         taskParamsMap.put(Constants.SWITCH_RESULT, JSONUtils.toJsonString(switchDependency));
+        this.switchDependency = switchDependency;
         this.setTaskParams(JSONUtils.toJsonString(taskParamsMap));
     }
 
@@ -344,7 +347,8 @@ public class TaskInstance implements Serializable {
 
         return this.getState().isSuccess()
                 || this.getState().isKill()
-                || (this.getState().isFailure() && !taskCanRetry());
+                || (this.getState().isFailure() && !taskCanRetry())
+                || this.getState().isForceSuccess();
     }
 
     public boolean isSubProcess() {
@@ -355,6 +359,10 @@ public class TaskInstance implements Serializable {
         return TASK_TYPE_DEPENDENT.equalsIgnoreCase(this.taskType);
     }
 
+    public boolean isDynamic() {
+        return TASK_TYPE_DYNAMIC.equalsIgnoreCase(this.taskType);
+    }
+
     public boolean isConditionsTask() {
         return TASK_TYPE_CONDITIONS.equalsIgnoreCase(this.taskType);
     }
@@ -404,4 +412,5 @@ public class TaskInstance implements Serializable {
         // task retry does not over time, return false
         return getRetryInterval() * SEC_2_MINUTES_TIME_UNIT < failedTimeInterval;
     }
+
 }
