@@ -23,6 +23,7 @@ import org.apache.ibatis.annotations.Mapper;
 import org.apache.ibatis.annotations.Param;
 
 import java.util.Date;
+import java.util.List;
 
 import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 
@@ -32,10 +33,19 @@ import com.baomidou.mybatisplus.core.mapper.BaseMapper;
 @Mapper
 public interface AlertMapper extends BaseMapper<Alert> {
 
+    /**
+     * Query the alert by alertStatus and return limit with default sort.
+     */
+    List<Alert> listingAlertByStatus(@Param("alertStatus") int alertStatus, @Param("limit") int limit);
+
     /**
      * Insert server crash alert
      * <p>This method will ensure that there is at most one unsent alert which has the same content in the database.
      */
-    void insertAlertWhenServerCrash(@Param("alert") Alert alert, @Param("crashAlarmSuppressionStartTime") Date crashAlarmSuppressionStartTime);
+    void insertAlertWhenServerCrash(@Param("alert") Alert alert,
+                                    @Param("crashAlarmSuppressionStartTime") Date crashAlarmSuppressionStartTime);
 
+    void deleteByWorkflowInstanceId(@Param("workflowInstanceId") Integer processInstanceId);
+
+    List<Alert> selectByWorkflowInstanceId(@Param("workflowInstanceId") Integer processInstanceId);
 }
