@@ -33,6 +33,8 @@ public class TaskInstanceUtils {
         target.setName(source.getName());
         target.setTaskType(source.getTaskType());
         target.setProcessInstanceId(source.getProcessInstanceId());
+        target.setProcessInstanceName(source.getProcessInstanceName());
+        target.setProjectCode(source.getProjectCode());
         target.setTaskCode(source.getTaskCode());
         target.setTaskDefinitionVersion(source.getTaskDefinitionVersion());
         target.setProcessInstanceName(source.getProcessInstanceName());
@@ -54,7 +56,8 @@ public class TaskInstanceUtils {
         target.setAppLink(source.getAppLink());
         target.setFlag(source.getFlag());
         target.setDependency(source.getDependency());
-        // todo: we need to cpoy the task params and then copy switchDependency, since the setSwitchDependency rely on task params, this is really a very bad practice.
+        // todo: we need to cpoy the task params and then copy switchDependency, since the setSwitchDependency rely on
+        // task params, this is really a very bad practice.
         target.setTaskParams(source.getTaskParams());
         target.setSwitchDependency(source.getSwitchDependency());
         target.setDuration(source.getDuration());
@@ -75,6 +78,7 @@ public class TaskInstanceUtils {
         target.setCpuQuota(source.getCpuQuota());
         target.setMemoryMax(source.getMemoryMax());
         target.setTaskExecuteType(source.getTaskExecuteType());
+        target.setTestFlag(source.getTestFlag());
     }
 
 }
