@@ -23,8 +23,8 @@ import org.apache.dolphinscheduler.dao.entity.PluginDefine;
 
 import java.util.List;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.springframework.beans.factory.annotation.Autowired;
 
 import com.baomidou.mybatisplus.core.metadata.IPage;
@@ -47,15 +47,15 @@ public class AlertPluginInstanceMapperTest extends BaseDaoTest {
     @Test
     public void testQueryAllAlertPluginInstanceList() {
         List<AlertPluginInstance> withoutSingleOne = alertPluginInstanceMapper.queryAllAlertPluginInstanceList();
-        Assert.assertEquals(0, withoutSingleOne.size());
+        Assertions.assertEquals(0, withoutSingleOne.size());
 
         createAlertPluginInstance("test_instance_1");
         List<AlertPluginInstance> withExactlyOne = alertPluginInstanceMapper.queryAllAlertPluginInstanceList();
-        Assert.assertEquals(1, withExactlyOne.size());
+        Assertions.assertEquals(1, withExactlyOne.size());
 
         createAlertPluginInstance("test_instance_2");
         List<AlertPluginInstance> withExactlyTwo = alertPluginInstanceMapper.queryAllAlertPluginInstanceList();
-        Assert.assertEquals(2, withExactlyTwo.size());
+        Assertions.assertEquals(2, withExactlyTwo.size());
     }
 
     /**
@@ -64,9 +64,9 @@ public class AlertPluginInstanceMapperTest extends BaseDaoTest {
     @Test
     public void testExistInstanceName() {
         String instanceName = "test_instance";
-        Assert.assertNull(alertPluginInstanceMapper.existInstanceName(instanceName));
+        Assertions.assertNull(alertPluginInstanceMapper.existInstanceName(instanceName));
         createAlertPluginInstance(instanceName);
-        Assert.assertTrue(alertPluginInstanceMapper.existInstanceName(instanceName));
+        Assertions.assertTrue(alertPluginInstanceMapper.existInstanceName(instanceName));
     }
 
     /**
@@ -79,10 +79,10 @@ public class AlertPluginInstanceMapperTest extends BaseDaoTest {
 
         Page<AlertPluginInstance> page = new Page<>(1, 10);
         IPage<AlertPluginInstance> matchTwoRecord = alertPluginInstanceMapper.queryByInstanceNamePage(page, "test");
-        Assert.assertEquals(2, matchTwoRecord.getTotal());
+        Assertions.assertEquals(2, matchTwoRecord.getTotal());
 
         IPage<AlertPluginInstance> matchOneRecord = alertPluginInstanceMapper.queryByInstanceNamePage(page, "pattern");
-        Assert.assertEquals(1, matchOneRecord.getTotal());
+        Assertions.assertEquals(1, matchOneRecord.getTotal());
     }
 
     /**
