@@ -30,8 +30,8 @@ import org.apache.dolphinscheduler.dao.entity.WorkFlowLineage;
 import java.util.Date;
 import java.util.List;
 
-import org.junit.Assert;
-import org.junit.Test;
+import org.junit.jupiter.api.Assertions;
+import org.junit.jupiter.api.Test;
 import org.springframework.beans.factory.annotation.Autowired;
 
 public class WorkFlowLineageMapperTest extends BaseDaoTest {
@@ -54,7 +54,7 @@ public class WorkFlowLineageMapperTest extends BaseDaoTest {
      * @return ProcessDefinition
      */
     private ProcessTaskRelation insertOneProcessTaskRelation() {
-        //insertOne
+        // insertOne
         ProcessTaskRelation processTaskRelation = new ProcessTaskRelation();
         processTaskRelation.setName("def 1");
 
@@ -75,7 +75,7 @@ public class WorkFlowLineageMapperTest extends BaseDaoTest {
      *
      */
     private void insertOneProcessDefinition() {
-        //insertOne
+        // insertOne
         ProcessDefinition processDefinition = new ProcessDefinition();
         processDefinition.setCode(1L);
         processDefinition.setName("def 1");
@@ -91,7 +91,7 @@ public class WorkFlowLineageMapperTest extends BaseDaoTest {
      *
      */
     private void insertOneSchedule(int id) {
-        //insertOne
+        // insertOne
         Schedule schedule = new Schedule();
         schedule.setStartTime(new Date());
         schedule.setEndTime(new Date());
@@ -111,16 +111,18 @@ public class WorkFlowLineageMapperTest extends BaseDaoTest {
         ProcessDefinition processDefinition = processDefinitionMapper.queryByCode(1L);
         insertOneSchedule(processDefinition.getId());
 
-        List<WorkFlowLineage> workFlowLineages = workFlowLineageMapper.queryWorkFlowLineageByName(processDefinition.getProjectCode(), processDefinition.getName());
-        Assert.assertNotEquals(workFlowLineages.size(), 0);
+        List<WorkFlowLineage> workFlowLineages = workFlowLineageMapper
+                .queryWorkFlowLineageByName(processDefinition.getProjectCode(), processDefinition.getName());
+        Assertions.assertNotEquals(0, workFlowLineages.size());
     }
 
     @Test
     public void testQueryCodeRelation() {
         ProcessTaskRelation processTaskRelation = insertOneProcessTaskRelation();
-        List<ProcessLineage> workFlowLineages = workFlowLineageMapper.queryProcessLineageByCode(processTaskRelation.getProjectCode(),
-            processTaskRelation.getProcessDefinitionCode());
-        Assert.assertNotEquals(workFlowLineages.size(), 0);
+        List<ProcessLineage> workFlowLineages =
+                workFlowLineageMapper.queryProcessLineageByCode(processTaskRelation.getProjectCode(),
+                        processTaskRelation.getProcessDefinitionCode());
+        Assertions.assertNotEquals(0, workFlowLineages.size());
     }
 
     @Test
@@ -128,8 +130,9 @@ public class WorkFlowLineageMapperTest extends BaseDaoTest {
         insertOneProcessDefinition();
         ProcessDefinition processDefinition = processDefinitionMapper.queryByCode(1L);
         insertOneProcessTaskRelation();
-        List<ProcessLineage> workFlowLineages = workFlowLineageMapper.queryProcessLineage(processDefinition.getProjectCode());
-        Assert.assertNotEquals(workFlowLineages.size(), 0);
+        List<ProcessLineage> workFlowLineages =
+                workFlowLineageMapper.queryProcessLineage(processDefinition.getProjectCode());
+        Assertions.assertNotEquals(0, workFlowLineages.size());
     }
 
     @Test
@@ -137,8 +140,9 @@ public class WorkFlowLineageMapperTest extends BaseDaoTest {
         insertOneProcessDefinition();
         ProcessDefinition processDefinition = processDefinitionMapper.queryByCode(1L);
         insertOneSchedule(processDefinition.getId());
-        WorkFlowLineage workFlowLineages = workFlowLineageMapper.queryWorkFlowLineageByCode(processDefinition.getProjectCode(), processDefinition.getCode());
-        Assert.assertNotNull(workFlowLineages);
+        WorkFlowLineage workFlowLineages = workFlowLineageMapper
+                .queryWorkFlowLineageByCode(processDefinition.getProjectCode(), processDefinition.getCode());
+        Assertions.assertNotNull(workFlowLineages);
     }
 
 }
