@@ -34,7 +34,6 @@ public interface DataSourceProcessor {
      */
     BaseDataSourceParamDTO castDatasourceParamDTO(String paramJson);
 
-
     /**
      * check datasource param is valid
      */
@@ -94,8 +93,17 @@ public interface DataSourceProcessor {
      * @param connectionParam connectionParam
      * @return {@link Connection}
      */
+    // todo: Change to return a ConnectionWrapper
     Connection getConnection(ConnectionParam connectionParam) throws ClassNotFoundException, SQLException, IOException;
 
+    /**
+     * test connection
+     *
+     * @param connectionParam connectionParam
+     * @return true if connection is valid
+     */
+    boolean checkDataSourceConnectivity(ConnectionParam connectionParam);
+
     /**
      * @return {@link DbType}
      */
