@@ -19,9 +19,10 @@
  */
 package org.apache.dolphinscheduler.e2e.pages.resource;
 
-import lombok.Getter;
 import org.apache.dolphinscheduler.e2e.pages.common.NavBarPage;
-import org.apache.dolphinscheduler.e2e.pages.security.TenantPage;
+
+import java.time.Duration;
+
 import org.openqa.selenium.JavascriptExecutor;
 import org.openqa.selenium.WebElement;
 import org.openqa.selenium.remote.RemoteWebDriver;
@@ -29,6 +30,8 @@ import org.openqa.selenium.support.FindBy;
 import org.openqa.selenium.support.ui.ExpectedConditions;
 import org.openqa.selenium.support.ui.WebDriverWait;
 
+import lombok.Getter;
+
 
 @Getter
 public class ResourcePage extends NavBarPage implements NavBarPage.NavBarItem {
@@ -47,26 +50,26 @@ public class ResourcePage extends NavBarPage implements NavBarPage.NavBarItem {
 
     public <T extends ResourcePage.Tab> T goToTab(Class<T> tab) {
         if (tab == FileManagePage.class) {
-            new WebDriverWait(driver, 10).until(ExpectedConditions.urlContains("/resource"));
-            new WebDriverWait(driver, 10).until(ExpectedConditions.elementToBeClickable(fileManageTab));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.urlContains("/resource"));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.elementToBeClickable(fileManageTab));
             ((JavascriptExecutor) driver).executeScript("arguments[0].click();", fileManageTab());
-            new WebDriverWait(driver, 10).until(ExpectedConditions.urlContains("/file-manage"));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.urlContains("/file-manage"));
             return tab.cast(new FileManagePage(driver));
         }
 
         if (tab == UdfManagePage.class) {
-            new WebDriverWait(driver, 10).until(ExpectedConditions.urlContains("/resource"));
-            new WebDriverWait(driver, 10).until(ExpectedConditions.elementToBeClickable(udfManageTab));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.urlContains("/resource"));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.elementToBeClickable(udfManageTab));
             ((JavascriptExecutor) driver).executeScript("arguments[0].click();", udfManageTab());
-            new WebDriverWait(driver, 10).until(ExpectedConditions.urlContains("/resource-manage"));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.urlContains("/resource-manage"));
             return tab.cast(new UdfManagePage(driver));
         }
 
         if (tab == FunctionManagePage.class) {
-            new WebDriverWait(driver, 10).until(ExpectedConditions.urlContains("/resource"));
-            new WebDriverWait(driver, 10).until(ExpectedConditions.elementToBeClickable(functionManageTab));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.urlContains("/resource"));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.elementToBeClickable(functionManageTab));
             ((JavascriptExecutor) driver).executeScript("arguments[0].click();", functionManageTab());
-            new WebDriverWait(driver, 10).until(ExpectedConditions.urlContains("/function-manage"));
+            new WebDriverWait(driver, Duration.ofSeconds(20)).until(ExpectedConditions.urlContains("/function-manage"));
             return tab.cast(new FunctionManagePage(driver));
         }
 
