@@ -21,18 +21,21 @@ import org.apache.dolphinscheduler.common.IStoppable;
 import org.apache.dolphinscheduler.common.constants.Constants;
 import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
 import org.apache.dolphinscheduler.common.thread.ThreadUtils;
+import org.apache.dolphinscheduler.plugin.task.api.TaskPluginManager;
 import org.apache.dolphinscheduler.scheduler.api.SchedulerApi;
 import org.apache.dolphinscheduler.server.master.registry.MasterRegistryClient;
 import org.apache.dolphinscheduler.server.master.rpc.MasterRPCServer;
+import org.apache.dolphinscheduler.server.master.rpc.MasterRpcClient;
 import org.apache.dolphinscheduler.server.master.runner.EventExecuteService;
 import org.apache.dolphinscheduler.server.master.runner.FailoverExecuteThread;
 import org.apache.dolphinscheduler.server.master.runner.MasterSchedulerBootstrap;
-import org.apache.dolphinscheduler.server.master.runner.task.TaskProcessorFactory;
 import org.apache.dolphinscheduler.service.bean.SpringApplicationContext;
-import org.apache.dolphinscheduler.service.task.TaskPluginManager;
+
+import javax.annotation.PostConstruct;
+
+import lombok.extern.slf4j.Slf4j;
+
 import org.quartz.SchedulerException;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
 import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.boot.SpringApplication;
 import org.springframework.boot.autoconfigure.SpringBootApplication;
@@ -40,16 +43,13 @@ import org.springframework.cache.annotation.EnableCaching;
 import org.springframework.context.annotation.ComponentScan;
 import org.springframework.transaction.annotation.EnableTransactionManagement;
 
-import javax.annotation.PostConstruct;
-
 @SpringBootApplication
 @ComponentScan("org.apache.dolphinscheduler")
 @EnableTransactionManagement
 @EnableCaching
+@Slf4j
 public class MasterServer implements IStoppable {
 
-    private static final Logger logger = LoggerFactory.getLogger(MasterServer.class);
-
     @Autowired
     private SpringApplicationContext springApplicationContext;
 
@@ -74,6 +74,9 @@ public class MasterServer implements IStoppable {
     @Autowired
     private MasterRPCServer masterRPCServer;
 
+    @Autowired
+    private MasterRpcClient masterRpcClient;
+
     public static void main(String[] args) {
         Thread.currentThread().setName(Constants.THREAD_NAME_MASTER_SERVER);
         SpringApplication.run(MasterServer.class);
@@ -86,6 +89,7 @@ public class MasterServer implements IStoppable {
     public void run() throws SchedulerException {
         // init rpc server
         this.masterRPCServer.start();
+        this.masterRpcClient.start();
 
         // install task plugin
         this.taskPluginManager.loadPlugin();
@@ -94,7 +98,6 @@ public class MasterServer implements IStoppable {
         this.masterRegistryClient.start();
         this.masterRegistryClient.setRegistryStoppable(this);
 
-        this.masterSchedulerBootstrap.init();
         this.masterSchedulerBootstrap.start();
 
         this.eventExecuteService.start();
@@ -118,7 +121,7 @@ public class MasterServer implements IStoppable {
         // set stop signal is true
         // execute only once
         if (!ServerLifeCycleManager.toStopped()) {
-            logger.warn("MasterServer is already stopped, current cause: {}", cause);
+            log.warn("MasterServer is already stopped, current cause: {}", cause);
             return;
         }
         // thread sleep 3 seconds for thread quietly stop
@@ -127,17 +130,18 @@ public class MasterServer implements IStoppable {
                 SchedulerApi closedSchedulerApi = schedulerApi;
                 MasterSchedulerBootstrap closedSchedulerBootstrap = masterSchedulerBootstrap;
                 MasterRPCServer closedRpcServer = masterRPCServer;
+                MasterRpcClient closedRpcClient = masterRpcClient;
                 MasterRegistryClient closedMasterRegistryClient = masterRegistryClient;
                 // close spring Context and will invoke method with @PreDestroy annotation to destroy beans.
                 // like ServerNodeManager,HostManager,TaskResponseService,CuratorZookeeperClient,etc
                 SpringApplicationContext closedSpringContext = springApplicationContext) {
 
-            logger.info("Master server is stopping, current cause : {}", cause);
+            log.info("Master server is stopping, current cause : {}", cause);
         } catch (Exception e) {
-            logger.error("MasterServer stop failed, current cause: {}", cause, e);
+            log.error("MasterServer stop failed, current cause: {}", cause, e);
             return;
         }
-        logger.info("MasterServer stopped, current cause: {}", cause);
+        log.info("MasterServer stopped, current cause: {}", cause);
     }
 
     @Override
