@@ -17,61 +17,60 @@
 
 package org.apache.dolphinscheduler.server.master.event;
 
-import com.google.auto.service.AutoService;
 import org.apache.dolphinscheduler.common.enums.StateEventType;
 import org.apache.dolphinscheduler.common.enums.TimeoutFlag;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskTimeoutStrategy;
 import org.apache.dolphinscheduler.server.master.metrics.TaskMetrics;
 import org.apache.dolphinscheduler.server.master.runner.WorkflowExecuteRunnable;
-import org.apache.dolphinscheduler.server.master.runner.task.ITaskProcessor;
-import org.apache.dolphinscheduler.server.master.runner.task.TaskAction;
+import org.apache.dolphinscheduler.server.master.runner.execute.DefaultTaskExecuteRunnable;
 
 import java.util.Map;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+
+import lombok.extern.slf4j.Slf4j;
+
+import com.google.auto.service.AutoService;
 
 @AutoService(StateEventHandler.class)
+@Slf4j
 public class TaskTimeoutStateEventHandler implements StateEventHandler {
 
-    private static final Logger logger = LoggerFactory.getLogger(TaskTimeoutStateEventHandler.class);
-
     @Override
     public boolean handleStateEvent(WorkflowExecuteRunnable workflowExecuteRunnable,
-        StateEvent stateEvent) throws StateEventHandleError {
+                                    StateEvent stateEvent) throws StateEventHandleError, StateEventHandleException {
         TaskStateEvent taskStateEvent = (TaskStateEvent) stateEvent;
 
         TaskMetrics.incTaskInstanceByState("timeout");
         workflowExecuteRunnable.checkTaskInstanceByStateEvent(taskStateEvent);
 
         TaskInstance taskInstance =
-            workflowExecuteRunnable.getTaskInstance(taskStateEvent.getTaskInstanceId()).orElseThrow(
-                () -> new StateEventHandleError(String.format(
-                    "Cannot find the task instance from workflow execute runnable, taskInstanceId: %s",
-                    taskStateEvent.getTaskInstanceId())));
+                workflowExecuteRunnable.getTaskInstance(taskStateEvent.getTaskInstanceId()).orElseThrow(
+                        () -> new StateEventHandleError(String.format(
+                                "Cannot find the task instance from workflow execute runnable, taskInstanceId: %s",
+                                taskStateEvent.getTaskInstanceId())));
 
-        logger.info("Handle task instance state timout event, taskInstanceId: {}", taskStateEvent.getTaskInstanceId());
+        log.info("Handle task instance state timeout event, taskInstanceId: {}", taskStateEvent.getTaskInstanceId());
 
         if (TimeoutFlag.CLOSE == taskInstance.getTaskDefine().getTimeoutFlag()) {
             return true;
         }
         TaskTimeoutStrategy taskTimeoutStrategy = taskInstance.getTaskDefine()
-            .getTimeoutNotifyStrategy();
-        Map<Long, ITaskProcessor> activeTaskProcessMap = workflowExecuteRunnable
-            .getActiveTaskProcessMap();
+                .getTimeoutNotifyStrategy();
+        Map<Long, DefaultTaskExecuteRunnable> taskExecuteRunnableMap =
+                workflowExecuteRunnable.getTaskExecuteRunnableMap();
         if ((TaskTimeoutStrategy.FAILED == taskTimeoutStrategy
-            || TaskTimeoutStrategy.WARNFAILED == taskTimeoutStrategy)) {
-            if (activeTaskProcessMap.containsKey(taskInstance.getTaskCode())) {
-                ITaskProcessor taskProcessor = activeTaskProcessMap.get(taskInstance.getTaskCode());
-                taskProcessor.action(TaskAction.TIMEOUT);
+                || TaskTimeoutStrategy.WARNFAILED == taskTimeoutStrategy)) {
+            if (taskExecuteRunnableMap.containsKey(taskInstance.getTaskCode())) {
+                taskExecuteRunnableMap.get(taskInstance.getTaskCode()).timeout();
+                workflowExecuteRunnable.taskFinished(taskInstance);
             } else {
-                logger.warn(
-                    "cannot find the task processor for task {}, so skip task processor action.",
-                    taskInstance.getTaskCode());
+                log.warn(
+                        "cannot find the task processor for task {}, so skip task processor action.",
+                        taskInstance.getTaskCode());
             }
         }
         if (TaskTimeoutStrategy.WARN == taskTimeoutStrategy
-            || TaskTimeoutStrategy.WARNFAILED == taskTimeoutStrategy) {
+                || TaskTimeoutStrategy.WARNFAILED == taskTimeoutStrategy) {
             workflowExecuteRunnable.processTimeout();
             workflowExecuteRunnable.taskTimeout(taskInstance);
         }
