@@ -17,34 +17,33 @@
 
 package org.apache.dolphinscheduler.server.master.processor.queue;
 
-import io.netty.channel.Channel;
 import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
 import org.apache.dolphinscheduler.common.thread.BaseDaemonThread;
-import org.apache.dolphinscheduler.remote.command.StateEventResponseCommand;
+import org.apache.dolphinscheduler.plugin.task.api.utils.LogUtils;
+import org.apache.dolphinscheduler.remote.command.StateEventResponse;
 import org.apache.dolphinscheduler.server.master.cache.ProcessInstanceExecCacheManager;
 import org.apache.dolphinscheduler.server.master.event.StateEvent;
 import org.apache.dolphinscheduler.server.master.runner.WorkflowExecuteRunnable;
 import org.apache.dolphinscheduler.server.master.runner.WorkflowExecuteThreadPool;
-import org.apache.dolphinscheduler.service.utils.LoggerUtils;
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-import org.springframework.beans.factory.annotation.Autowired;
-import org.springframework.stereotype.Component;
 
-import javax.annotation.PostConstruct;
-import javax.annotation.PreDestroy;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.concurrent.BlockingQueue;
 import java.util.concurrent.LinkedBlockingQueue;
 
-@Component
-public class StateEventResponseService {
+import javax.annotation.PostConstruct;
+import javax.annotation.PreDestroy;
 
-    /**
-     * logger
-     */
-    private final Logger logger = LoggerFactory.getLogger(StateEventResponseService.class);
+import lombok.extern.slf4j.Slf4j;
+
+import org.springframework.beans.factory.annotation.Autowired;
+import org.springframework.stereotype.Component;
+
+import io.netty.channel.Channel;
+
+@Component
+@Slf4j
+public class StateEventResponseService {
 
     /**
      * attemptQueue
@@ -75,13 +74,11 @@ public class StateEventResponseService {
             List<StateEvent> remainEvents = new ArrayList<>(eventQueue.size());
             eventQueue.drainTo(remainEvents);
             for (StateEvent event : remainEvents) {
-                try {
-                    LoggerUtils.setWorkflowAndTaskInstanceIDMDC(event.getProcessInstanceId(),
-                            event.getTaskInstanceId());
+                try (
+                        final LogUtils.MDCAutoClosableContext mdcAutoClosableContext =
+                                LogUtils.setWorkflowAndTaskInstanceIDMDC(event.getProcessInstanceId(),
+                                        event.getTaskInstanceId())) {
                     this.persist(event);
-
-                } finally {
-                    LoggerUtils.removeWorkflowAndTaskInstanceIdMDC();
                 }
             }
         }
@@ -95,7 +92,7 @@ public class StateEventResponseService {
             // check the event is validated
             eventQueue.put(stateEvent);
         } catch (InterruptedException e) {
-            logger.error("Put state event : {} error", stateEvent, e);
+            log.error("Put state event : {} error", stateEvent, e);
             Thread.currentThread().interrupt();
         }
     }
@@ -111,30 +108,32 @@ public class StateEventResponseService {
 
         @Override
         public void run() {
-            logger.info("State event loop service started");
+            log.info("State event loop service started");
             while (!ServerLifeCycleManager.isStopped()) {
+                StateEvent stateEvent;
                 try {
-                    // if not task , blocking here
-                    StateEvent stateEvent = eventQueue.take();
-                    LoggerUtils.setWorkflowAndTaskInstanceIDMDC(stateEvent.getProcessInstanceId(),
-                            stateEvent.getTaskInstanceId());
-                    persist(stateEvent);
+                    stateEvent = eventQueue.take();
                 } catch (InterruptedException e) {
-                    logger.warn("State event loop service interrupted, will stop this loop", e);
+                    log.warn("State event loop service interrupted, will stop loop");
                     Thread.currentThread().interrupt();
                     break;
-                } finally {
-                    LoggerUtils.removeWorkflowAndTaskInstanceIdMDC();
+                }
+                try (
+                        final LogUtils.MDCAutoClosableContext mdcAutoClosableContext =
+                                LogUtils.setWorkflowAndTaskInstanceIDMDC(stateEvent.getProcessInstanceId(),
+                                        stateEvent.getTaskInstanceId())) {
+                    // if not task , blocking here
+                    persist(stateEvent);
                 }
             }
-            logger.info("State event loop service stopped");
+            log.info("State event loop service stopped");
         }
     }
 
     private void writeResponse(StateEvent stateEvent) {
         Channel channel = stateEvent.getChannel();
         if (channel != null) {
-            StateEventResponseCommand command = new StateEventResponseCommand(stateEvent.getKey());
+            StateEventResponse command = new StateEventResponse(stateEvent.getKey());
             channel.writeAndFlush(command.convert2Command());
         }
     }
@@ -142,7 +141,7 @@ public class StateEventResponseService {
     private void persist(StateEvent stateEvent) {
         try {
             if (!this.processInstanceExecCacheManager.contains(stateEvent.getProcessInstanceId())) {
-                logger.warn("Persist event into workflow execute thread error, "
+                log.warn("Persist event into workflow execute thread error, "
                         + "cannot find the workflow instance from cache manager, event: {}", stateEvent);
                 writeResponse(stateEvent);
                 return;
@@ -164,7 +163,7 @@ public class StateEventResponseService {
             // this response is not needed.
             writeResponse(stateEvent);
         } catch (Exception e) {
-            logger.error("Persist event queue error, event: {}", stateEvent, e);
+            log.error("Persist event queue error, event: {}", stateEvent, e);
         }
     }
 
