@@ -17,46 +17,44 @@
 
 package org.apache.dolphinscheduler.server.master.registry;
 
-import static com.google.common.base.Preconditions.checkNotNull;
-
+import org.apache.dolphinscheduler.common.lifecycle.ServerLifeCycleManager;
 import org.apache.dolphinscheduler.registry.api.ConnectionListener;
 import org.apache.dolphinscheduler.registry.api.ConnectionState;
-import org.apache.dolphinscheduler.service.registry.RegistryClient;
+import org.apache.dolphinscheduler.registry.api.RegistryClient;
+import org.apache.dolphinscheduler.server.master.config.MasterConfig;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.NonNull;
+import lombok.extern.slf4j.Slf4j;
 
+@Slf4j
 public class MasterConnectionStateListener implements ConnectionListener {
 
-    private static final Logger logger = LoggerFactory.getLogger(MasterConnectionStateListener.class);
-
-    private final String masterNodePath;
+    private final MasterConfig masterConfig;
     private final RegistryClient registryClient;
-    private final MasterHeartBeatTask masterHeartBeatTask;
+    private final MasterConnectStrategy masterConnectStrategy;
 
-    public MasterConnectionStateListener(String masterNodePath, RegistryClient registryClient, MasterHeartBeatTask masterHeartBeatTask) {
-        this.masterNodePath = checkNotNull(masterNodePath);
-        this.registryClient = checkNotNull(registryClient);
-        this.masterHeartBeatTask = checkNotNull(masterHeartBeatTask);
+    public MasterConnectionStateListener(@NonNull MasterConfig masterConfig,
+                                         @NonNull RegistryClient registryClient,
+                                         @NonNull MasterConnectStrategy masterConnectStrategy) {
+        this.masterConfig = masterConfig;
+        this.registryClient = registryClient;
+        this.masterConnectStrategy = masterConnectStrategy;
     }
 
     @Override
     public void onUpdate(ConnectionState state) {
+        log.info("Master received a {} event from registry, the current server state is {}", state,
+                ServerLifeCycleManager.getServerStatus());
         switch (state) {
             case CONNECTED:
-                logger.debug("registry connection state is {}", state);
                 break;
             case SUSPENDED:
-                logger.warn("registry connection state is {}, ready to retry connection", state);
                 break;
             case RECONNECTED:
-                logger.debug("registry connection state is {}, clean the node info", state);
-                registryClient.remove(masterNodePath);
-                registryClient.persistEphemeral(masterNodePath, masterHeartBeatTask.getHeartBeatInfo());
+                masterConnectStrategy.reconnect();
                 break;
             case DISCONNECTED:
-                logger.warn("registry connection state is {}, ready to stop myself", state);
-                registryClient.getStoppable().stop("registry connection state is DISCONNECTED, stop myself");
+                masterConnectStrategy.disconnect();
                 break;
             default:
         }
