@@ -29,38 +29,37 @@ import org.apache.dolphinscheduler.dao.entity.ProcessTaskRelation;
 import org.apache.dolphinscheduler.dao.entity.Resource;
 import org.apache.dolphinscheduler.dao.entity.TaskDefinition;
 import org.apache.dolphinscheduler.dao.entity.TaskInstance;
-import org.apache.dolphinscheduler.dao.entity.Tenant;
 import org.apache.dolphinscheduler.dao.mapper.ProcessTaskRelationMapper;
+import org.apache.dolphinscheduler.dao.repository.TaskInstanceDao;
 import org.apache.dolphinscheduler.plugin.task.api.TaskChannel;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
+import org.apache.dolphinscheduler.plugin.task.api.TaskPluginManager;
 import org.apache.dolphinscheduler.plugin.task.api.enums.TaskExecutionStatus;
 import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.ParametersNode;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.ResourceParametersHelper;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParamUtils;
-import org.apache.dolphinscheduler.remote.command.TaskDispatchCommand;
-import org.apache.dolphinscheduler.remote.command.TaskExecuteRunningAckMessage;
-import org.apache.dolphinscheduler.remote.command.TaskExecuteStartCommand;
+import org.apache.dolphinscheduler.plugin.task.api.utils.LogUtils;
+import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
+import org.apache.dolphinscheduler.remote.command.task.TaskExecuteRunningMessageAck;
+import org.apache.dolphinscheduler.remote.command.task.TaskExecuteStartMessage;
 import org.apache.dolphinscheduler.server.master.builder.TaskExecutionContextBuilder;
 import org.apache.dolphinscheduler.server.master.cache.StreamTaskInstanceExecCacheManager;
 import org.apache.dolphinscheduler.server.master.config.MasterConfig;
-import org.apache.dolphinscheduler.server.master.dispatch.ExecutorDispatcher;
-import org.apache.dolphinscheduler.server.master.dispatch.context.ExecutionContext;
-import org.apache.dolphinscheduler.server.master.dispatch.enums.ExecutorType;
-import org.apache.dolphinscheduler.server.master.dispatch.exceptions.ExecuteException;
 import org.apache.dolphinscheduler.server.master.event.StateEventHandleError;
 import org.apache.dolphinscheduler.server.master.event.StateEventHandleException;
 import org.apache.dolphinscheduler.server.master.metrics.TaskMetrics;
 import org.apache.dolphinscheduler.server.master.processor.queue.TaskEvent;
+import org.apache.dolphinscheduler.server.master.runner.dispatcher.WorkerTaskDispatcher;
+import org.apache.dolphinscheduler.server.master.runner.execute.DefaultTaskExecuteRunnable;
+import org.apache.dolphinscheduler.server.master.runner.execute.DefaultTaskExecuteRunnableFactory;
+import org.apache.dolphinscheduler.server.master.runner.execute.TaskExecutionContextFactory;
 import org.apache.dolphinscheduler.service.bean.SpringApplicationContext;
 import org.apache.dolphinscheduler.service.process.ProcessService;
-import org.apache.dolphinscheduler.service.task.TaskPluginManager;
-import org.apache.dolphinscheduler.service.utils.LoggerUtils;
 import org.apache.dolphinscheduler.spi.enums.ResourceType;
 
-import org.apache.commons.collections.CollectionUtils;
+import org.apache.commons.collections4.CollectionUtils;
 import org.apache.commons.lang3.StringUtils;
 
 import java.util.Date;
@@ -74,22 +73,23 @@ import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
 import lombok.NonNull;
-
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
 /**
  * stream task execute
  */
+@Slf4j
 public class StreamTaskExecuteRunnable implements Runnable {
 
-    private static final Logger logger = LoggerFactory.getLogger(StreamTaskExecuteRunnable.class);
-
     protected MasterConfig masterConfig;
 
     protected ProcessService processService;
 
-    protected ExecutorDispatcher dispatcher;
+    protected TaskInstanceDao taskInstanceDao;
+
+    protected DefaultTaskExecuteRunnableFactory defaultTaskExecuteRunnableFactory;
+
+    protected WorkerTaskDispatcher workerTaskDispatcher;
 
     protected ProcessTaskRelationMapper processTaskRelationMapper;
 
@@ -103,7 +103,9 @@ public class StreamTaskExecuteRunnable implements Runnable {
 
     protected ProcessDefinition processDefinition;
 
-    protected TaskExecuteStartCommand taskExecuteStartCommand;
+    protected TaskExecuteStartMessage taskExecuteStartMessage;
+
+    protected TaskExecutionContextFactory taskExecutionContextFactory;
 
     /**
      * task event queue
@@ -112,16 +114,18 @@ public class StreamTaskExecuteRunnable implements Runnable {
 
     private TaskRunnableStatus taskRunnableStatus = TaskRunnableStatus.CREATED;
 
-    public StreamTaskExecuteRunnable(TaskDefinition taskDefinition, TaskExecuteStartCommand taskExecuteStartCommand) {
+    public StreamTaskExecuteRunnable(TaskDefinition taskDefinition, TaskExecuteStartMessage taskExecuteStartMessage) {
         this.processService = SpringApplicationContext.getBean(ProcessService.class);
         this.masterConfig = SpringApplicationContext.getBean(MasterConfig.class);
-        this.dispatcher = SpringApplicationContext.getBean(ExecutorDispatcher.class);
+        this.workerTaskDispatcher = SpringApplicationContext.getBean(WorkerTaskDispatcher.class);
         this.taskPluginManager = SpringApplicationContext.getBean(TaskPluginManager.class);
         this.processTaskRelationMapper = SpringApplicationContext.getBean(ProcessTaskRelationMapper.class);
+        this.taskInstanceDao = SpringApplicationContext.getBean(TaskInstanceDao.class);
         this.streamTaskInstanceExecCacheManager =
                 SpringApplicationContext.getBean(StreamTaskInstanceExecCacheManager.class);
         this.taskDefinition = taskDefinition;
-        this.taskExecuteStartCommand = taskExecuteStartCommand;
+        this.taskExecuteStartMessage = taskExecuteStartMessage;
+        this.taskExecutionContextFactory = SpringApplicationContext.getBean(TaskExecutionContextFactory.class);
     }
 
     public TaskInstance getTaskInstance() {
@@ -133,7 +137,7 @@ public class StreamTaskExecuteRunnable implements Runnable {
         // submit task
         processService.updateTaskDefinitionResources(taskDefinition);
         taskInstance = newTaskInstance(taskDefinition);
-        processService.saveTaskInstance(taskInstance);
+        taskInstanceDao.upsertTaskInstance(taskInstance);
 
         // add cache
         streamTaskInstanceExecCacheManager.cache(taskInstance.getId(), this);
@@ -144,47 +148,20 @@ public class StreamTaskExecuteRunnable implements Runnable {
         int processDefinitionVersion = processTaskRelationList.get(0).getProcessDefinitionVersion();
         processDefinition = processService.findProcessDefinition(processDefinitionCode, processDefinitionVersion);
 
-        // dispatch task
-        TaskExecutionContext taskExecutionContext = getTaskExecutionContext(taskInstance);
-        if (taskExecutionContext == null) {
-            taskInstance.setState(TaskExecutionStatus.FAILURE);
-            processService.saveTaskInstance(taskInstance);
-            return;
-        }
-
-        TaskDispatchCommand dispatchCommand = new TaskDispatchCommand(taskExecutionContext,
-                masterConfig.getMasterAddress(),
-                taskExecutionContext.getHost(),
-                System.currentTimeMillis());
-
-        ExecutionContext executionContext = new ExecutionContext(dispatchCommand.convert2Command(), ExecutorType.WORKER,
-                taskExecutionContext.getWorkerGroup(), taskInstance);
-        Boolean dispatchSuccess = false;
         try {
-            dispatchSuccess = dispatcher.dispatch(executionContext);
-        } catch (ExecuteException e) {
-            logger.error("Master dispatch task to worker error, taskInstanceId: {}, worker: {}",
-                    taskInstance.getId(),
-                    executionContext.getHost(),
-                    e);
-        }
-        if (!dispatchSuccess) {
-            logger.info("Master failed to dispatch task to worker, taskInstanceId: {}, worker: {}",
-                    taskInstance.getId(),
-                    executionContext.getHost());
-
-            // set task instance fail
+            DefaultTaskExecuteRunnable taskExecuteRunnable =
+                    defaultTaskExecuteRunnableFactory.createTaskExecuteRunnable(taskInstance);
+            workerTaskDispatcher.dispatchTask(taskExecuteRunnable);
+        } catch (Exception e) {
+            log.error("Master dispatch task to worker error, taskInstanceName: {}", taskInstance.getName(), e);
             taskInstance.setState(TaskExecutionStatus.FAILURE);
-            processService.saveTaskInstance(taskInstance);
+            taskInstanceDao.upsertTaskInstance(taskInstance);
             return;
         }
-
         // set started flag
         taskRunnableStatus = TaskRunnableStatus.STARTED;
-
-        logger.info("Master success dispatch task to worker, taskInstanceId: {}, worker: {}",
-                taskInstance.getId(),
-                executionContext.getHost());
+        log.info("Master success dispatch task to worker, taskInstanceName: {}, worker: {}", taskInstance.getId(),
+                taskInstance.getHost());
     }
 
     public boolean isStart() {
@@ -193,7 +170,7 @@ public class StreamTaskExecuteRunnable implements Runnable {
 
     public boolean addTaskEvent(TaskEvent taskEvent) {
         if (taskInstance.getId() != taskEvent.getTaskInstanceId()) {
-            logger.info("state event would be abounded, taskInstanceId:{}, eventType:{}, state:{}",
+            log.info("state event would be abounded, taskInstanceId:{}, eventType:{}, state:{}",
                     taskEvent.getTaskInstanceId(), taskEvent.getEvent(), taskEvent.getState());
             return false;
         }
@@ -210,7 +187,7 @@ public class StreamTaskExecuteRunnable implements Runnable {
      */
     public void handleEvents() {
         if (!isStart()) {
-            logger.info(
+            log.info(
                     "The stream task instance is not started, will not handle its state event, current state event size: {}",
                     taskEvents.size());
             return;
@@ -219,30 +196,30 @@ public class StreamTaskExecuteRunnable implements Runnable {
         while (!this.taskEvents.isEmpty()) {
             try {
                 taskEvent = this.taskEvents.peek();
-                LoggerUtils.setTaskInstanceIdMDC(taskEvent.getTaskInstanceId());
+                LogUtils.setTaskInstanceIdMDC(taskEvent.getTaskInstanceId());
 
-                logger.info("Begin to handle state event, {}", taskEvent);
+                log.info("Begin to handle state event, {}", taskEvent);
                 if (this.handleTaskEvent(taskEvent)) {
                     this.taskEvents.remove(taskEvent);
                 }
             } catch (StateEventHandleError stateEventHandleError) {
-                logger.error("State event handle error, will remove this event: {}", taskEvent, stateEventHandleError);
+                log.error("State event handle error, will remove this event: {}", taskEvent, stateEventHandleError);
                 this.taskEvents.remove(taskEvent);
                 ThreadUtils.sleep(Constants.SLEEP_TIME_MILLIS);
             } catch (StateEventHandleException stateEventHandleException) {
-                logger.error("State event handle error, will retry this event: {}",
+                log.error("State event handle error, will retry this event: {}",
                         taskEvent,
                         stateEventHandleException);
                 ThreadUtils.sleep(Constants.SLEEP_TIME_MILLIS);
             } catch (Exception e) {
                 // we catch the exception here, since if the state event handle failed, the state event will still keep
                 // in the stateEvents queue.
-                logger.error("State event handle error, get a unknown exception, will retry this event: {}",
+                log.error("State event handle error, get a unknown exception, will retry this event: {}",
                         taskEvent,
                         e);
                 ThreadUtils.sleep(Constants.SLEEP_TIME_MILLIS);
             } finally {
-                LoggerUtils.removeWorkflowAndTaskInstanceIdMDC();
+                LogUtils.removeWorkflowAndTaskInstanceIdMDC();
             }
         }
     }
@@ -256,6 +233,7 @@ public class StreamTaskExecuteRunnable implements Runnable {
         taskInstance.setState(TaskExecutionStatus.SUBMITTED_SUCCESS);
         // set process instance id to 0
         taskInstance.setProcessInstanceId(0);
+        taskInstance.setProjectCode(taskDefinition.getProjectCode());
         // task instance type
         taskInstance.setTaskType(taskDefinition.getTaskType().toUpperCase());
         // task instance whether alert
@@ -293,7 +271,7 @@ public class StreamTaskExecuteRunnable implements Runnable {
         taskInstance.setDelayTime(taskDefinition.getDelayTime());
 
         // task dry run flag
-        taskInstance.setDryRun(taskExecuteStartCommand.getDryRun());
+        taskInstance.setDryRun(taskExecuteStartMessage.getDryRun());
 
         taskInstance.setWorkerGroup(StringUtils.isBlank(taskDefinition.getWorkerGroup()) ? DEFAULT_WORKER_GROUP
                 : taskDefinition.getWorkerGroup());
@@ -315,8 +293,8 @@ public class StreamTaskExecuteRunnable implements Runnable {
         }
 
         taskInstance.setTaskExecuteType(taskDefinition.getTaskExecuteType());
-        taskInstance.setExecutorId(taskExecuteStartCommand.getExecutorId());
-        taskInstance.setExecutorName(taskExecuteStartCommand.getExecutorName());
+        taskInstance.setExecutorId(taskExecuteStartMessage.getExecutorId());
+        taskInstance.setExecutorName(taskExecuteStartMessage.getExecutorName());
 
         return taskInstance;
     }
@@ -329,11 +307,11 @@ public class StreamTaskExecuteRunnable implements Runnable {
      */
     protected TaskExecutionContext getTaskExecutionContext(TaskInstance taskInstance) {
         int userId = taskDefinition == null ? 0 : taskDefinition.getUserId();
-        Tenant tenant = processService.getTenantForProcess(processDefinition.getTenantId(), userId);
+        String tenantCode = processService.getTenantForProcess(taskExecuteStartMessage.getTenantCode(), userId);
 
         // verify tenant is null
-        if (tenant == null) {
-            logger.error("tenant not exists,task instance id : {}", taskInstance.getId());
+        if (StringUtils.isBlank(tenantCode)) {
+            log.error("tenant not exists,task instance id : {}", taskInstance.getId());
             return null;
         }
 
@@ -342,10 +320,14 @@ public class StreamTaskExecuteRunnable implements Runnable {
         TaskChannel taskChannel = taskPluginManager.getTaskChannel(taskInstance.getTaskType());
         ResourceParametersHelper resources = taskChannel.getResources(taskInstance.getTaskParams());
 
-        AbstractParameters baseParam = taskPluginManager.getParameters(ParametersNode.builder()
-                .taskType(taskInstance.getTaskType()).taskParams(taskInstance.getTaskParams()).build());
+        AbstractParameters baseParam = taskPluginManager.getParameters(
+                ParametersNode.builder()
+                        .taskType(taskInstance.getTaskType())
+                        .taskParams(taskInstance.getTaskParams())
+                        .build());
         Map<String, Property> propertyMap = paramParsingPreparation(taskInstance, baseParam);
         TaskExecutionContext taskExecutionContext = TaskExecutionContextBuilder.get()
+                .buildWorkflowInstanceHost(masterConfig.getMasterAddress())
                 .buildTaskInstanceRelatedInfo(taskInstance)
                 .buildTaskDefinitionRelatedInfo(taskDefinition)
                 .buildResourceParametersInfo(resources)
@@ -353,13 +335,14 @@ public class StreamTaskExecuteRunnable implements Runnable {
                 .buildParamInfo(propertyMap)
                 .create();
 
-        taskExecutionContext.setTenantCode(tenant.getTenantCode());
+        taskExecutionContext.setTenantCode(tenantCode);
         taskExecutionContext.setProjectCode(processDefinition.getProjectCode());
         taskExecutionContext.setProcessDefineCode(processDefinition.getCode());
         taskExecutionContext.setProcessDefineVersion(processDefinition.getVersion());
         // process instance id default 0
         taskExecutionContext.setProcessInstanceId(0);
-
+        taskExecutionContextFactory.setDataQualityTaskExecutionContext(taskExecutionContext, taskInstance, tenantCode);
+        taskExecutionContextFactory.setK8sTaskRelatedInfo(taskExecutionContext, taskInstance);
         return taskExecutionContext;
     }
 
@@ -416,14 +399,14 @@ public class StreamTaskExecuteRunnable implements Runnable {
         taskInstance.setEndTime(taskEvent.getEndTime());
         taskInstance.setVarPool(taskEvent.getVarPool());
         processService.changeOutParam(taskInstance);
-        processService.updateTaskInstance(taskInstance);
+        taskInstanceDao.updateById(taskInstance);
 
         // send ack
         sendAckToWorker(taskEvent);
 
         if (taskInstance.getState().isFinished()) {
             streamTaskInstanceExecCacheManager.removeByTaskInstanceId(taskInstance.getId());
-            logger.info("The stream task instance is finish, taskInstanceId:{}, state:{}", taskInstance.getId(),
+            log.info("The stream task instance is finish, taskInstanceId:{}, state:{}", taskInstance.getId(),
                     taskEvent.getState());
         }
 
@@ -433,7 +416,7 @@ public class StreamTaskExecuteRunnable implements Runnable {
     private void measureTaskState(TaskEvent taskEvent) {
         if (taskEvent == null || taskEvent.getState() == null) {
             // the event is broken
-            logger.warn("The task event is broken..., taskEvent: {}", taskEvent);
+            log.warn("The task event is broken..., taskEvent: {}", taskEvent);
             return;
         }
         if (taskEvent.getState().isFinished()) {
@@ -457,8 +440,8 @@ public class StreamTaskExecuteRunnable implements Runnable {
     public Map<String, Property> paramParsingPreparation(@NonNull TaskInstance taskInstance,
                                                          @NonNull AbstractParameters parameters) {
         // assign value to definedParams here
-        Map<String, String> globalParamsMap = taskExecuteStartCommand.getStartParams();
-        Map<String, Property> globalParams = ParamUtils.getUserDefParamsMap(globalParamsMap);
+        Map<String, String> globalParamsMap = taskExecuteStartMessage.getStartParams();
+        Map<String, Property> globalParams = ParameterUtils.getUserDefParamsMap(globalParamsMap);
 
         // combining local and global parameters
         Map<String, Property> localParams = parameters.getInputLocalParametersMap();
@@ -483,9 +466,14 @@ public class StreamTaskExecuteRunnable implements Runnable {
 
     private void sendAckToWorker(TaskEvent taskEvent) {
         // If event handle success, send ack to worker to otherwise the worker will retry this event
-        TaskExecuteRunningAckMessage taskExecuteRunningAckMessage =
-                new TaskExecuteRunningAckMessage(true, taskEvent.getTaskInstanceId());
-        taskEvent.getChannel().writeAndFlush(taskExecuteRunningAckMessage.convert2Command());
+        TaskExecuteRunningMessageAck taskExecuteRunningMessageAck =
+                new TaskExecuteRunningMessageAck(
+                        true,
+                        taskEvent.getTaskInstanceId(),
+                        masterConfig.getMasterAddress(),
+                        taskEvent.getWorkerAddress(),
+                        System.currentTimeMillis());
+        taskEvent.getChannel().writeAndFlush(taskExecuteRunningMessageAck.convert2Command());
     }
 
     private enum TaskRunnableStatus {
