@@ -16,8 +16,10 @@
  */
 package org.apache.dolphinscheduler.remote.processor;
 
+import org.apache.dolphinscheduler.remote.command.Message;
+import org.apache.dolphinscheduler.remote.command.MessageType;
+
 import io.netty.channel.Channel;
-import org.apache.dolphinscheduler.remote.command.Command;
 
 /**
  *  netty request processor
@@ -27,7 +29,9 @@ public interface NettyRequestProcessor {
     /**
      *  process logic
      * @param channel channel
-     * @param command command
+     * @param message command
      */
-    void process(final Channel channel, final Command command);
+    void process(final Channel channel, final Message message);
+
+    MessageType getCommandType();
 }
