@@ -17,22 +17,20 @@
 
 package org.apache.dolphinscheduler.remote.utils;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
-
 import java.util.concurrent.RejectedExecutionHandler;
 import java.util.concurrent.ThreadPoolExecutor;
 
+import lombok.extern.slf4j.Slf4j;
+
 /**
  * caller thread execute
  */
+@Slf4j
 public class CallerThreadExecutePolicy implements RejectedExecutionHandler {
 
-    private final Logger logger = LoggerFactory.getLogger(CallerThreadExecutePolicy.class);
-
     @Override
     public void rejectedExecution(Runnable r, ThreadPoolExecutor executor) {
-        logger.warn("queue is full, trigger caller thread execute");
+        log.warn("queue is full, trigger caller thread execute");
         r.run();
     }
 }
