@@ -36,6 +36,7 @@ import com.google.common.base.Preconditions;
  * All the task instances are in the same process instance.
  */
 public class PeerTaskInstancePriorityQueue implements TaskPriorityQueue<TaskInstance> {
+
     /**
      * queue size
      */
@@ -88,7 +89,8 @@ public class PeerTaskInstancePriorityQueue implements TaskPriorityQueue<TaskInst
      */
     @Override
     public TaskInstance poll(long timeout, TimeUnit unit) throws TaskPriorityQueueException {
-        throw new TaskPriorityQueueException("This operation is not currently supported and suggest to use PriorityBlockingQueue if you want！");
+        throw new TaskPriorityQueueException(
+                "This operation is not currently supported and suggest to use PriorityBlockingQueue if you want！");
     }
 
     /**
@@ -157,8 +159,7 @@ public class PeerTaskInstancePriorityQueue implements TaskPriorityQueue<TaskInst
         return String.join(
                 String.valueOf(taskInstance.getProcessInstanceId()),
                 String.valueOf(taskInstance.getTaskCode()),
-                String.valueOf(taskInstance.getTaskDefinitionVersion())
-                , "-");
+                String.valueOf(taskInstance.getTaskDefinitionVersion()), "-");
     }
 
     /**
@@ -175,9 +176,9 @@ public class PeerTaskInstancePriorityQueue implements TaskPriorityQueue<TaskInst
          */
         @Override
         public int compare(TaskInstance o1, TaskInstance o2) {
-            if(o1.getTaskInstancePriority().equals(o2.getTaskInstancePriority())){
+            if (o1.getTaskInstancePriority().equals(o2.getTaskInstancePriority())) {
                 // larger number, higher priority
-                return Constants.OPPOSITE_VALUE * Integer.compare(o1.getTaskGroupPriority(),o2.getTaskGroupPriority());
+                return Constants.OPPOSITE_VALUE * Integer.compare(o1.getTaskGroupPriority(), o2.getTaskGroupPriority());
             }
             return o1.getTaskInstancePriority().compareTo(o2.getTaskInstancePriority());
         }
