@@ -23,7 +23,6 @@ import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.ResourceParametersHelper;
 
 import java.io.Serializable;
-import java.util.Date;
 import java.util.Map;
 
 import lombok.AllArgsConstructor;
@@ -31,6 +30,8 @@ import lombok.Builder;
 import lombok.Data;
 import lombok.NoArgsConstructor;
 
+import com.fasterxml.jackson.annotation.JsonInclude;
+
 /**
  * to master/worker task transport
  */
@@ -38,6 +39,7 @@ import lombok.NoArgsConstructor;
 @Builder
 @NoArgsConstructor
 @AllArgsConstructor
+@JsonInclude(JsonInclude.Include.NON_NULL)
 public class TaskExecutionContext implements Serializable {
 
     private static final long serialVersionUID = -1L;
@@ -55,18 +57,20 @@ public class TaskExecutionContext implements Serializable {
     /**
      * task first submit time.
      */
-    private Date firstSubmitTime;
+    private long firstSubmitTime;
 
     /**
      * task start time
      */
-    private Date startTime;
+    private long startTime;
 
     /**
      * task type
      */
     private String taskType;
 
+    private String workflowInstanceHost;
+
     /**
      * host
      */
@@ -82,6 +86,11 @@ public class TaskExecutionContext implements Serializable {
      */
     private String logPath;
 
+    /**
+     * applicationId path
+     */
+    private String appInfoPath;
+
     /**
      * task json
      */
@@ -115,7 +124,7 @@ public class TaskExecutionContext implements Serializable {
     /**
      * process instance schedule time
      */
-    private Date scheduleTime;
+    private long scheduleTime;
 
     /**
      * process instance global parameters
@@ -137,11 +146,6 @@ public class TaskExecutionContext implements Serializable {
      */
     private String tenantCode;
 
-    /**
-     * task queue
-     */
-    private String queue;
-
     /**
      * process define id
      */
@@ -162,11 +166,6 @@ public class TaskExecutionContext implements Serializable {
      */
     private String taskParams;
 
-    /**
-     * envFile
-     */
-    private String envFile;
-
     /**
      * environmentConfig
      */
@@ -174,6 +173,7 @@ public class TaskExecutionContext implements Serializable {
 
     /**
      * definedParams
+     * // todo: we need to rename definedParams, prepareParamsMap, paramsMap, this is confusing
      */
     private Map<String, String> definedParams;
 
@@ -212,18 +212,12 @@ public class TaskExecutionContext implements Serializable {
      */
     private TaskExecutionStatus currentExecutionStatus;
 
-    /**
-     * Task Logger name should be like:
-     * TaskAppId=TASK-{firstSubmitTime}-{processDefineCode}_{processDefineVersion}-{processInstanceId}-{taskInstanceId}
-     */
-    private String taskLogName;
-
     private ResourceParametersHelper resourceParametersHelper;
 
     /**
      * endTime
      */
-    private Date endTime;
+    private long endTime;
 
     /**
      * sql TaskExecutionContext
@@ -261,4 +255,20 @@ public class TaskExecutionContext implements Serializable {
      * max memory
      */
     private Integer memoryMax;
+
+    /**
+     * test flag
+     */
+    private int testFlag;
+
+    private boolean logBufferEnable;
+
+    /**
+     * dispatch fail times
+     */
+    private int dispatchFailTimes;
+
+    public void increaseDispatchFailTimes() {
+        this.dispatchFailTimes++;
+    }
 }
