@@ -27,10 +27,14 @@ import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.ADD_STRI
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.COMMA;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.DIVISION_CHAR;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.DIVISION_STRING;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.HYPHEN;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.LAST_DAY;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.LEFT_BRACE_CHAR;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.LEFT_BRACE_STRING;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.MONTH_BEGIN;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.MONTH_END;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.MONTH_FIRST_DAY;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.MONTH_LAST_DAY;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.MULTIPLY_CHAR;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.MULTIPLY_STRING;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.N;
@@ -39,9 +43,13 @@ import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.PARAMETE
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.RIGHT_BRACE_CHAR;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.SUBTRACT_CHAR;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.SUBTRACT_STRING;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.THIS_DAY;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.TIMESTAMP;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.WEEK_BEGIN;
 import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.WEEK_END;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.WEEK_FIRST_DAY;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.WEEK_LAST_DAY;
+import static org.apache.dolphinscheduler.plugin.task.api.TaskConstants.YEAR_WEEK;
 
 import org.apache.dolphinscheduler.common.utils.DateUtils;
 
@@ -49,19 +57,19 @@ import org.apache.commons.lang3.StringUtils;
 
 import java.util.AbstractMap;
 import java.util.ArrayList;
+import java.util.Calendar;
 import java.util.Date;
 import java.util.List;
 import java.util.Map;
 import java.util.Stack;
 
-import org.slf4j.Logger;
-import org.slf4j.LoggerFactory;
+import lombok.extern.slf4j.Slf4j;
 
 /**
  * time place holder utils
  */
+@Slf4j
 public class TimePlaceholderUtils {
-    private static final Logger logger = LoggerFactory.getLogger(TimePlaceholderUtils.class);
 
     /**
      * Prefix of the position to be replaced
@@ -97,7 +105,8 @@ public class TimePlaceholderUtils {
      *                                       be ignored ({@code true}) or cause an exception ({@code false})
      */
     private static PropertyPlaceholderHelper getPropertyPlaceholderHelper(boolean ignoreUnresolvablePlaceholders) {
-        return new PropertyPlaceholderHelper(PLACEHOLDER_PREFIX, PLACEHOLDER_SUFFIX, null, ignoreUnresolvablePlaceholders);
+        return new PropertyPlaceholderHelper(PLACEHOLDER_PREFIX, PLACEHOLDER_SUFFIX, null,
+                ignoreUnresolvablePlaceholders);
     }
 
     /**
@@ -131,7 +140,8 @@ public class TimePlaceholderUtils {
                     arr[i] = N;
                 } else {
                     char c = arr[i - 1];
-                    if (c == ADD_CHAR || c == SUBTRACT_CHAR || c == MULTIPLY_CHAR || c == DIVISION_CHAR || c == LEFT_BRACE_CHAR) {
+                    if (c == ADD_CHAR || c == SUBTRACT_CHAR || c == MULTIPLY_CHAR || c == DIVISION_CHAR
+                            || c == LEFT_BRACE_CHAR) {
                         arr[i] = N;
                     }
                 }
@@ -140,7 +150,8 @@ public class TimePlaceholderUtils {
                     arr[i] = P;
                 } else {
                     char c = arr[i - 1];
-                    if (c == ADD_CHAR || c == SUBTRACT_CHAR || c == MULTIPLY_CHAR || c == DIVISION_CHAR || c == LEFT_BRACE_CHAR) {
+                    if (c == ADD_CHAR || c == SUBTRACT_CHAR || c == MULTIPLY_CHAR || c == DIVISION_CHAR
+                            || c == LEFT_BRACE_CHAR) {
                         arr[i] = P;
                     }
                 }
@@ -277,9 +288,11 @@ public class TimePlaceholderUtils {
      * @return true or false
      */
     private static boolean compare(String peek, String cur) {
-        if (MULTIPLY_STRING.equals(peek) && (DIVISION_STRING.equals(cur) || MULTIPLY_STRING.equals(cur) || ADD_STRING.equals(cur) || SUBTRACT_STRING.equals(cur))) {
+        if (MULTIPLY_STRING.equals(peek) && (DIVISION_STRING.equals(cur) || MULTIPLY_STRING.equals(cur)
+                || ADD_STRING.equals(cur) || SUBTRACT_STRING.equals(cur))) {
             return true;
-        } else if (DIVISION_STRING.equals(peek) && (DIVISION_STRING.equals(cur) || MULTIPLY_STRING.equals(cur) || ADD_STRING.equals(cur) || SUBTRACT_STRING.equals(cur))) {
+        } else if (DIVISION_STRING.equals(peek) && (DIVISION_STRING.equals(cur) || MULTIPLY_STRING.equals(cur)
+                || ADD_STRING.equals(cur) || SUBTRACT_STRING.equals(cur))) {
             return true;
         } else if (ADD_STRING.equals(peek) && (ADD_STRING.equals(cur) || SUBTRACT_STRING.equals(cur))) {
             return true;
@@ -292,8 +305,9 @@ public class TimePlaceholderUtils {
     /**
      * Placeholder replacement resolver
      */
-    private static class TimePlaceholderResolver implements
-        PropertyPlaceholderHelper.PlaceholderResolver {
+    private static class TimePlaceholderResolver
+            implements
+                PropertyPlaceholderHelper.PlaceholderResolver {
 
         private final String value;
 
@@ -309,7 +323,7 @@ public class TimePlaceholderUtils {
             try {
                 return calculateTime(placeholderName, date);
             } catch (Exception ex) {
-                logger.error("resolve placeholder '{}' in [ {} ]", placeholderName, value, ex);
+                log.error("resolve placeholder '{}' in [ {} ]", placeholderName, value, ex);
                 return null;
             }
         }
@@ -353,18 +367,106 @@ public class TimePlaceholderUtils {
                 Date timestamp = DateUtils.parse(dateStr, PARAMETER_FORMAT_TIME);
 
                 value = String.valueOf(timestamp.getTime() / 1000);
+            } else if (expression.startsWith(YEAR_WEEK)) {
+                value = calculateYearWeek(expression, date);
             } else {
                 Map.Entry<Date, String> entry = calcTimeExpression(expression, date);
                 value = DateUtils.format(entry.getKey(), entry.getValue());
             }
         } catch (Exception e) {
-            logger.error(e.getMessage(), e);
+            log.error(e.getMessage(), e);
             throw e;
         }
 
         return value;
     }
 
+    /**
+     * get week of year
+     * @param expression expression
+     * @param date       date
+     * @return week of year
+     */
+    public static String calculateYearWeek(String expression, Date date) {
+
+        String dataFormat = expression.substring(YEAR_WEEK.length() + 1, expression.length() - 1);
+
+        String targetDate = "";
+        try {
+
+            if (dataFormat.contains(COMMA)) {
+                String param1 = dataFormat.split(COMMA)[0];
+                String param2 = dataFormat.split(COMMA)[1];
+                dataFormat = param1;
+
+                targetDate = transformYearWeek(date, dataFormat, calculate(param2));
+
+            } else {
+                targetDate = transformYearWeek(date, dataFormat, 1);
+            }
+        } catch (Exception e) {
+            throw new RuntimeException("expression not valid");
+        }
+
+        return targetDate;
+    }
+
+    /**
+     * transform week of year
+     * @param date date
+     * @param format date_format,for example: yyyy-MM-dd / yyyyMMdd
+     * @param weekDay day of week
+     * @return date_string
+     */
+    private static String transformYearWeek(Date date, String format, int weekDay) {
+        Calendar calendar = Calendar.getInstance();
+        // Minimum number of days required for the first week of the year
+        calendar.setMinimalDaysInFirstWeek(4);
+
+        // By default ,Set Monday as the first day of the week
+        switch (weekDay) {
+            case 2:
+                calendar.setFirstDayOfWeek(Calendar.TUESDAY);
+                break;
+            case 3:
+                calendar.setFirstDayOfWeek(Calendar.WEDNESDAY);
+                break;
+            case 4:
+                calendar.setFirstDayOfWeek(Calendar.THURSDAY);
+                break;
+            case 5:
+                calendar.setFirstDayOfWeek(Calendar.FRIDAY);
+                break;
+            case 6:
+                calendar.setFirstDayOfWeek(Calendar.SATURDAY);
+                break;
+            case 7:
+                calendar.setFirstDayOfWeek(Calendar.SUNDAY);
+                break;
+            default:
+                calendar.setFirstDayOfWeek(Calendar.MONDAY);
+                break;
+        }
+        calendar.setTimeInMillis(date.getTime());
+
+        int weekOfYear = calendar.get(Calendar.WEEK_OF_YEAR);
+
+        int year = calendar.get(Calendar.YEAR);
+
+        String weekYearStr = "";
+        if (weekOfYear < 10 && format.contains(HYPHEN)) {
+            weekYearStr = String.format("%d%s0%d", year, HYPHEN, weekOfYear);
+        } else if (weekOfYear >= 10 && format.contains(HYPHEN)) {
+            weekYearStr = String.format("%d%s%d", year, HYPHEN, weekOfYear);
+        } else if (weekOfYear < 10) {
+            weekYearStr = String.format("%d0%d", year, weekOfYear);
+        } else {
+            weekYearStr = String.format("%d%d", year, weekOfYear);
+        }
+
+        return weekYearStr;
+    }
+
     /**
      * calculate time expresstion
      *
@@ -385,6 +487,18 @@ public class TimePlaceholderUtils {
             resultEntry = calcWeekStart(expression, date);
         } else if (expression.startsWith(WEEK_END)) {
             resultEntry = calcWeekEnd(expression, date);
+        } else if (expression.startsWith(MONTH_FIRST_DAY)) {
+            resultEntry = calcCustomDay(expression, MONTH_FIRST_DAY, date);
+        } else if (expression.startsWith(MONTH_LAST_DAY)) {
+            resultEntry = calcCustomDay(expression, MONTH_LAST_DAY, date);
+        } else if (expression.startsWith(THIS_DAY)) {
+            resultEntry = calcCustomDay(expression, THIS_DAY, date);
+        } else if (expression.startsWith(LAST_DAY)) {
+            resultEntry = calcCustomDay(expression, LAST_DAY, date);
+        } else if (expression.startsWith(WEEK_FIRST_DAY)) {
+            resultEntry = calcCustomDay(expression, WEEK_FIRST_DAY, date);
+        } else if (expression.startsWith(WEEK_LAST_DAY)) {
+            resultEntry = calcCustomDay(expression, WEEK_LAST_DAY, date);
         } else {
             resultEntry = calcMinutes(expression, date);
         }
@@ -440,6 +554,90 @@ public class TimePlaceholderUtils {
         throw new RuntimeException("expression not valid");
     }
 
+    /**
+     * calculate time expression
+     * month first day month last day
+     * @param expression expression
+     * @param date       date
+     * @return calculate time expression with date,format
+     */
+    public static Map.Entry<Date, String> calcCustomDay(String expression, String keyDate, Date date) {
+        String dataFormat = "yyyy-MM-dd";
+        Date targetDate = new Date();
+
+        switch (keyDate) {
+            case MONTH_FIRST_DAY:
+                dataFormat = expression.substring(MONTH_FIRST_DAY.length() + 1, expression.length() - 1);
+
+                if (dataFormat.contains(COMMA)) {
+                    String param1 = dataFormat.split(COMMA)[0];
+                    String param2 = dataFormat.split(COMMA)[1];
+                    dataFormat = param1;
+
+                    targetDate = addMonths(DateUtils.getFirstDayOfMonth(date), calculate(param2));
+                } else {
+                    targetDate = DateUtils.getFirstDayOfMonth(date);
+                }
+
+                break;
+            case MONTH_LAST_DAY:
+                dataFormat = expression.substring(MONTH_LAST_DAY.length() + 1, expression.length() - 1);
+
+                if (dataFormat.contains(COMMA)) {
+                    String param1 = dataFormat.split(COMMA)[0];
+                    String param2 = dataFormat.split(COMMA)[1];
+                    dataFormat = param1;
+
+                    Date lastMonthDay = addMonths(date, calculate(param2));
+
+                    targetDate = DateUtils.getLastDayOfMonth(lastMonthDay);
+
+                } else {
+                    targetDate = DateUtils.getLastDayOfMonth(date);
+                }
+                break;
+            case THIS_DAY:
+                dataFormat = expression.substring(THIS_DAY.length() + 1, expression.length() - 1);
+                targetDate = addDays(date, 0);
+                break;
+            case LAST_DAY:
+                dataFormat = expression.substring(LAST_DAY.length() + 1, expression.length() - 1);
+                targetDate = addDays(date, -1);
+                break;
+            case WEEK_FIRST_DAY:
+                dataFormat = expression.substring(WEEK_FIRST_DAY.length() + 1, expression.length() - 1);
+
+                if (dataFormat.contains(COMMA)) {
+                    String param1 = dataFormat.split(COMMA)[0];
+                    String param2 = dataFormat.split(COMMA)[1];
+                    dataFormat = param1;
+
+                    targetDate = addWeeks(DateUtils.getMonday(date), calculate(param2));
+                } else {
+                    targetDate = addWeeks(DateUtils.getMonday(date), 0);
+                }
+                break;
+            case WEEK_LAST_DAY:
+                dataFormat = expression.substring(WEEK_LAST_DAY.length() + 1, expression.length() - 1);
+
+                if (dataFormat.contains(COMMA)) {
+                    String param1 = dataFormat.split(COMMA)[0];
+                    String param2 = dataFormat.split(COMMA)[1];
+                    dataFormat = param1;
+
+                    targetDate = addWeeks(DateUtils.getSunday(date), calculate(param2));
+                } else {
+                    targetDate = addWeeks(DateUtils.getSunday(date), 0);
+                }
+                break;
+            default:
+                break;
+        }
+
+        return new AbstractMap.SimpleImmutableEntry<>(targetDate, dataFormat);
+
+    }
+
     /**
      * get first day of week
      *
@@ -563,7 +761,7 @@ public class TimePlaceholderUtils {
         } else {
 
             calcExpression = String.format("60*24*(%s)%s", minuteExpression.substring(0, index),
-                minuteExpression.substring(index));
+                    minuteExpression.substring(index));
         }
 
         return calculate(calcExpression);
