@@ -38,13 +38,11 @@ import org.apache.dolphinscheduler.plugin.datasource.api.utils.CommonUtils;
 import org.apache.dolphinscheduler.plugin.task.api.AbstractYarnTask;
 import org.apache.dolphinscheduler.plugin.task.api.DataQualityTaskExecutionContext;
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
-import org.apache.dolphinscheduler.plugin.task.api.model.Property;
 import org.apache.dolphinscheduler.plugin.task.api.model.ResourceInfo;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.dataquality.DataQualityParameters;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParamUtils;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParameterUtils;
 import org.apache.dolphinscheduler.plugin.task.api.utils.ArgsUtils;
+import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
 import org.apache.dolphinscheduler.plugin.task.dq.rule.RuleManager;
 import org.apache.dolphinscheduler.plugin.task.dq.rule.parameter.DataQualityConfiguration;
 import org.apache.dolphinscheduler.plugin.task.dq.utils.SparkArgsUtils;
@@ -58,6 +56,7 @@ import java.time.format.DateTimeFormatter;
 import java.util.ArrayList;
 import java.util.List;
 import java.util.Map;
+import java.util.stream.Collectors;
 
 /**
  * In DataQualityTask, the input parameters will be converted into DataQualityConfiguration,
@@ -67,9 +66,9 @@ import java.util.Map;
 public class DataQualityTask extends AbstractYarnTask {
 
     /**
-     * spark2 command
+     * spark command
      */
-    private static final String SPARK2_COMMAND = "${SPARK_HOME2}/bin/spark-submit";
+    private static final String SPARK_COMMAND = "${SPARK_HOME}/bin/spark-submit";
 
     private DataQualityParameters dataQualityParameters;
 
@@ -82,12 +81,13 @@ public class DataQualityTask extends AbstractYarnTask {
 
     @Override
     public void init() {
-        logger.info("data quality task params {}", dqTaskExecutionContext.getTaskParams());
 
-        dataQualityParameters = JSONUtils.parseObject(dqTaskExecutionContext.getTaskParams(), DataQualityParameters.class);
+        dataQualityParameters =
+                JSONUtils.parseObject(dqTaskExecutionContext.getTaskParams(), DataQualityParameters.class);
+        log.info("Initialize data quality task params {}", JSONUtils.toPrettyJsonString(dataQualityParameters));
 
         if (null == dataQualityParameters) {
-            logger.error("data quality params is null");
+            log.error("data quality params is null");
             return;
         }
 
@@ -95,15 +95,15 @@ public class DataQualityTask extends AbstractYarnTask {
             throw new RuntimeException("data quality task params is not valid");
         }
 
-        Map<String,String> inputParameter = dataQualityParameters.getRuleInputParameter();
-        for (Map.Entry<String,String> entry: inputParameter.entrySet()) {
+        Map<String, String> inputParameter = dataQualityParameters.getRuleInputParameter();
+        for (Map.Entry<String, String> entry : inputParameter.entrySet()) {
             if (entry != null && entry.getValue() != null) {
                 entry.setValue(entry.getValue().trim());
             }
         }
 
-        DataQualityTaskExecutionContext dataQualityTaskExecutionContext
-                        = dqTaskExecutionContext.getDataQualityTaskExecutionContext();
+        DataQualityTaskExecutionContext dataQualityTaskExecutionContext =
+                dqTaskExecutionContext.getDataQualityTaskExecutionContext();
 
         operateInputParameter(inputParameter, dataQualityTaskExecutionContext);
 
@@ -121,14 +121,11 @@ public class DataQualityTask extends AbstractYarnTask {
                                 StringEscapeUtils.escapeJava(JSONUtils.toJsonString(dataQualityConfiguration)))
                         + "\"");
 
-        dataQualityParameters
-                .getSparkParameters()
-                .setQueue(dqTaskExecutionContext.getQueue());
-
         setMainJarName();
     }
 
-    private void operateInputParameter(Map<String, String> inputParameter, DataQualityTaskExecutionContext dataQualityTaskExecutionContext) {
+    private void operateInputParameter(Map<String, String> inputParameter,
+                                       DataQualityTaskExecutionContext dataQualityTaskExecutionContext) {
         DateTimeFormatter df = DateTimeFormatter.ofPattern(YYYY_MM_DD_HH_MM_SS);
         LocalDateTime time = LocalDateTime.now();
         String now = df.format(time);
@@ -143,7 +140,7 @@ public class DataQualityTask extends AbstractYarnTask {
         inputParameter.put(TASK_INSTANCE_ID, String.valueOf(dqTaskExecutionContext.getTaskInstanceId()));
 
         if (StringUtils.isEmpty(inputParameter.get(DATA_TIME))) {
-            inputParameter.put(DATA_TIME,ArgsUtils.wrapperSingleQuotes(now));
+            inputParameter.put(DATA_TIME, ArgsUtils.wrapperSingleQuotes(now));
         }
 
         if (StringUtils.isNotEmpty(inputParameter.get(REGEXP_PATTERN))) {
@@ -158,30 +155,28 @@ public class DataQualityTask extends AbstractYarnTask {
                             + UNDERLINE + dqTaskExecutionContext.getProcessInstanceId()
                             + UNDERLINE + dqTaskExecutionContext.getTaskName());
         } else {
-            inputParameter.put(ERROR_OUTPUT_PATH,"");
+            inputParameter.put(ERROR_OUTPUT_PATH, "");
         }
     }
 
     @Override
-    protected String buildCommand() {
+    protected String getScript() {
         List<String> args = new ArrayList<>();
-
-        args.add(SPARK2_COMMAND);
+        args.add(SPARK_COMMAND);
         args.addAll(SparkArgsUtils.buildArgs(dataQualityParameters.getSparkParameters()));
-
-        // replace placeholder
-        Map<String, Property> paramsMap = dqTaskExecutionContext.getPrepareParamsMap();
-        String command = ParameterUtils.convertParameterPlaceholders(String.join(" ", args), ParamUtils.convert(paramsMap));
-        logger.info("data quality task command: {}", command);
-
-        return command;
+        return args.stream().collect(Collectors.joining(" "));
     }
 
     @Override
+    protected Map<String, String> getProperties() {
+        return ParameterUtils.convert(dqTaskExecutionContext.getPrepareParamsMap());
+    }
+
     protected void setMainJarName() {
         ResourceInfo mainJar = new ResourceInfo();
         String basePath = System.getProperty("user.dir").replace(File.separator + "bin", "");
-        mainJar.setRes(basePath + File.separator + "libs" + File.separator + CommonUtils.getDataQualityJarName());
+        mainJar.setResourceName(
+                basePath + File.separator + "libs" + File.separator + CommonUtils.getDataQualityJarName());
         dataQualityParameters.getSparkParameters().setMainJar(mainJar);
     }
 
