@@ -43,10 +43,10 @@ public class PigeonTaskChannelFactory implements TaskChannelFactory {
 
     @Override
     public List<PluginParams> getParams() {
-        InputParam webHookParam
-                = InputParam.newBuilder(PigeonParamsConstants.NAME_TARGET_JOB_NAME, PigeonParamsConstants.TARGET_JOB_NAME)
-                .addValidate(Validate.newBuilder().setRequired(true).build())
-                .build();
+        InputParam webHookParam =
+                InputParam.newBuilder(PigeonParamsConstants.NAME_TARGET_JOB_NAME, PigeonParamsConstants.TARGET_JOB_NAME)
+                        .addValidate(Validate.newBuilder().setRequired(true).build())
+                        .build();
         return Arrays.asList(webHookParam);
     }
 }
