@@ -17,7 +17,9 @@
 
 package org.apache.dolphinscheduler.plugin.task.sql;
 
+import org.apache.dolphinscheduler.common.utils.DateUtils;
 import org.apache.dolphinscheduler.common.utils.JSONUtils;
+import org.apache.dolphinscheduler.plugin.datasource.api.plugin.DataSourceClientProvider;
 import org.apache.dolphinscheduler.plugin.datasource.api.utils.CommonUtils;
 import org.apache.dolphinscheduler.plugin.datasource.api.utils.DataSourceUtils;
 import org.apache.dolphinscheduler.plugin.task.api.AbstractTask;
@@ -34,8 +36,7 @@ import org.apache.dolphinscheduler.plugin.task.api.model.TaskAlertInfo;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.AbstractParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.SqlParameters;
 import org.apache.dolphinscheduler.plugin.task.api.parameters.resource.UdfFuncParameters;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParamUtils;
-import org.apache.dolphinscheduler.plugin.task.api.parser.ParameterUtils;
+import org.apache.dolphinscheduler.plugin.task.api.utils.ParameterUtils;
 import org.apache.dolphinscheduler.spi.datasource.BaseConnectionParam;
 import org.apache.dolphinscheduler.spi.enums.DbType;
 
@@ -50,6 +51,7 @@ import java.sql.SQLException;
 import java.sql.Statement;
 import java.text.MessageFormat;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
@@ -94,6 +96,10 @@ public class SqlTask extends AbstractTask {
 
     private SQLTaskExecutionContext sqlTaskExecutionContext;
 
+    public static final int TEST_FLAG_YES = 1;
+
+    private static final String SQL_SEPARATOR = ";\n";
+
     /**
      * Abstract Yarn Task
      *
@@ -103,10 +109,12 @@ public class SqlTask extends AbstractTask {
         super(taskRequest);
         this.taskExecutionContext = taskRequest;
         this.sqlParameters = JSONUtils.parseObject(taskExecutionContext.getTaskParams(), SqlParameters.class);
-
-        assert sqlParameters != null;
-        if (!sqlParameters.checkParameters()) {
-            throw new RuntimeException("sql task params is not valid");
+        log.info("Initialize sql task parameter {}", JSONUtils.toPrettyJsonString(sqlParameters));
+        if (sqlParameters == null || !sqlParameters.checkParameters()) {
+            throw new TaskException("sql task params is not valid");
+        }
+        if (taskExecutionContext.getTestFlag() == TEST_FLAG_YES && this.sqlParameters.getDatasource() == 0) {
+            throw new TaskException("unbound test data source");
         }
 
         sqlTaskExecutionContext =
@@ -120,8 +128,8 @@ public class SqlTask extends AbstractTask {
 
     @Override
     public void handle(TaskCallBack taskCallBack) throws TaskException {
-        logger.info("Full sql parameters: {}", sqlParameters);
-        logger.info(
+        log.info("Full sql parameters: {}", sqlParameters);
+        log.info(
                 "sql type : {}, datasource : {}, sql : {} , localParams : {},udfs : {},showType : {},connParams : {},varPool : {} ,query max result limit  {}",
                 sqlParameters.getType(),
                 sqlParameters.getDatasource(),
@@ -132,19 +140,21 @@ public class SqlTask extends AbstractTask {
                 sqlParameters.getConnParams(),
                 sqlParameters.getVarPool(),
                 sqlParameters.getLimit());
+        String separator = SQL_SEPARATOR;
         try {
 
             // get datasource
             baseConnectionParam = (BaseConnectionParam) DataSourceUtils.buildConnectionParams(
                     DbType.valueOf(sqlParameters.getType()),
                     sqlTaskExecutionContext.getConnectionParams());
-
+            if (DbType.valueOf(sqlParameters.getType()).isSupportMultipleStatement()) {
+                separator = "";
+            }
             // ready to execute SQL and parameter entity Map
-            List<SqlBinds> mainStatementSqlBinds =
-                    SqlSplitter.split(sqlParameters.getSql(), sqlParameters.getSegmentSeparator())
-                            .stream()
-                            .map(this::getSqlAndSqlParamsMap)
-                            .collect(Collectors.toList());
+            List<SqlBinds> mainStatementSqlBinds = split(sqlParameters.getSql(), separator)
+                    .stream()
+                    .map(this::getSqlAndSqlParamsMap)
+                    .collect(Collectors.toList());
 
             List<SqlBinds> preStatementSqlBinds = Optional.ofNullable(sqlParameters.getPreStatements())
                     .orElse(new ArrayList<>())
@@ -157,7 +167,7 @@ public class SqlTask extends AbstractTask {
                     .map(this::getSqlAndSqlParamsMap)
                     .collect(Collectors.toList());
 
-            List<String> createFuncs = createFuncs(sqlTaskExecutionContext.getUdfFuncParametersList(), logger);
+            List<String> createFuncs = createFuncs(sqlTaskExecutionContext.getUdfFuncParametersList(), log);
 
             // execute sql task
             executeFuncAndSql(mainStatementSqlBinds, preStatementSqlBinds, postStatementSqlBinds, createFuncs);
@@ -166,7 +176,7 @@ public class SqlTask extends AbstractTask {
 
         } catch (Exception e) {
             setExitStatusCode(TaskConstants.EXIT_CODE_FAILURE);
-            logger.error("sql task error", e);
+            log.error("sql task error", e);
             throw new TaskException("Execute sql task failed", e);
         }
     }
@@ -176,6 +186,31 @@ public class SqlTask extends AbstractTask {
 
     }
 
+    /**
+     * split sql by segment separator
+     * <p>The segment separator is used
+     * when the data source does not support multi-segment SQL execution,
+     * and the client needs to split the SQL and execute it multiple times.</p>
+     * @param sql
+     * @param segmentSeparator
+     * @return
+     */
+    public static List<String> split(String sql, String segmentSeparator) {
+        if (StringUtils.isEmpty(segmentSeparator)) {
+            return Collections.singletonList(sql);
+        }
+
+        String[] lines = sql.split(segmentSeparator);
+        List<String> segments = new ArrayList<>();
+        for (String line : lines) {
+            if (line.trim().isEmpty() || line.startsWith("--")) {
+                continue;
+            }
+            segments.add(line);
+        }
+        return segments;
+    }
+
     /**
      * execute function and sql
      *
@@ -188,11 +223,11 @@ public class SqlTask extends AbstractTask {
                                   List<SqlBinds> preStatementsBinds,
                                   List<SqlBinds> postStatementsBinds,
                                   List<String> createFuncs) throws Exception {
-        Connection connection = null;
-        try {
+        try (
+                Connection connection =
+                        DataSourceClientProvider.getAdHocConnection(DbType.valueOf(sqlParameters.getType()),
+                                baseConnectionParam)) {
 
-            // create connection
-            connection = DataSourceUtils.getConnection(DbType.valueOf(sqlParameters.getType()), baseConnectionParam);
             // create temp function
             if (CollectionUtils.isNotEmpty(createFuncs)) {
                 createTempFunction(connection, createFuncs);
@@ -218,10 +253,8 @@ public class SqlTask extends AbstractTask {
             // post execute
             executeUpdate(connection, postStatementsBinds, "post");
         } catch (Exception e) {
-            logger.error("execute sql error: {}", e.getMessage());
+            log.error("execute sql error: {}", e.getMessage());
             throw e;
-        } finally {
-            close(connection);
         }
     }
 
@@ -257,7 +290,7 @@ public class SqlTask extends AbstractTask {
 
             while (resultSet.next()) {
                 if (rowCount == limit) {
-                    logger.info("sql result limit : {} exceeding results are filtered", limit);
+                    log.info("sql result limit : {} exceeding results are filtered", limit);
                     break;
                 }
                 ObjectNode mapOfColValues = JSONUtils.createObjectNode();
@@ -267,25 +300,49 @@ public class SqlTask extends AbstractTask {
                 resultJSONArray.add(mapOfColValues);
                 rowCount++;
             }
+
             int displayRows = sqlParameters.getDisplayRows() > 0 ? sqlParameters.getDisplayRows()
                     : TaskConstants.DEFAULT_DISPLAY_ROWS;
             displayRows = Math.min(displayRows, rowCount);
-            logger.info("display sql result {} rows as follows:", displayRows);
+            log.info("display sql result {} rows as follows:", displayRows);
             for (int i = 0; i < displayRows; i++) {
                 String row = JSONUtils.toJsonString(resultJSONArray.get(i));
-                logger.info("row {} : {}", i + 1, row);
+                log.info("row {} : {}", i + 1, row);
             }
         }
-        String result = JSONUtils.toJsonString(resultJSONArray);
+
+        String result = resultJSONArray.isEmpty() ? JSONUtils.toJsonString(generateEmptyRow(resultSet))
+                : JSONUtils.toJsonString(resultJSONArray);
+
         if (Boolean.TRUE.equals(sqlParameters.getSendEmail())) {
             sendAttachment(sqlParameters.getGroupId(), StringUtils.isNotEmpty(sqlParameters.getTitle())
                     ? sqlParameters.getTitle()
                     : taskExecutionContext.getTaskName() + " query result sets", result);
         }
-        logger.debug("execute sql result : {}", result);
+        log.debug("execute sql result : {}", result);
         return result;
     }
 
+    /**
+     * generate empty Results as ArrayNode
+     */
+    private ArrayNode generateEmptyRow(ResultSet resultSet) throws SQLException {
+        ArrayNode resultJSONArray = JSONUtils.createArrayNode();
+        ObjectNode emptyOfColValues = JSONUtils.createObjectNode();
+        if (resultSet != null) {
+            ResultSetMetaData metaData = resultSet.getMetaData();
+            int columnsNum = metaData.getColumnCount();
+            log.info("sql query results is empty");
+            for (int i = 1; i <= columnsNum; i++) {
+                emptyOfColValues.set(metaData.getColumnLabel(i), JSONUtils.toJsonNode(""));
+            }
+        } else {
+            emptyOfColValues.set("error", JSONUtils.toJsonNode("resultSet is null"));
+        }
+        resultJSONArray.add(emptyOfColValues);
+        return resultJSONArray;
+    }
+
     /**
      * send alert as an attachment
      *
@@ -303,6 +360,7 @@ public class SqlTask extends AbstractTask {
 
     private String executeQuery(Connection connection, SqlBinds sqlBinds, String handlerType) throws Exception {
         try (PreparedStatement statement = prepareStatementAndBind(connection, sqlBinds)) {
+            log.info("{} statement execute query, for sql: {}", handlerType, sqlBinds.getSql());
             ResultSet resultSet = statement.executeQuery();
             return resultProcess(resultSet);
         }
@@ -314,7 +372,7 @@ public class SqlTask extends AbstractTask {
         for (SqlBinds sqlBind : statementsBinds) {
             try (PreparedStatement statement = prepareStatementAndBind(connection, sqlBind)) {
                 result = statement.executeUpdate();
-                logger.info("{} statement execute update result: {}, for sql: {}", handlerType, result,
+                log.info("{} statement execute update result: {}, for sql: {}", handlerType, result,
                         sqlBind.getSql());
             }
         }
@@ -331,7 +389,7 @@ public class SqlTask extends AbstractTask {
                                     List<String> createFuncs) throws Exception {
         try (Statement funcStmt = connection.createStatement()) {
             for (String createFunc : createFuncs) {
-                logger.info("hive create function sql: {}", createFunc);
+                log.info("hive create function sql: {}", createFunc);
                 funcStmt.execute(createFunc);
             }
         }
@@ -347,7 +405,7 @@ public class SqlTask extends AbstractTask {
             try {
                 connection.close();
             } catch (SQLException e) {
-                logger.error("close connection error : {}", e.getMessage(), e);
+                log.error("close connection error : {}", e.getMessage(), e);
             }
         }
     }
@@ -376,7 +434,7 @@ public class SqlTask extends AbstractTask {
                     ParameterUtils.setInParameter(entry.getKey(), stmt, prop.getType(), prop.getValue());
                 }
             }
-            logger.info("prepare statement replace sql : {}, sql parameters : {}", sqlBinds.getSql(),
+            log.info("prepare statement replace sql : {}, sql parameters : {}", sqlBinds.getSql(),
                     sqlBinds.getParamsMap());
             return stmt;
         } catch (Exception exception) {
@@ -394,17 +452,17 @@ public class SqlTask extends AbstractTask {
      */
     private void printReplacedSql(String content, String formatSql, String rgex, Map<Integer, Property> sqlParamsMap) {
         // parameter print style
-        logger.info("after replace sql , preparing : {}", formatSql);
+        log.info("after replace sql , preparing : {}", formatSql);
         StringBuilder logPrint = new StringBuilder("replaced sql , parameters:");
         if (sqlParamsMap == null) {
-            logger.info("printReplacedSql: sqlParamsMap is null.");
+            log.info("printReplacedSql: sqlParamsMap is null.");
         } else {
             for (int i = 1; i <= sqlParamsMap.size(); i++) {
                 logPrint.append(sqlParamsMap.get(i).getValue()).append("(").append(sqlParamsMap.get(i).getType())
                         .append(")");
             }
         }
-        logger.info("Sql Params are {}", logPrint);
+        log.info("Sql Params are {}", logPrint);
     }
 
     /**
@@ -417,8 +475,9 @@ public class SqlTask extends AbstractTask {
         StringBuilder sqlBuilder = new StringBuilder();
         // new
         // replace variable TIME with $[YYYYmmddd...] in sql when history run job and batch complement job
-        sql = ParameterUtils.replaceScheduleTime(sql, taskExecutionContext.getScheduleTime());
-        // combining local and global parameters
+        sql = ParameterUtils.replaceScheduleTime(sql,
+                DateUtils.timeStampToDate(taskExecutionContext.getScheduleTime()));
+
         Map<String, Property> paramsMap = taskExecutionContext.getPrepareParamsMap();
 
         // spell SQL according to the final user-defined variable
@@ -429,8 +488,8 @@ public class SqlTask extends AbstractTask {
 
         if (StringUtils.isNotEmpty(sqlParameters.getTitle())) {
             String title = ParameterUtils.convertParameterPlaceholders(sqlParameters.getTitle(),
-                    ParamUtils.convert(paramsMap));
-            logger.info("SQL title : {}", title);
+                    ParameterUtils.convert(paramsMap));
+            log.info("SQL title : {}", title);
             sqlParameters.setTitle(title);
         }
 
@@ -467,13 +526,13 @@ public class SqlTask extends AbstractTask {
      * create function list
      *
      * @param udfFuncParameters udfFuncParameters
-     * @param logger logger
+     * @param log log
      * @return
      */
-    private List<String> createFuncs(List<UdfFuncParameters> udfFuncParameters, Logger logger) {
+    private List<String> createFuncs(List<UdfFuncParameters> udfFuncParameters, Logger log) {
 
         if (CollectionUtils.isEmpty(udfFuncParameters)) {
-            logger.info("can't find udf function resource");
+            log.info("can't find udf function resource");
             return null;
         }
         // build jar sql
@@ -507,9 +566,7 @@ public class SqlTask extends AbstractTask {
             String prefixPath = defaultFS.startsWith("file://") ? "file://" : defaultFS;
             String uploadPath = CommonUtils.getHdfsUdfDir(value.getTenantCode());
             String resourceFullName = value.getResourceName();
-            resourceFullName =
-                    resourceFullName.startsWith("/") ? resourceFullName : String.format("/%s", resourceFullName);
-            return String.format("add jar %s%s%s", prefixPath, uploadPath, resourceFullName);
+            return String.format("add jar %s", resourceFullName);
         }).collect(Collectors.toList());
     }
 
