@@ -18,9 +18,13 @@
 export default {
   datasource: 'DataSource',
   create_datasource: 'Create DataSource',
+  choose_datasource_type: 'Choose DataSource Type',
+  select: 'Select',
   search_input_tips: 'Please input the keywords',
   datasource_name: 'Datasource Name',
   datasource_name_tips: 'Please enter datasource name',
+  datawarehouse: 'Datawarehouse',
+  datawarehouse_tips: 'Please enter datawarehouse',
   datasource_user_name: 'Owner',
   datasource_type: 'Datasource Type',
   datasource_parameter: 'Datasource Parameter',
@@ -48,6 +52,8 @@ export default {
   oracle_connect_type_tips: 'Please select serviceName or SID',
   oracle_service_name: 'ServiceName',
   oracle_sid: 'SID',
+  compatible_mode: 'Compatible Mode',
+  compatible_mode_tips: 'Please enter compatible mode',
   jdbc_connect_parameters: 'jdbc connect parameters',
   principal_tips: 'Please enter Principal',
   krb5_conf_tips:
@@ -64,5 +70,22 @@ export default {
   user_password_tips: 'Please enter your password',
   aws_region: 'Aws Region',
   aws_region_tips: 'Please enter AwsRegion',
-  jdbc_format_tips: 'jdbc connection parameters is not a correct JSON format'
+  validation: 'Validation',
+  mode_tips: 'Please select a mode',
+  jdbc_format_tips: 'jdbc connection parameters is not a correct JSON format',
+  database_username: 'Database Username',
+  database_password: 'Database Password',
+  Azure_AD_username: 'Azure AD username',
+  Azure_AD_password: 'Azure AD password',
+  MSIClientId: 'MSI ClientId',
+  clientId: 'ClientId',
+  clientSecret: 'ClientSecret',
+  OAuth_token_endpoint: 'OAuth 2.0 token endpoint',
+  endpoint_tips: 'Please enter OAuth Token',
+  AccessKeyID: 'AccessKeyID',
+  AccessKeyID_tips: 'Please input AccessKeyID',
+  SecretAccessKey: 'SecretAccessKey',
+  SecretAccessKey_tips: 'Please input SecretAccessKey',
+  dbUser: 'DbUser',
+  dbUser_tips: 'Please input DbUser'
 }
