@@ -23,10 +23,13 @@ export default {
   monitor: 'Monitor',
   security: 'Security',
   project_overview: 'Project Overview',
+  project_parameter: 'Project Parameter',
+  project_preferences: 'Project Preferences',
   workflow_relation: 'Workflow Relation',
   workflow: 'Workflow',
   workflow_definition: 'Workflow Definition',
   workflow_instance: 'Workflow Instance',
+  workflow_timing: 'Workflow Timing',
   task: 'Task',
   task_instance: 'Task Instance',
   task_definition: 'Task Definition',
@@ -56,5 +59,6 @@ export default {
   task_group_queue: 'Task Group Queue',
   data_quality: 'Data Quality',
   task_result: 'Task Result',
-  rule: 'Rule management'
+  rule: 'Rule management',
+  ui_setting: 'UI Setting'
 }
