@@ -36,11 +36,19 @@ export default {
     delete: 'Delete',
     confirm: 'Confirm',
     cancel: 'Cancel',
-    delete_confirm: 'Delete?'
+    delete_confirm: 'Delete?',
+    authorize_level: 'Authorize Level',
+    no_permission: 'No Permission',
+    read_permission: 'Read Permission',
+    all_permission: 'All Permission'
   },
   workflow: {
+    on_line: 'Online',
+    test: 'Test',
+    operating_environment: 'Operating Environment',
     workflow_relation: 'Workflow Relation',
     create_workflow: 'Create Workflow',
+    create_workflow_dynamic: 'Create Workflow (Dynamic)',
     import_workflow: 'Import Workflow',
     workflow_name: 'Workflow Name',
     workflow_instance_name: 'Workflow Instance Name',
@@ -57,6 +65,7 @@ export default {
     workflow_publish_status: 'Workflow Publish Status',
     schedule_publish_status: 'Schedule Publish Status',
     workflow_definition: 'Workflow Definition',
+    workflow_timing: 'Workflow Timing',
     workflow_instance: 'Workflow Instance',
     status: 'Status',
     create_time: 'Create Time',
@@ -66,18 +75,24 @@ export default {
     modify_user: 'Modify User',
     operation: 'Operation',
     edit: 'Edit',
+    confirm: 'Confirm',
+    cancel: 'Cancel',
     start: 'Start',
     timing: 'Timing',
     timezone: 'Timezone',
     up_line: 'Online',
     down_line: 'Offline',
     copy_workflow: 'Copy Workflow',
-    cron_manage: 'Cron manage',
+    copy_workflow_name: 'Copy workflow name',
+    visit_workflow_instances: 'Visit workflow instances',
+    cron_manage: 'Timing Management',
     delete: 'Delete',
     tree_view: 'Tree View',
     tree_limit: 'Limit Size',
     export: 'Export',
     batch_copy: 'Batch Copy',
+    batch_delete: 'Batch Delete',
+    batch_export: 'Batch Export',
     version_info: 'Version Info',
     version: 'Version',
     file_upload: 'File Upload',
@@ -95,14 +110,19 @@ export default {
     backward_execution: 'Backward execution',
     forward_execution: 'Forward execution',
     current_node_execution: 'Execute only the current node',
+    backward_execution_task: 'Run backwards',
+    forward_execution_task: 'Run forwards',
+    current_node_execution_task: 'Run',
     notification_strategy: 'Notification Strategy',
     workflow_priority: 'Workflow Priority',
     worker_group: 'Worker Group',
+    tenant_code: 'Tenant',
     environment_name: 'Environment Name',
     alarm_group: 'Alarm Group',
     complement_data: 'Complement Data',
     startup_parameter: 'Startup Parameter',
     whether_dry_run: 'Whether Dry-Run',
+    whether_test: 'Whether Test',
     continue: 'Continue',
     end: 'End',
     none_send: 'None',
@@ -122,6 +142,9 @@ export default {
     parallelism: 'Parallelism',
     custom_parallelism: 'Custom Parallelism',
     please_enter_parallelism: 'Please enter Parallelism',
+    order_of_execution: 'Order of execution',
+    ascending_order: 'In ascending order',
+    descending_order: 'In descending order',
     please_choose: 'Please Choose',
     start_time: 'Start Time',
     end_time: 'End Time',
@@ -150,6 +173,8 @@ export default {
     pause: 'Pause',
     recovery_waiting_thread: 'Recovery waiting thread',
     recover_serial_wait: 'Recover serial wait',
+    execute_task: 'Execute the specified task',
+    dynamic_generation: 'Dynamic Generation',
     recovery_suspend: 'Recovery Suspend',
     recovery_failed: 'Recovery Failed',
     gantt: 'Gantt',
@@ -192,6 +217,7 @@ export default {
     cancel_full_screen: 'Cancel full screen',
     task_state: 'Task status',
     mode_of_dependent: 'Mode of dependent',
+    all_level_dependent: 'all level dependent',
     open: 'Open',
     project_name_required: 'Project name is required',
     related_items: 'Related items',
@@ -203,14 +229,21 @@ export default {
       'There is not any workflows. Please create a workflow, and then visit this page again.',
     ready_to_block: 'Ready to block',
     block: 'Block',
+    want_to_set_timing: 'Would you like to set the workflow timing?',
+    confirm_to_online: 'Confirm to make the workflow online?',
+    confirm_to_offline: 'Confirm to make the workflow offline?',
   },
   task: {
+    on_line: 'Online',
+    test: 'Test',
+    operating_environment: 'Operating Environment',
     cancel_full_screen: 'Cancel full screen',
     enter_full_screen: 'Enter full screen',
     current_task_settings: 'Current task settings',
     online: 'Online',
     offline: 'Offline',
     task_name: 'Task Name',
+    task_code: 'Task Code',
     task_type: 'Task Type',
     create_task: 'Create Task',
     workflow_instance: 'Workflow Instance',
@@ -219,6 +252,7 @@ export default {
     workflow_state: 'Workflow State',
     version: 'Version',
     current_version: 'Current Version',
+    run_type: 'Run Type',
     switch_version: 'Switch To This Version',
     confirm_switch_version: 'Confirm Switch To This Version?',
     description: 'Description',
@@ -236,6 +270,7 @@ export default {
     retry_count: 'Retry Count',
     dry_run_flag: 'Dry Run Flag',
     host: 'Host',
+    app_link: 'External Application Link',
     operation: 'Operation',
     edit: 'Edit',
     delete: 'Delete',
@@ -259,11 +294,13 @@ export default {
     set_parameters_before_starting: 'Please set the parameters before starting',
     notification_strategy: 'Notification Strategy',
     worker_group: 'Worker group',
+    tenant_code: 'Tenant',
     environment_name: 'Environment Name',
     alarm_group: 'Alarm group',
     startup_parameter: 'Startup Parameter',
     whether_dry_run: 'Whether Dry-Run',
-    please_choose: 'Please Choose'
+    please_choose: 'Please Choose',
+    remove_task_cache: 'Clear cache'
   },
   dag: {
     create: 'Create Workflow',
@@ -283,7 +320,6 @@ export default {
     copy_success: 'Copy Success',
     workflow_name: 'Workflow Name',
     description: 'Description',
-    tenant: 'Tenant',
     timeout_alert: 'Timeout Alert',
     process_execute_type: 'Process execute type',
     parallel: 'parallel',
@@ -291,7 +327,7 @@ export default {
     serial_discard: 'Serial discard',
     serial_priority: 'Serial priority',
     recover_serial_wait: 'Recover serial wait',
-    global_variables: 'Global Variables',
+    global_variables: 'Global Parameters',
     basic_info: 'Basic Information',
     minute: 'Minute',
     key: 'Key',
@@ -311,6 +347,11 @@ export default {
     online: 'Online'
   },
   node: {
+    is_cache: 'Cache Execution',
+    jvm_args: 'Java VM Parameters',
+    jvm_args_tips: 'Please enter virtual machine parameters',
+    run_type: 'Run Type',
+    is_module_path: 'Use Module Path',
     return_back: 'Return',
     current_node_settings: 'Current node settings',
     instructions: 'Instructions',
@@ -345,6 +386,7 @@ export default {
     times: 'Times',
     failed_retry_interval: 'Failed retry interval',
     minute: 'Minute',
+    second: 'Second',
     delay_execution_time: 'Delay execution time',
     namespace_cluster: 'Namespace(Cluster)',
     min_cpu: 'Min cpu',
@@ -353,6 +395,16 @@ export default {
     mb: 'MB',
     image: 'Image',
     image_tips: 'Please enter image',
+    image_pull_policy: 'Image pull policy',
+    image_pull_policy_tips: 'Please select a image pull policy (required)',
+    pull_secret: 'Pull secret',
+    pull_secret_tips: 'Please enter pull secret',
+    command: 'Command',
+    command_tips:
+      'Please enter the container execution command, for example: ["printenv"]',
+    args: 'Args',
+    args_tips:
+      'Please enter the container execution command args, for example: ["HOSTNAME", "KUBERNETES_PORT"]',
     min_memory_tips: 'Please enter min memory',
     state: 'State',
     branch_flow: 'Branch flow',
@@ -389,9 +441,15 @@ export default {
     prop_repeat: 'prop is repeat',
     value_tips: 'value(optional)',
     value_required_tips: 'value(required)',
+    custom_labels: 'Customized labels',
+    node_selectors: 'Node Selectors',
+    label_repeat: 'repeated label',
+    label_name_tips: 'label name(required)',
+    label_value_tips: 'label value(required)',
+    expression_name_tips: 'expression label key(required)',
+    expression_value_tips: 'expression values(optional)',
     pre_tasks: 'Pre tasks',
     program_type: 'Program Type',
-    spark_version: 'Spark Version',
     main_class: 'Main Class',
     main_class_tips: 'Please enter main class',
     main_package: 'Main Package',
@@ -534,6 +592,7 @@ export default {
     add_pre_task_check_condition: 'Add pre task check condition',
     switch_condition: 'Condition',
     switch_branch_flow: 'Branch Flow',
+    switch_branch_flow_default: 'Default Branch Flow',
     switch_branch_flow_tips: 'Please select branch flow',
     and: 'and',
     or: 'or',
@@ -586,6 +645,7 @@ export default {
     add_dependency: 'Add dependency',
     waiting_dependent_start: 'Waiting Dependent start',
     check_interval: 'Check interval',
+    check_interval_tips: 'Check interval must be a positive integer',
     waiting_dependent_complete: 'Waiting Dependent complete',
     project_name: 'Project Name',
     project_name_tips: 'Please select a project(required)',
@@ -607,6 +667,7 @@ export default {
     table_count_check: 'TableCountCheck',
     src_connector_type: 'SrcConnType',
     src_datasource_id: 'SrcSource',
+    src_database: 'SrcDatabase',
     src_table: 'SrcTable',
     src_filter: 'SrcFilter',
     src_field: 'SrcField',
@@ -617,6 +678,7 @@ export default {
     failure_strategy: 'FailureStrategy',
     target_connector_type: 'TargetConnType',
     target_datasource_id: 'TargetSourceId',
+    target_database: 'TargetDatabase',
     target_table: 'TargetTable',
     target_filter: 'TargetFilter',
     mapping_columns: 'OnClause',
@@ -640,8 +702,6 @@ export default {
     emr_flow_define_json_tips: 'Please enter the definition of the job flow.',
     emr_steps_define_json: 'stepsDefineJson',
     emr_steps_define_json_tips: 'Please enter the definition of the emr step.',
-    segment_separator: 'Segment Execution Separator',
-    segment_separator_tips: 'Please enter the segment execution separator',
     zeppelin_note_id: 'zeppelinNoteId',
     zeppelin_note_id_tips: 'Please enter the note id of your zeppelin note',
     zeppelin_paragraph_id: 'zeppelinParagraphId',
@@ -657,6 +717,13 @@ export default {
       'Directory for cloned zeppelin note in production mode',
     zeppelin_production_note_directory_tips:
       'Please enter the production note directory to enable production mode',
+    zeppelin_username: 'zeppelinUsername',
+    zeppelin_username_tips: 'Please enter the zeppelin server username',
+    zeppelin_password: 'zeppelinPassword',
+    zeppelin_password_tips: 'Please enter the zeppelin server password',
+    sql_execution_type: 'SQL Input',
+    sql_execution_type_from_file: 'FROM_FILE',
+    sql_execution_type_from_script: 'FROM_SCRIPT',
     hive_cli_task_execution_type: 'Hive Cli Task Execution Type',
     hive_sql_script: 'Hive SQL Script',
     hive_cli_options: 'Hive Cli Options',
@@ -712,7 +779,7 @@ export default {
     mlflow_deployModelKey: 'Model-URI',
     mlflow_deployPort: 'Port',
     mlflowProjectRepository: 'Repository',
-    mlflowProjectRepository_tips: 'git respository or path on worker',
+    mlflowProjectRepository_tips: 'git repository or path on worker',
     mlflowProjectVersion: 'Project Version',
     mlflowProjectVersion_tips: 'git version',
     mlflow_cpuLimit: 'Max Cpu Limit',
@@ -749,10 +816,20 @@ export default {
     unlimited: 'unlimited',
     please_select_source_connector_type: 'Please select source connector type',
     please_select_source_datasource_id: 'Please select source datasource id',
+    please_select_source_database: 'Please select source database',
     please_enter_source_table_name: 'Please select source table name',
     please_enter_filter_expression: 'Please enter filter expression',
     please_enter_column_only_single_column_is_supported:
       'Please select column, only single column is supported',
+    please_select_target_connector_type: 'Please select target connector type',
+    please_select_target_datasource: 'Please select target datasource id',
+    please_select_target_database: 'Please select target database',
+    please_enter_target_table: 'Please select target table name',
+    please_enter_target_filter_expression: 'Please enter target filter expression',
+    please_enter_comparison_name_the_alias_in_comparison_execute_sql: 'Please enter comparison name the alias in comparison execute sql',
+    please_enter_statistics_name_the_alias_in_statistics_execute_sql: 'Please enter statistics name the alias in statistics execute sql',
+    please_enter_comparison_execute_sql: 'Please enter comparison execute sql',
+    please_enter_statistics_execute_sql: 'Please enter statistics execute sql',
     please_enter_threshold_number_is_needed:
       'Please enter threshold number is needed',
     please_enter_comparison_title: 'please select comparison title',
@@ -773,11 +850,70 @@ export default {
     pytorch_python_path: 'Project Path',
     pytorch_is_create_environment: 'Create An Environment Or Not',
     pytorch_python_command: 'Python Command Path',
-    pytorch_python_command_tips: 'If empty，will be set $PYTHON_HOME',
+    pytorch_python_command_tips: 'If empty，will be set $PYTHON_LAUNCHER',
     pytorch_python_env_tool: 'Python Environment Manager Tool',
     pytorch_requirements: 'Requirement File',
     pytorch_conda_python_version: 'Python Version',
     pytorch_conda_python_version_tips:
-      'Please enter the version number, such as 3.6, 3.7, 3.x'
-  }
+      'Please enter the version number, such as 3.6, 3.7, 3.x',
+    factory_name: 'Factory Name',
+    resource_group_name: 'Resource Group Name',
+    pipeline_name: 'Pipeline Name',
+    factory_tips: 'Please select factory',
+    resource_group_tips: 'Please select resource group',
+    pipeline_tips: 'Please select pipeline',
+    dependent_failure_policy: 'Dependent failure policy',
+    dependent_failure_policy_failure: 'failure',
+    dependent_failure_policy_waiting: 'waiting',
+    dependent_failure_waiting_time: 'Dependent failure waiting time',
+    dependent_failure_waiting_time_tips:
+      'Failure waiting time must be a positive integer',
+    max_num_of_sub_workflow_instances: 'max num of sub workflow instances',
+    filter_condition: 'Filter Condition',
+    params_value: 'Params Value',
+    separator: 'Separator',
+    dynamic_name_tips: 'name(required)',
+    dynamic_value_tips: 'params or value(required)',
+    dynamic_separator_tips: 'separator(required)',
+    child_node_definition: 'child node definition',
+    child_node_instance: 'child node instance',
+    yarn_queue: 'Yarn Queue',
+    yarn_queue_tips: 'Please input yarn queue(optional)',
+  },
+  menu: {
+    fav: 'Favorites',
+    universal: 'Universal',
+    cloud: 'Cloud',
+    logic: 'Logic',
+    di: 'Data Integration',
+    dq: 'Data Quality',
+    ml: 'Machine Learning',
+    other: 'Other'
+  },
+  parameter: {
+    create_parameter: 'Create Parameter',
+    edit_parameter: 'Edit Parameter',
+    parameter_manage: 'Parameter Management',
+    code: 'Parameter Code',
+    name: 'Parameter Name',
+    value: 'Parameter Value',
+    create_time: 'Create Time',
+    update_time: 'Update Time',
+    name_tips: 'Please enter your parameter name',
+    value_tips: 'Please enter your parameter value',
+    operation: 'Operation',
+    edit: 'Edit',
+    delete: 'Delete',
+    delete_confirm: 'Delete?',
+    success: 'Success',
+  },
+  preference: {
+    edit_preference: 'Edit Preference',
+    preference_manage: 'Project Preference Management',
+    instruction_tips: 'The settings below will affect all workflows and tasks under this project.When creating the workflow or task, these preferences will be the default value of their components.',
+    success: 'Success',
+    submit: 'Submit',
+    enabled: 'Enabled',
+    disabled: 'Disabled'
+  },
 }
