@@ -17,13 +17,17 @@
 
 export default {
   datasource: '数据源',
-  create_datasource: '创建数据源',
+  create_datasource: '创建源',
+  choose_datasource_type: '选择源类型',
+  select: '更改',
   search_input_tips: '请输入关键字',
-  datasource_name: '数据源名称',
+  datasource_name: '源名称',
   datasource_name_tips: '请输入数据源名称',
+  datawarehouse: '数据仓库',
+  datawarehouse_tips: '请输入数据仓库',
   datasource_user_name: '所属用户',
-  datasource_type: '数据源类型',
-  datasource_parameter: '数据源参数',
+  datasource_type: '源类型',
+  datasource_parameter: '参数',
   description: '描述',
   description_tips: '请输入描述',
   create_time: '创建时间',
@@ -48,6 +52,8 @@ export default {
   oracle_connect_type_tips: '请选择服务名或SID',
   oracle_service_name: '服务名',
   oracle_sid: 'SID',
+  compatible_mode: '兼容模式',
+  compatible_mode_tips: '请输入兼容模式',
   jdbc_connect_parameters: 'jdbc连接参数',
   principal_tips: '请输入Principal',
   krb5_conf_tips: '请输入kerberos认证参数 java.security.krb5.conf',
@@ -61,5 +67,22 @@ export default {
   user_password_tips: '请输入密码',
   aws_region: 'AwsRegion',
   aws_region_tips: '请输入AwsRegion',
-  jdbc_format_tips: 'jdbc连接参数不是一个正确的JSON格式'
+  validation: '验证',
+  mode_tips: '请选择验证模式',
+  jdbc_format_tips: 'jdbc连接参数不是一个正确的JSON格式',
+  database_username: '数据库用户名',
+  database_password: '数据库密码',
+  Azure_AD_username: 'Azure AD用户名',
+  Azure_AD_password: 'Azure AD密码',
+  MSIClientId: 'MSI ClientId',
+  clientId: 'ClientId',
+  clientSecret: 'ClientSecret',
+  OAuth_token_endpoint: 'OAuth 2.0 token endpoint',
+  endpoint_tips: '请输入OAuth',
+  AccessKeyID: 'AccessKeyID',
+  AccessKeyID_tips: '请输入AccessKeyID',
+  SecretAccessKey: 'SecretAccessKey',
+  SecretAccessKey_tips: '请输入SecretAccessKey',
+  dbUser: 'DbUser',
+  dbUser_tips: '请输入DbUser'
 }
