@@ -19,14 +19,18 @@ export default {
   home: '首页',
   project: '项目管理',
   resources: '资源中心',
-  datasource: '数据源中心',
+  datasource: '源中心',
   monitor: '监控中心',
   security: '安全中心',
+  ui_setting: '界面设置',
   project_overview: '项目概览',
+  project_parameter: '项目级别参数',
+  project_preferences: '项目偏好设置',
   workflow_relation: '工作流关系',
   workflow: '工作流',
   workflow_definition: '工作流定义',
   workflow_instance: '工作流实例',
+  workflow_timing: '工作流定时',
   task: '任务',
   task_instance: '任务实例',
   task_definition: '任务定义',
