@@ -36,11 +36,19 @@ export default {
     delete: '删除',
     confirm: '确定',
     cancel: '取消',
-    delete_confirm: '确定删除吗?'
+    delete_confirm: '确定删除吗?',
+    authorize_level: '权限等级',
+    no_permission: '无权限',
+    read_permission: '读权限',
+    all_permission: '所有权限'
   },
   workflow: {
+    on_line: '线上',
+    test: '测试',
+    operating_environment: '运行环境',
     workflow_relation: '工作流关系',
     create_workflow: '创建工作流',
+    create_workflow_dynamic: '创建工作流 (动态)',
     import_workflow: '导入工作流',
     workflow_name: '工作流名称',
     workflow_instance_name: '工作流实例名称',
@@ -58,6 +66,7 @@ export default {
     schedule_publish_status: '定时状态',
     workflow_definition: '工作流定义',
     workflow_instance: '工作流实例',
+    workflow_timing: '工作流定时',
     status: '状态',
     create_time: '创建时间',
     update_time: '更新时间',
@@ -74,12 +83,16 @@ export default {
     up_line: '上线',
     down_line: '下线',
     copy_workflow: '复制工作流',
+    copy_workflow_name: '复制工作流名称',
+    visit_workflow_instances: '查看工作流实例',
     cron_manage: '定时管理',
     delete: '删除',
     tree_view: '工作流树形图',
     tree_limit: '限制大小',
     export: '导出',
     batch_copy: '批量复制',
+    batch_delete: '批量删除',
+    batch_export: '批量导出',
     version_info: '版本信息',
     version: '版本',
     file_upload: '文件上传',
@@ -97,14 +110,19 @@ export default {
     backward_execution: '向后执行',
     forward_execution: '向前执行',
     current_node_execution: '仅执行当前节点',
+    backward_execution_task: '向后运行',
+    forward_execution_task: '向前运行',
+    current_node_execution_task: '运行',
     notification_strategy: '通知策略',
     workflow_priority: '流程优先级',
     worker_group: 'Worker分组',
+    tenant_code: '租户',
     environment_name: '环境名称',
     alarm_group: '告警组',
     complement_data: '补数',
     startup_parameter: '启动参数',
     whether_dry_run: '是否空跑',
+    whether_test: '是否测试',
     continue: '继续',
     end: '结束',
     none_send: '都不发',
@@ -123,6 +141,9 @@ export default {
     parallelism: '并行度',
     custom_parallelism: '自定义并行度',
     please_enter_parallelism: '请输入并行度',
+    order_of_execution: '执行顺序',
+    ascending_order: '按日期升序执行',
+    descending_order: '按日期降序执行',
     please_choose: '请选择',
     start_time: '开始时间',
     end_time: '结束时间',
@@ -151,6 +172,8 @@ export default {
     pause: '暂停',
     recovery_waiting_thread: '恢复等待线程',
     recover_serial_wait: '串行恢复',
+    execute_task: '执行指定任务',
+    dynamic_generation: '动态生成',
     recovery_suspend: '恢复运行',
     recovery_failed: '重跑失败任务',
     gantt: '甘特图',
@@ -193,6 +216,7 @@ export default {
     cancel_full_screen: '取消全屏',
     task_state: '任务状态',
     mode_of_dependent: '依赖模式',
+    all_level_dependent: '所有层级依赖',
     open: '打开',
     project_name_required: '项目名称必填',
     related_items: '关联项目',
@@ -203,14 +227,21 @@ export default {
       '目前没有任何工作流，请先创建工作流，再访问该页面',
     ready_to_block: '准备锁定',
     block: '锁定',
+    want_to_set_timing: '现在想去配置该工作流定时?',
+    confirm_to_online: '是否确定上线该工作流?',
+    confirm_to_offline: '是否确定下线该工作流?',
   },
   task: {
+    on_line: '线上',
+    test: '测试',
+    operating_environment: '运行环境',
     cancel_full_screen: '取消全屏',
     enter_full_screen: '全屏',
     current_task_settings: '当前任务设置',
     online: '已上线',
     offline: '已下线',
     task_name: '任务名称',
+    task_code: '任务编码',
     task_type: '任务类型',
     task_instance: '任务实例',
     create_task: '创建任务',
@@ -236,6 +267,7 @@ export default {
     duration: '运行时间',
     retry_count: '重试次数',
     dry_run_flag: '空跑标识',
+    app_link: '外部应用链接',
     host: '主机',
     operation: '操作',
     edit: '编辑',
@@ -260,11 +292,13 @@ export default {
     set_parameters_before_starting: '启动前请先设置参数',
     notification_strategy: '通知策略',
     worker_group: 'Worker分组',
+    tenant_code: '租户',
     environment_name: '环境名称',
     alarm_group: '告警组',
     startup_parameter: '启动参数',
     whether_dry_run: '是否空跑',
-    please_choose: '请选择'
+    please_choose: '请选择',
+    remove_task_cache: '清除缓存'
   },
   dag: {
     create: '创建工作流',
@@ -284,7 +318,6 @@ export default {
     copy_success: '复制成功',
     workflow_name: '工作流名称',
     description: '描述',
-    tenant: '租户',
     timeout_alert: '超时告警',
     process_execute_type: '执行策略',
     parallel: '并行',
@@ -292,7 +325,7 @@ export default {
     serial_discard: '串行抛弃',
     serial_priority: '串行优先',
     recover_serial_wait: '串行恢复',
-    global_variables: '全局变量',
+    global_variables: '全局参数',
     basic_info: '基本信息',
     minute: '分',
     key: '键',
@@ -312,6 +345,11 @@ export default {
     online: '已上线'
   },
   node: {
+    is_cache: '缓存执行',
+    is_module_path: '使用模块路径',
+    run_type: '运行类型',
+    jvm_args: '虚拟机参数',
+    jvm_args_tips: '请输入虚拟机参数',
     return_back: '返回上一节点',
     current_node_settings: '当前节点设置',
     instructions: '使用说明',
@@ -345,6 +383,7 @@ export default {
     times: '次',
     failed_retry_interval: '失败重试间隔',
     minute: '分',
+    second: '秒',
     delay_execution_time: '延时执行时间',
     namespace_cluster: '命名空间(集群)',
     min_cpu: '最小cpu',
@@ -353,6 +392,14 @@ export default {
     mb: 'MB',
     image: '镜像',
     image_tips: '请输入镜像',
+    image_pull_policy: '镜像拉取策略',
+    image_pull_policy_tips: '请选择镜像拉取策略（必选）',
+    pull_secret: '仓库密钥',
+    pull_secret_tips: '请输入仓库密钥',
+    command: '容器执行命令',
+    command_tips: '请输入容器执行命令，例如：["printenv"]',
+    args: '执行命令参数',
+    args_tips: '请输入容器执行命令参数，例如：["HOSTNAME", "KUBERNETES_PORT"]',
     min_memory_tips: '请输入最小内存',
     state: '状态',
     branch_flow: '分支流转',
@@ -385,9 +432,15 @@ export default {
     prop_repeat: 'prop中有重复',
     value_tips: 'value(选填)',
     value_required_tips: 'value(必填)',
+    custom_labels: '自定义标签',
+    node_selectors: '节点选择器',
+    label_repeat: 'label中有重复',
+    label_name_tips: 'label name(必填)',
+    label_value_tips: 'label value(必填)',
+    expression_name_tips: '表达式标签键值(必填)',
+    expression_value_tips: '表达式值集(选填)',
     pre_tasks: '前置任务',
     program_type: '程序类型',
-    spark_version: 'Spark版本',
     main_class: '主函数的Class',
     main_class_tips: '请填写主函数的Class',
     main_package: '主程序包',
@@ -528,6 +581,7 @@ export default {
     add_pre_task_check_condition: '添加前置检查条件',
     switch_condition: '条件',
     switch_branch_flow: '分支流转',
+    switch_branch_flow_default: '默认分支流转',
     switch_branch_flow_tips: '请选择分支流转',
     and: '且',
     or: '或',
@@ -580,6 +634,7 @@ export default {
     add_dependency: '添加依赖',
     waiting_dependent_start: '等待依赖启动',
     check_interval: '检查间隔',
+    check_interval_tips: '检查间隔必须为正整数',
     waiting_dependent_complete: '等待依赖完成',
     project_name: '项目名称',
     project_name_tips: '项目名称（必填）',
@@ -601,6 +656,7 @@ export default {
     table_count_check: '表行数校验',
     src_connector_type: '源数据类型',
     src_datasource_id: '源数据源',
+    src_database: '源数据库',
     src_table: '源数据表',
     src_filter: '源表过滤条件',
     src_field: '源表检测列',
@@ -611,6 +667,7 @@ export default {
     failure_strategy: '失败策略',
     target_connector_type: '目标数据类型',
     target_datasource_id: '目标数据源',
+    target_database: '目标数据库',
     target_table: '目标数据表',
     target_filter: '目标表过滤条件',
     mapping_columns: 'ON语句',
@@ -634,8 +691,6 @@ export default {
     emr_flow_define_json_tips: '请输入工作流定义',
     emr_steps_define_json: 'stepsDefineJson',
     emr_steps_define_json_tips: '请输入EMR步骤定义',
-    segment_separator: '分段执行符号',
-    segment_separator_tips: '请输入分段执行符号',
     zeppelin_note_id: 'zeppelinNoteId',
     zeppelin_note_id_tips: '请输入zeppelin note id',
     zeppelin_paragraph_id: 'zeppelinParagraphId',
@@ -647,6 +702,13 @@ export default {
     zeppelin_parameters_tips: '请输入zeppelin dynamic form参数',
     zeppelin_rest_endpoint: 'zeppelinRestEndpoint',
     zeppelin_rest_endpoint_tips: '请输入zeppelin server的rest endpoint',
+    zeppelin_username: 'zeppelinUsername',
+    zeppelin_username_tips: '请输入zeppelin server的登陆用户名',
+    zeppelin_password: 'zeppelinPassword',
+    zeppelin_password_tips: '请输入zeppelin server的登陆密码',
+    sql_execution_type: 'SQL来源',
+    sql_execution_type_from_file: '选择资源中心文件',
+    sql_execution_type_from_script: '脚本输入',
     hive_cli_task_execution_type: 'Hive Cli 任务类型',
     hive_sql_script: 'Hive SQL 脚本',
     hive_cli_options: 'Hive Cli 选项',
@@ -732,11 +794,21 @@ export default {
     unlimited: '不限制',
     please_select_source_connector_type: '请选择源数据类型',
     please_select_source_datasource_id: '请选择源数据源',
+    please_select_source_database: '请选择源数据库',
     please_enter_source_table_name: '请选择源数据表',
     please_enter_filter_expression: '请输入源表过滤条件',
     please_enter_column_only_single_column_is_supported: '请选择源表检测列',
     please_enter_threshold_number_is_needed: '请输入阈值',
     please_enter_comparison_title: '请选择期望值类型',
+    please_select_target_connector_type: '请选择目标数据类型',
+    please_select_target_datasource: '请选择目标数据源',
+    please_select_target_database: '请选择目标数据库',
+    please_enter_target_table: '请选择目标数据表',
+    please_enter_target_filter_expression: '请输入目标表过滤条件',
+    please_enter_comparison_name_the_alias_in_comparison_execute_sql: '请输入期望值名',
+    please_enter_statistics_name_the_alias_in_statistics_execute_sql: '请输入实际值名',
+    please_enter_comparison_execute_sql: '请输入期望值计算SQL',
+    please_enter_statistics_execute_sql: '请输入实际值计算SQL',
     custom_config: '自定义配置',
     engine: '引擎',
     engine_tips: '请选择引擎',
@@ -754,10 +826,68 @@ export default {
     pytorch_python_path: 'python项目地址',
     pytorch_is_create_environment: '是否创建新环境',
     pytorch_python_command: 'python命令路径',
-    pytorch_python_command_tips: '若为空，则使用$PYTHON_HOME',
+    pytorch_python_command_tips: '若为空，则使用$PYTHON_LAUNCHER',
     pytorch_python_env_tool: 'python环境管理工具',
     pytorch_requirements: '依赖文件',
     pytorch_conda_python_version: 'python版本',
-    pytorch_conda_python_version_tips: '请输入版本号，如 3.6, 3.7, 3.x等'
-  }
+    pytorch_conda_python_version_tips: '请输入版本号，如 3.6, 3.7, 3.x等',
+    factory_name: '工厂名称',
+    resource_group_name: '资源组名称',
+    pipeline_name: 'pipeline名称',
+    factory_tips: '请选择工厂',
+    resource_group_tips: '请选择资源组',
+    pipeline_tips: '请选择pipeline',
+    dependent_failure_policy: '依赖失败策略',
+    dependent_failure_policy_failure: '失败',
+    dependent_failure_policy_waiting: '等待',
+    dependent_failure_waiting_time: '依赖失败等待时间',
+    dependent_failure_waiting_time_tips: '失败等待时间必须为正整数',
+    max_num_of_sub_workflow_instances: '动态生成实例上限',
+    filter_condition: '过滤条件',
+    params_value: '取值参数',
+    separator: '分隔符',
+    dynamic_name_tips: 'name(必填)',
+    dynamic_value_tips: 'params or value(必填)',
+    dynamic_separator_tips: '分隔符(必填)',
+    child_node_definition: '子节点定义',
+    child_node_instance: '子节点实例',
+    yarn_queue: 'Yarn队列',
+    yarn_queue_tips: '请输入Yarn队列(选填)',
+  },
+  menu: {
+    fav: '收藏组件',
+    universal: '通用组件',
+    cloud: '云',
+    logic: '逻辑节点',
+    di: '数据集成',
+    dq: '数据质量',
+    ml: '机器学习',
+    other: '其他'
+  },
+  parameter: {
+    create_parameter: '创建项目级别参数',
+    edit_parameter: '修改项目级别参数',
+    parameter_manage: '参数管理',
+    code: '参数编码',
+    name: '参数名称',
+    value: '参数值',
+    create_time: '创建时间',
+    update_time: '更新时间',
+    name_tips: '请输入参数名称',
+    value_tips: '请输入参数值',
+    operation: '操作',
+    edit: '编辑',
+    delete: '删除',
+    delete_confirm: '确定删除吗?',
+    success: '成功',
+  },
+  preference: {
+    edit_preference: '修改项目偏好设置',
+    preference_manage: '项目偏好管理',
+    instruction_tips: '下面这些项目偏好配置将影响这个项目下的所有工作流和任务。当创建工作流和任务时，这些配置将影响组件中的默认选项',
+    success: '成功',
+    submit: '提交',
+    enabled: '启用',
+    disabled: '未启用'
+  },
 }
