@@ -28,6 +28,7 @@ export default {
     actions: '操作',
     edit_tenant: '编辑租户',
     tenant_code_tips: '请输入操作系统租户',
+    tenant_code_invalid_tips: '操作系统租户名称含有非法字符',
     queue_name_tips: '请选择队列',
     description_tips: '请输入描述',
     delete_confirm: '确定删除吗?',
@@ -76,6 +77,8 @@ export default {
     update_time: '更新时间',
     operation: '操作',
     edit: '编辑',
+    delete: '删除',
+    delete_confirm: '确定删除吗?',
     queue_name_tips: '请输入队列名',
     queue_value_tips: '请输入队列值'
   },
@@ -141,6 +144,7 @@ export default {
     edit_user: '编辑用户',
     delete_user: '删除用户',
     delete_confirm: '确定删除吗?',
+    reset_password: '重新设置密码',
     project: '项目',
     resource: '资源',
     file_resource: '文件资源',
@@ -148,6 +152,9 @@ export default {
     datasource: '数据源',
     udf: 'UDF函数',
     namespace: '命名空间',
+    revoke_auth: '撤销权限',
+    grant_read: '授予读权限',
+    grant_all: '授予所有权限',
     authorize_project: '项目授权',
     authorize_resource: '资源授权',
     authorize_namespace: '命名空间授权',
@@ -158,6 +165,7 @@ export default {
     username_tips: '请输入用户名',
     user_password: '密码',
     user_password_tips: '请输入包含字母和数字，长度在6～20之间的密码',
+    confirm_password_tips: '两次密码输入不一致',
     user_type: '用户类型',
     ordinary_user: '普通用户',
     administrator: '管理员',
