@@ -25,3 +25,24 @@ export function login(data: LoginReq): any {
     data
   })
 }
+
+export function ssoLoginUrl(): any {
+  return axios({
+    url: '/login/sso',
+    method: 'get'
+  })
+}
+
+export function getOauth2Provider(): any {
+  return axios({
+    url: '/oauth2-provider',
+    method: 'get',
+  })
+}
+
+export function clearCookie(): any {
+  return axios({
+    url: '/cookies',
+    method: 'delete',
+  })
+}
\ No newline at end of file
