@@ -16,7 +16,13 @@
  */
 
 import { axios } from '@/service/service'
-import { ListReq, ProjectsReq, UserIdReq, UpdateProjectsReq } from './types'
+import {
+  ListReq,
+  ListIdReq,
+  ProjectsReq,
+  UserIdReq,
+  UpdateProjectsReq
+} from './types'
 
 export function queryProjectListPaging(params: ListReq): any {
   return axios({
@@ -26,6 +32,16 @@ export function queryProjectListPaging(params: ListReq): any {
   })
 }
 
+export function queryProjectWithAuthorizedLevelListPaging(
+  params: ListIdReq
+): any {
+  return axios({
+    url: '/projects/project-with-authorized-level-list-paging',
+    method: 'get',
+    params
+  })
+}
+
 export function createProject(data: ProjectsReq): any {
   return axios({
     url: '/projects',
@@ -64,6 +80,14 @@ export function queryUnauthorizedProject(params: UserIdReq): any {
   })
 }
 
+export function queryProjectWithAuthorizedLevel(params: UserIdReq): any {
+  return axios({
+    url: '/projects/project-with-authorized-level',
+    method: 'get',
+    params
+  })
+}
+
 export function queryProjectByCode(code: number): any {
   return axios({
     url: `/projects/${code}`,
