@@ -20,6 +20,8 @@ import type { UserInfoRes } from '@/service/modules/users/types'
 interface UserState {
   sessionId: string
   securityConfigType: string
+  baseResDir: string
+  baseUdfDir: string
   userInfo: UserInfoRes | {}
 }
 
