@@ -33,6 +33,7 @@ export function useForm(id?: number) {
 
   const initialValues = {
     type: 'MYSQL',
+    label: 'MYSQL',
     name: '',
     note: '',
     host: '',
@@ -41,11 +42,16 @@ export function useForm(id?: number) {
     javaSecurityKrb5Conf: '',
     loginUserKeytabUsername: '',
     loginUserKeytabPath: '',
+    mode: '',
     userName: '',
     password: '',
     database: '',
     connectType: '',
-    other: ''
+    other: '',
+    endpoint: '',
+    MSIClientId: '',
+    dbUser: '',
+    datawarehouse: ''
   } as IDataSourceDetail
 
   const state = reactive({
@@ -55,8 +61,13 @@ export function useForm(id?: number) {
     showHost: true,
     showPort: true,
     showAwsRegion: false,
+    showCompatibleMode: false,
     showConnectType: false,
     showPrincipal: false,
+    showMode: false,
+    showDataBaseName: true,
+    showJDBCConnectParameters: true,
+    showPublicKey: false,
     rules: {
       name: {
         trigger: ['input'],
@@ -77,6 +88,9 @@ export function useForm(id?: number) {
       port: {
         trigger: ['input'],
         validator() {
+          if (state.showMode && state.detailForm.mode === 'IAM-accessKey') {
+            return
+          }
           if (!state.detailForm.port && state.showPort) {
             return new Error(t('datasource.port_tips'))
           }
@@ -90,10 +104,21 @@ export function useForm(id?: number) {
           }
         }
       },
+      mode: {
+        trigger: ['blur'],
+        validator() {
+          if (!state.detailForm.mode && state.showMode) {
+            return new Error(t('datasource.mode_tips'))
+          }
+        }
+      },
       userName: {
         trigger: ['input'],
         validator() {
-          if (!state.detailForm.userName) {
+          if (
+            !state.detailForm.userName &&
+            state.detailForm.type !== 'AZURESQL'
+          ) {
             return new Error(t('datasource.user_name_tips'))
           }
         }
@@ -114,6 +139,14 @@ export function useForm(id?: number) {
           }
         }
       },
+      datawarehouse: {
+        trigger: ['input'],
+        validator() {
+          if (!state.detailForm.datawarehouse) {
+            return new Error(t('datasource.datawarehouse_tips'))
+          }
+        }
+      },
       connectType: {
         trigger: ['update'],
         validator() {
@@ -129,30 +162,108 @@ export function useForm(id?: number) {
             return new Error(t('datasource.jdbc_format_tips'))
           }
         }
+      },
+      endpoint: {
+        trigger: ['input'],
+        validator() {
+          if (
+            !state.detailForm.endpoint &&
+            state.detailForm.type === 'AZURESQL' &&
+            state.detailForm.mode === 'accessToken'
+          ) {
+            return new Error(t('datasource.endpoint_tips'))
+          }
+        }
+      },
+      dbUser: {
+        trigger: ['input'],
+        validator() {
+          if (
+            !state.detailForm.dbUser &&
+            state.showMode &&
+            state.detailForm.mode === 'IAM-accessKey'
+          ) {
+            return new Error(t('datasource.IAM-accessKey'))
+          }
+        }
       }
-    } as FormRules
+      // databaseUserName: {
+      //   trigger: ['input'],
+      //   validator() {
+      //     if (!state.detailForm.userName) {
+      //       return new Error(t('datasource.user_name_tips'))
+      //     }
+      //   }
+      // },
+    } as FormRules,
+    modeOptions: [
+      {
+        label: 'SqlPassword',
+        value: 'SqlPassword'
+      },
+      {
+        label: 'ActiveDirectoryPassword',
+        value: 'ActiveDirectoryPassword'
+      },
+      {
+        label: 'ActiveDirectoryMSI',
+        value: 'ActiveDirectoryMSI'
+      },
+      {
+        label: 'ActiveDirectoryServicePrincipal',
+        value: 'ActiveDirectoryServicePrincipal'
+      },
+      {
+        label: 'accessToken',
+        value: 'accessToken'
+      }
+    ],
+    redShiftModeOptions: [
+      {
+        label: 'password',
+        value: 'password'
+      },
+      {
+        label: 'IAM-accessKey',
+        value: 'IAM-accessKey'
+      }
+    ]
   })
 
   const changeType = async (type: IDataBase, options: IDataBaseOption) => {
     state.detailForm.port = options.previousPort || options.defaultPort
     state.detailForm.type = type
 
-    state.requiredDataBase = (type !== 'POSTGRESQL' && type !== 'ATHENA')
+    state.requiredDataBase = type !== 'POSTGRESQL' && type !== 'ATHENA'
 
     state.showHost = type !== 'ATHENA'
     state.showPort = type !== 'ATHENA'
     state.showAwsRegion = type === 'ATHENA'
+    state.showMode = ['AZURESQL', 'REDSHIFT'].includes(type)
 
     if (type === 'ORACLE' && !id) {
       state.detailForm.connectType = 'ORACLE_SERVICE_NAME'
     }
     state.showConnectType = type === 'ORACLE'
 
+    state.showCompatibleMode = type == 'OCEANBASE'
+
     if (type === 'HIVE' || type === 'SPARK') {
       state.showPrincipal = await getKerberosStartupState()
     } else {
       state.showPrincipal = false
     }
+    if (type === 'SSH') {
+      state.showDataBaseName = false
+      state.requiredDataBase = false
+      state.showJDBCConnectParameters = false
+      state.showPublicKey = true
+    } else {
+      state.showDataBaseName = true
+      state.requiredDataBase = true
+      state.showJDBCConnectParameters = true
+      state.showPublicKey = false
+    }
   }
 
   const changePort = async () => {
@@ -226,6 +337,11 @@ export const datasourceType: IDataBaseOptionKeys = {
     label: 'DB2',
     defaultPort: 50000
   },
+  VERTICA: {
+    value: 'VERTICA',
+    label: 'VERTICA',
+    defaultPort: 5433
+  },
   PRESTO: {
     value: 'PRESTO',
     label: 'PRESTO',
@@ -240,6 +356,56 @@ export const datasourceType: IDataBaseOptionKeys = {
     value: 'ATHENA',
     label: 'ATHENA',
     defaultPort: 0
+  },
+  TRINO: {
+    value: 'TRINO',
+    label: 'TRINO',
+    defaultPort: 8080
+  },
+  AZURESQL: {
+    value: 'AZURESQL',
+    label: 'AZURESQL',
+    defaultPort: 1433
+  },
+  STARROCKS: {
+    value: 'STARROCKS',
+    label: 'STARROCKS',
+    defaultPort: 9030
+  },
+  DAMENG: {
+    value: 'DAMENG',
+    label: 'DAMENG',
+    defaultPort: 5236
+  },
+  OCEANBASE: {
+    value: 'OCEANBASE',
+    label: 'OCEANBASE',
+    defaultPort: 2881
+  },
+  SNOWFLAKE: {
+    value: 'SNOWFLAKE',
+    label: 'SNOWFLAKE',
+    defaultPort: 3306
+  },
+  SSH: {
+    value: 'SSH',
+    label: 'SSH',
+    defaultPort: 22
+  },
+  DATABEND: {
+    value: 'DATABEND',
+    label: 'DATABEND',
+    defaultPort: 8000
+  },
+  HANA: {
+    value: 'HANA',
+    label: 'HANA',
+    defaultPort: 30015
+  },
+  DORIS: {
+    value: 'DORIS',
+    label: 'DORIS',
+    defaultPort: 9030
   }
 }
 
