@@ -24,7 +24,8 @@ import {
   provide,
   computed,
   h,
-  Ref
+  Ref,
+  onMounted
 } from 'vue'
 import { useI18n } from 'vue-i18n'
 import Modal from '@/components/modal'
@@ -48,6 +49,8 @@ import type {
   IWorkflowTaskInstance,
   WorkflowInstance
 } from './types'
+import { queryProjectPreferenceByProjectCode } from '@/service/modules/projects-preference'
+import { INodeData } from './types'
 
 const props = {
   show: {
@@ -109,6 +112,7 @@ const NodeDetailModal = defineComponent({
     }
 
     const headerLinks = ref([] as any)
+    const projectPreferences = ref({} as any)
 
     const handleViewLog = () => {
       if (props.taskInstance) {
@@ -116,6 +120,20 @@ const NodeDetailModal = defineComponent({
       }
     }
 
+    const initProjectPreferences = (projectCode: number) => {
+      queryProjectPreferenceByProjectCode(projectCode).then((result: any) => {
+        if (result?.preferences && result.state === 1) {
+          projectPreferences.value = JSON.parse(result.preferences)
+        }
+      })
+    }
+
+    const restructureNodeData = (data: INodeData) => {
+      if (!data?.id) {
+        Object.assign(data, projectPreferences.value)
+      }
+    }
+
     const initHeaderLinks = (processInstance: any, taskType?: ITaskType) => {
       headerLinks.value = [
         {
@@ -140,9 +158,8 @@ const NodeDetailModal = defineComponent({
           action: () => {
             router.push({
               name: 'task-instance',
-              params: {
-                processInstanceId: processInstance.id,
-                taskName: props.data.name
+              query: {
+                taskCode: props.data.code
               }
             })
           },
@@ -158,7 +175,9 @@ const NodeDetailModal = defineComponent({
         },
         {
           text: t('project.node.enter_this_child_node'),
-          show: props.data.taskType === 'SUB_PROCESS',
+          show:
+            props.data.taskType === 'SUB_PROCESS' ||
+            props.data.taskType === 'DYNAMIC',
           disabled:
             !props.data.id ||
             (router.currentRoute.value.name === 'workflow-instance-detail' &&
@@ -204,14 +223,20 @@ const NodeDetailModal = defineComponent({
       }))
     )
 
+    onMounted(() => {
+      initProjectPreferences(props.projectCode)
+    })
+
     watch(
       () => [props.show, props.data],
       async () => {
         if (!props.show) return
         initHeaderLinks(props.processInstance, props.data.taskType)
         taskStore.init()
+        const nodeData = formatModel(props.data)
         await nextTick()
-        detailRef.value.value.setValues(formatModel(props.data))
+        restructureNodeData(nodeData)
+        detailRef.value.value.setValues(nodeData)
       }
     )
 
