@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-import { computed, ref } from 'vue'
+import { computed, ref, watch } from 'vue'
 import { useI18n } from 'vue-i18n'
 import {
   useCustomParams,
@@ -25,7 +25,9 @@ import {
   useExecutorMemory,
   useExecutorCores,
   useMainJar,
-  useResources
+  useNamespace,
+  useResources,
+  useYarnQueue
 } from '.'
 import type { IJsonItem } from '../types'
 
@@ -37,10 +39,39 @@ export function useSpark(model: { [field: string]: any }): IJsonItem[] {
 
   const mainArgsSpan = computed(() => (model.programType === 'SQL' ? 0 : 24))
 
-  const rawScriptSpan = computed(() => (model.programType === 'SQL' ? 24 : 0))
+  const rawScriptSpan = computed(() => (model.programType === 'SQL' && model.sqlExecutionType === 'SCRIPT' ? 24 : 0))
 
   const showCluster = computed(() => model.programType !== 'SQL')
 
+  const resourcesRequired = ref(
+    model.programType === 'SQL' && model.sqlExecutionType === 'FILE'
+  )
+
+  const resourcesLimit = computed(() =>
+    model.programType === 'SQL' && model.sqlExecutionType === 'FILE' ? 1 : -1
+  )
+
+  const sqlExecutionTypeSpan = computed(() => (model.programType === 'SQL' ? 12 : 0))
+
+  const SQL_EXECUTION_TYPES = [
+    {
+      label: t('project.node.sql_execution_type_from_script'),
+      value: 'SCRIPT'
+    },
+    {
+      label: t('project.node.sql_execution_type_from_file'),
+      value: 'FILE'
+    }
+  ]
+
+  watch(
+    () => [model.sqlExecutionType, model.programType],
+    () => {
+      resourcesRequired.value =
+        model.programType === 'SQL' && model.sqlExecutionType === 'FILE'
+    }
+  )
+
   return [
     {
       type: 'select',
@@ -57,10 +88,14 @@ export function useSpark(model: { [field: string]: any }): IJsonItem[] {
     },
     {
       type: 'select',
-      field: 'sparkVersion',
-      span: 12,
-      name: t('project.node.spark_version'),
-      options: SPARK_VERSIONS
+      field: 'sqlExecutionType',
+      span: sqlExecutionTypeSpan,
+      name: t('project.node.sql_execution_type'),
+      options: SQL_EXECUTION_TYPES,
+      validate: {
+        trigger: ['input', 'blur'],
+        required: true
+      }
     },
     {
       type: 'input',
@@ -90,6 +125,9 @@ export function useSpark(model: { [field: string]: any }): IJsonItem[] {
       field: 'rawScript',
       span: rawScriptSpan,
       name: t('project.node.script'),
+      props: {
+        language: 'sql'
+      },
       validate: {
         trigger: ['input', 'trigger'],
         required: true,
@@ -97,6 +135,7 @@ export function useSpark(model: { [field: string]: any }): IJsonItem[] {
       }
     },
     useDeployMode(24, ref(true), showCluster),
+    useNamespace(),
     {
       type: 'input',
       field: 'appName',
@@ -110,6 +149,7 @@ export function useSpark(model: { [field: string]: any }): IJsonItem[] {
     useExecutorNumber(),
     useExecutorMemory(),
     useExecutorCores(),
+    useYarnQueue(),
     {
       type: 'input',
       field: 'mainArgs',
@@ -129,7 +169,7 @@ export function useSpark(model: { [field: string]: any }): IJsonItem[] {
         placeholder: t('project.node.option_parameters_tips')
       }
     },
-    useResources(),
+    useResources(24, resourcesRequired, resourcesLimit),
     ...useCustomParams({ model, field: 'localParams', isSimple: false })
   ]
 }
@@ -152,14 +192,3 @@ export const PROGRAM_TYPES = [
     value: 'SQL'
   }
 ]
-
-export const SPARK_VERSIONS = [
-  {
-    label: 'SPARK2',
-    value: 'SPARK2'
-  },
-  {
-    label: 'SPARK1',
-    value: 'SPARK1'
-  }
-]
