@@ -72,6 +72,22 @@ export function useZeppelin(model: { [field: string]: any }): IJsonItem[] {
         placeholder: t('project.node.zeppelin_production_note_directory_tips')
       }
     },
+    {
+      type: 'input',
+      field: 'username',
+      name: t('project.node.zeppelin_username'),
+      props: {
+        placeholder: t('project.node.zeppelin_username_tips')
+      }
+    },
+    {
+      type: 'input',
+      field: 'password',
+      name: t('project.node.zeppelin_password'),
+      props: {
+        placeholder: t('project.node.zeppelin_password_tips')
+      }
+    },
     {
       type: 'input',
       field: 'parameters',
