@@ -57,7 +57,8 @@ export function useDataQuality({
     numExecutors: 2,
     executorMemory: '2G',
     executorCores: 2,
-    others: '--conf spark.yarn.maxAppAttempts=1'
+    others: '--conf spark.yarn.maxAppAttempts=1',
+    yarnQueue: ''
   } as INodeData)
 
   return {
@@ -65,6 +66,7 @@ export function useDataQuality({
       Fields.useName(from),
       ...Fields.useTaskDefinition({ projectCode, from, readonly, data, model }),
       Fields.useRunFlag(),
+      Fields.useCache(),
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
@@ -83,6 +85,7 @@ export function useDataQuality({
       Fields.useExecutorNumber(),
       Fields.useExecutorMemory(),
       Fields.useExecutorCores(),
+      Fields.useYarnQueue(),
       {
         type: 'input',
         field: 'others',
