@@ -38,6 +38,8 @@ export function useK8s({
     description: '',
     timeoutFlag: false,
     localParams: [],
+    customizedLabels: [],
+    nodeSelectors: [],
     environmentCode: null,
     failRetryInterval: 1,
     failRetryTimes: 0,
@@ -52,6 +54,7 @@ export function useK8s({
       Fields.useName(),
       ...Fields.useTaskDefinition({ projectCode, from, readonly, data, model }),
       Fields.useRunFlag(),
+      Fields.useCache(),
       Fields.useDescription(),
       Fields.useTaskPriority(),
       Fields.useWorkerGroup(),
