@@ -103,6 +103,7 @@ export default defineComponent({
   render() {
     const { t } = this
 
+    // @ts-ignore
     return (
       <div class={styles.box}>
         <ul class={styles['box-bd']}>
@@ -153,6 +154,10 @@ export default defineComponent({
                 : '-'}
             </span>
           </li>
+          <li>
+            <span class={styles.tab}>{t('project.workflow.tenant_code')}:</span>
+            <span class={styles.content}>{this.startupParam?.tenantCode}</span>
+          </li>
           <li>
             <span class={styles.tab}>
               {t('project.workflow.notification_strategy')}:
