@@ -106,6 +106,7 @@ export default defineComponent({
         state.functionForm.funcName = props.row.funcName
         state.functionForm.className = props.row.className
         state.functionForm.resourceId = props.row.resourceId || -1
+        state.functionForm.fullName = props.row.resourceName || ''
         state.functionForm.description = props.row.description
       }
     )
@@ -124,7 +125,6 @@ export default defineComponent({
   },
   render() {
     const { t } = useI18n()
-
     return (
       <Modal
         show={this.$props.show}
@@ -173,22 +173,23 @@ export default defineComponent({
           </NFormItem>
           <NFormItem
             label={t('resource.function.udf_resources')}
-            path='resourceId'
+            path='fullName'
           >
             <NInputGroup>
               <NTreeSelect
                 options={this.udfResourceList}
-                label-field='fullName'
-                key-field='id'
-                v-model={[this.functionForm.resourceId, 'value']}
+                label-field='name'
+                key-field='fullName'
+                check-strategy='child'
+                v-model={[this.functionForm.fullName, 'value']}
                 placeholder={t(
                   'resource.function.enter_select_udf_resources_tips'
                 )}
-                defaultValue={this.functionForm.resourceId}
+                defaultValue={this.functionForm.fullName}
                 disabled={this.uploadShow}
                 showPath={false}
                 class='btn-udf-resource-dropdown'
-              ></NTreeSelect>
+              />
               <NButton
                 type='primary'
                 ghost
@@ -216,7 +217,7 @@ export default defineComponent({
                     'resource.function.enter_select_udf_resources_directory_tips'
                   )}
                   defaultValue={this.uploadForm.pid}
-                ></NTreeSelect>
+                />
               </NFormItem>
               <NFormItem
                 label=' '
@@ -251,7 +252,6 @@ export default defineComponent({
                 style={{ marginBottom: '5px' }}
               >
                 <NInput
-                  allowInput={this.trim}
                   type='textarea'
                   v-model={[this.uploadForm.description, 'value']}
                   placeholder={t('resource.function.enter_description_tips')}
@@ -271,7 +271,6 @@ export default defineComponent({
             path='description'
           >
             <NInput
-              allowInput={this.trim}
               type='textarea'
               v-model={[this.functionForm.description, 'value']}
               placeholder={t('resource.function.enter_instructions_tips')}
