@@ -24,19 +24,13 @@ import {
   watch,
   getCurrentInstance
 } from 'vue'
-import {
-  NIcon,
-  NSpace,
-  NDataTable,
-  NButton,
-  NPagination,
-  NInput
-} from 'naive-ui'
+import { NIcon, NSpace, NDataTable, NButton, NPagination } from 'naive-ui'
 import { useI18n } from 'vue-i18n'
 import { SearchOutlined } from '@vicons/antd'
 import { useTable } from './use-table'
 import Card from '@/components/card'
 import FolderModal from './components/function-modal'
+import Search from '@/components/input-search'
 import styles from './index.module.scss'
 
 export default defineComponent({
@@ -47,6 +41,7 @@ export default defineComponent({
     const requestData = () => {
       getTableData({
         id: variables.id,
+        fullName: variables.fullName,
         pageSize: variables.pageSize,
         pageNo: variables.page,
         searchVal: variables.searchVal
@@ -114,11 +109,10 @@ export default defineComponent({
               {t('resource.function.create_udf_function')}
             </NButton>
             <NSpace>
-              <NInput
-                allowInput={this.trim}
-                size='small'
+              <Search
                 placeholder={t('resource.function.enter_keyword_tips')}
-                v-model={[this.searchVal, 'value']}
+                v-model:value={this.searchVal}
+                onSearch={this.handleSearch}
               />
               <NButton type='primary' size='small' onClick={this.handleSearch}>
                 <NIcon>
