@@ -18,8 +18,8 @@
 package org.apache.dolphinscheduler.server.worker.message;
 
 import org.apache.dolphinscheduler.plugin.task.api.TaskExecutionContext;
-import org.apache.dolphinscheduler.remote.command.CommandType;
-import org.apache.dolphinscheduler.remote.command.TaskExecuteRunningCommand;
+import org.apache.dolphinscheduler.remote.command.MessageType;
+import org.apache.dolphinscheduler.remote.command.task.TaskExecuteRunningMessage;
 import org.apache.dolphinscheduler.remote.exceptions.RemotingException;
 import org.apache.dolphinscheduler.remote.utils.Host;
 import org.apache.dolphinscheduler.server.worker.config.WorkerConfig;
@@ -31,7 +31,7 @@ import org.springframework.beans.factory.annotation.Autowired;
 import org.springframework.stereotype.Component;
 
 @Component
-public class TaskExecuteRunningMessageSender implements MessageSender<TaskExecuteRunningCommand> {
+public class TaskExecuteRunningMessageSender implements MessageSender<TaskExecuteRunningMessage> {
 
     @Autowired
     private WorkerRpcClient workerRpcClient;
@@ -40,15 +40,15 @@ public class TaskExecuteRunningMessageSender implements MessageSender<TaskExecut
     private WorkerConfig workerConfig;
 
     @Override
-    public void sendMessage(TaskExecuteRunningCommand message) throws RemotingException {
+    public void sendMessage(TaskExecuteRunningMessage message) throws RemotingException {
         workerRpcClient.send(Host.of(message.getMessageReceiverAddress()), message.convert2Command());
     }
 
-    public TaskExecuteRunningCommand buildMessage(@NonNull TaskExecutionContext taskExecutionContext,
-                                                  @NonNull String messageReceiverAddress) {
-        TaskExecuteRunningCommand taskExecuteRunningMessage =
-                new TaskExecuteRunningCommand(workerConfig.getWorkerAddress(),
-                        messageReceiverAddress,
+    @Override
+    public TaskExecuteRunningMessage buildMessage(@NonNull TaskExecutionContext taskExecutionContext) {
+        TaskExecuteRunningMessage taskExecuteRunningMessage =
+                new TaskExecuteRunningMessage(workerConfig.getWorkerAddress(),
+                        taskExecutionContext.getWorkflowInstanceHost(),
                         System.currentTimeMillis());
         taskExecuteRunningMessage.setTaskInstanceId(taskExecutionContext.getTaskInstanceId());
         taskExecuteRunningMessage.setProcessInstanceId(taskExecutionContext.getProcessInstanceId());
@@ -62,7 +62,7 @@ public class TaskExecuteRunningMessageSender implements MessageSender<TaskExecut
     }
 
     @Override
-    public CommandType getMessageType() {
-        return CommandType.TASK_EXECUTE_RUNNING;
+    public MessageType getMessageType() {
+        return MessageType.TASK_EXECUTE_RUNNING_MESSAGE;
     }
 }
