@@ -20,25 +20,25 @@ package org.apache.dolphinscheduler.server.worker.metrics;
 import java.util.concurrent.TimeUnit;
 import java.util.function.Supplier;
 
+import lombok.experimental.UtilityClass;
 import io.micrometer.core.instrument.Counter;
 import io.micrometer.core.instrument.DistributionSummary;
 import io.micrometer.core.instrument.Gauge;
 import io.micrometer.core.instrument.Metrics;
 import io.micrometer.core.instrument.Timer;
-import lombok.experimental.UtilityClass;
 
 @UtilityClass
 public class WorkerServerMetrics {
 
     private final Counter workerOverloadCounter =
-        Counter.builder("ds.worker.overload.count")
-            .description("overloaded workers count")
-            .register(Metrics.globalRegistry);
+            Counter.builder("ds.worker.overload.count")
+                    .description("overloaded workers count")
+                    .register(Metrics.globalRegistry);
 
     private final Counter workerFullSubmitQueueCounter =
-        Counter.builder("ds.worker.full.submit.queue.count")
-            .description("full worker submit queues count")
-            .register(Metrics.globalRegistry);
+            Counter.builder("ds.worker.full.submit.queue.count")
+                    .description("full worker submit queues count")
+                    .register(Metrics.globalRegistry);
 
     private final Counter workerResourceDownloadSuccessCounter =
             Counter.builder("ds.worker.resource.download.count")
@@ -61,11 +61,11 @@ public class WorkerServerMetrics {
 
     private final DistributionSummary workerResourceDownloadSizeDistribution =
             DistributionSummary.builder("ds.worker.resource.download.size")
-            .baseUnit("bytes")
-            .publishPercentiles(0.5, 0.75, 0.95, 0.99)
-            .publishPercentileHistogram()
-            .description("size of downloaded resource files on worker")
-            .register(Metrics.globalRegistry);
+                    .baseUnit("bytes")
+                    .publishPercentiles(0.5, 0.75, 0.95, 0.99)
+                    .publishPercentileHistogram()
+                    .description("size of downloaded resource files on worker")
+                    .register(Metrics.globalRegistry);
 
     public void incWorkerOverloadCount() {
         workerOverloadCounter.increment();
@@ -91,10 +91,40 @@ public class WorkerServerMetrics {
         workerResourceDownloadSizeDistribution.record(size);
     }
 
-    public void registerWorkerRunningTaskGauge(final Supplier<Number> supplier) {
-        Gauge.builder("ds.task.running", supplier)
-            .description("number of running tasks on workers")
-            .register(Metrics.globalRegistry);
+    public void registerWorkerTaskTotalGauge(final Supplier<Number> supplier) {
+        Gauge.builder("ds.worker.task", supplier)
+                .description("total number of tasks on worker")
+                .register(Metrics.globalRegistry);
+    }
+
+    public void registerWorkerExecuteQueueSizeGauge(Supplier<Number> supplier) {
+        Gauge.builder("ds.worker.execute.queue.size", supplier)
+                .description("worker execute queue size")
+                .register(Metrics.globalRegistry);
+    }
+
+    public void registerWorkerActiveExecuteThreadGauge(Supplier<Number> supplier) {
+        Gauge.builder("ds.worker.active.execute.thread", supplier)
+                .description("number of active task execute threads on worker")
+                .register(Metrics.globalRegistry);
+    }
+
+    public void registerWorkerMemoryAvailableGauge(Supplier<Number> supplier) {
+        Gauge.builder("ds.worker.memory.available", supplier)
+                .description("worker memory available")
+                .register(Metrics.globalRegistry);
+    }
+
+    public void registerWorkerCpuUsageGauge(Supplier<Number> supplier) {
+        Gauge.builder("ds.worker.cpu.usage", supplier)
+                .description("worker cpu usage")
+                .register(Metrics.globalRegistry);
+    }
+
+    public void registerWorkerMemoryUsageGauge(Supplier<Number> supplier) {
+        Gauge.builder("ds.worker.memory.usage", supplier)
+                .description("worker memory usage")
+                .register(Metrics.globalRegistry);
     }
 
 }
